/****************************************************************************
 * fritems.h
 * Frame Relay WAN SmartCard Configuration definitions
 *
 * Copyright (c) 1993-2000, Spirent Communications of Calabasas, Inc.
 * Copyright (c) 1996-1999, Netcom Systems, Inc.
 ****************************************************************************/

#ifndef _FRITEMS_H_
#define _FRITEMS_H_

#include "ettypes.h"
#include "stmitems.h"
#include "wanitems.h"
#include "l3items.h"

/**************************************************************************
 * Notes On Calling Sequence using the API.
 *
 * - Updating link configuration resets the link.
 *
 * - LMI can be changed on-the-fly. However, caution should be taken as the DTE
 *   and DCE and get out of sequence. In that case, reset the link. In general,
 *   there is no need to change the UNI mode without resetting the link.
 *   Changing the timer and count can be done on-the-fly. Changing UNI mode/
 *   LMP will reset LMI.
 *
 * - One drawback of card configuration is to restart all protocol frames. It
 *   can be made better by separating the transmit mode and protocol frame
 *   configurations commands in the future.
 *
 * - Transmit frame rate is actually a running average of the rate for the
 *   current second and the last recorded rate. This is done to smooth out any
 *   jerking in rate counters.
 *
 * - All stack frames and LMI frames are counted when they are enqueued for
 *   transmission instead of being counted after they are sent.
 *
 * - When link configuration is changed, the link is restarted. However, in
 *   some situation, the down time is too short for the peer physical layer to
 *   detect the link has been restarted. It may be better to explicitly do link
 *   disable and enable. Ideally a stream or PVC can be disable or enabled when
 *   traffic is ongoing to inject frames error and to vary traffic.
 *
 * - After IP subnets are added/removed. A commit command should be done before
 *   it is taken into effect.
 *
 *
 * Notes On Frame Relay Testing Setup, Test and Retrieve Result Data
 *
 *   Like any other protocol testing, we use HTSetStructure to setup Frame Relay
 *   testing, then use HTGetStructure to bring back the testing results. We can
 *   play calculation, reformation and all kinds of analysis processes before we
 *   display results to user. So, here are the major steps:
 *
 *   SetStructure -> Run -> Stop -> GetStructure -> Analysis -> Display
 *
 *   Example 1. Configure multi-PVC and multi-stream in a wan card
 *              Here we setup a back-to-back testing by using multi-pvc and
 *              multi-stream.
 *              Tx port is iHubTx, iSlotTx and iPortTx.
 *              Rx port is iHubRx, iSlotRx and iPortRx.
 *
 *              ETSocketLink("aaa.bbb.ccc.ddd", 16385);
 *
 *              // use HTSetDefaultFrLine to config default FRLineCfg structure
 *              FRSetDefaultLine( true,       // DTE
 *                                  1024000L,   // Speed
 *                                  iHubTx, iSlotTx, iPortTx);
 *              FRSetDefaultLine( false,      // DCE
 *                                  1024000L,   // Speed
 *                                  iHubRx, iSlotRx, iPortRx);
 *
 *              // use HTSetDefaultFrLmi to config default FRLmiCfg structure
 *              FRSetDefaultLmi(  true,          // true for DTE
 *                                  FR_C_LMI_PARM, // FR_C_DISABLE
 *                                  iHubTx,   iSlotTx,   iPortTx );
 *
 *              FRSetDefaultLmi(  false,         // false for DCE
 *                                  FR_C_LMI_PARM, // FR_C_DISABLE
 *                                  iHubRx,   iSlotRx,   iPortRx );
 *
 *              // use HTSetDefaultFrCardCfg to cfg default FRCardCfg structure
 *              FRSetDefaultCardCfg(
 *                                  5,                // ulMultiBurstCnt,
 *                                  10,               // ulBurstCnt,
 *                                  9L,               // ulInterBurstGap
 *                                  FR_TX_CONTINUOUS, // ulTxMode,
 *                                  FR_RFC1490_RTD_NLPID,// ucEncapType
 *                                  ucCardSlot,       // the card number
 *                                  iHubTx,   iSlotTx,   iPortTx );
 *
 *              // Command FR_SET_START_CFG, Start PVC, stream and
 *              // IP subnet addr. Config
 *              FRSetStartCfg( iHubTx,   iSlotTx,   iPortTx );
 *              FRSetStartCfg( iHubRx,   iSlotRx,   iPortRx );
 *
 *              // Command FR_STREAM_DELETE_ALL, Delete all existing streams
 *              FRDeleteAllStream( iHubTx,   iSlotTx,   iPortTx );
 *
 *              // Command FR_PVC_DELETE_ALL, Delete all existing PVCs
 *              FRDeleteAllPvc( iHubTx,   iSlotTx,   iPortTx);
 *              FRDeleteAllPvc( iHubRx,   iSlotRx,   iPortRx);
 *
 *              // Define 4 PVCs between Tx and Rx
 *              for(i=1; i<=4; i++)
 *              {
 *                FRSetPVC(
 *                64000L,       //CIR,
 *                10 * i,       //DLCI,
 *                64000L,       //Bc,
 *                1024000L,     //AccessRate,
 *                0,            //Be,
 *                500,          //FrameRate,
 *                FR_IPSUBNET_ID_NOT_DEFINE,  // IPSubnet ID
 *                iHubTx,  iSlotTx,  iPortTx );
 *              }
 *
 *              for(i=1; i<=4; i++)
 *              {
 *                FRSetPVC(
 *                64000L,       //CIR,
 *                10 * i,       //DLCI,
 *                64000L,       //Bc,
 *                1024000L,     //AccessRate,
 *                0,            //Be,
 *                500,          //FrameRate,
 *                FR_IPSUBNET_ID_NOT_DEFINE,  // IPSubnet ID
 *                iHubRx,  iSlotRx,  iPortRx );
 *              }
 *
 *              // Define 10 IP streams at Tx:
 *              for(i=0; i<iStreamPvcCount; i++)
 *              {
 *                FRSetDefaultStreamIP(
 *                60,        //iFrameLength,
 *                1,         // Tag Enable 1, otherwise 0
 *                i+1,       //iInitialSequenceNumber
 *                iHubTx,iSlotTx,iPortTx );
 *              }
 *
 *              //Following are a mapping between PVC and Stream's StreamId
 *              // The mapping is:
 *
 *              // 0 - 40,  1 - 40,  2 - 40,  3 - 40
 *              FRSetDefaultPvcStrmMapCfg(0,40,
 *                                          0,0,0,0,0,0,FR_RFC1490_RTD_NLPID,
 *                                          iHubTx,   iSlotTx,   iPortTx );
 *              FRSetDefaultPvcStrmMapCfg(1,40,
 *                                          0,0,0,0,0,0,FR_RFC1490_RTD_NLPID,
 *                                          iHubTx,   iSlotTx,   iPortTx );
 *              FRSetDefaultPvcStrmMapCfg(2,40,
 *                                          0,0,0,0,0,0,FR_RFC1490_RTD_NLPID,
 *                                          iHubTx,   iSlotTx,   iPortTx );
 *              FRSetDefaultPvcStrmMapCfg(3,40,
 *                                          0,0,0,0,0,0,FR_RFC1490_RTD_NLPID,
 *                                          iHubTx,   iSlotTx,   iPortTx );
 *
 *              // 4 - 20,  5 - 20,  6 - 20
 *              FRSetDefaultPvcStrmMapCfg(4,20,
 *                                          0,0,0,0,0,0,FR_RFC1490_RTD_NLPID,
 *                                          iHubTx,   iSlotTx,   iPortTx );
 *              FRSetDefaultPvcStrmMapCfg(5,20,
 *                                          0,0,0,0,0,0,FR_RFC1490_RTD_NLPID,
 *                                          iHubTx,   iSlotTx,   iPortTx );
 *              FRSetDefaultPvcStrmMapCfg(6,20,
 *                                          0,0,0,0,0,0,FR_RFC1490_RTD_NLPID,
 *                                          iHubTx,   iSlotTx,   iPortTx );
 *
 *              // 7 - 30,  8 - 30
 *              FRSetDefaultPvcStrmMapCfg(7,30,
 *                                          0,0,0,0,0,0,FR_RFC1490_RTD_NLPID,
 *                                          iHubTx,   iSlotTx,   iPortTx );
 *              FRSetDefaultPvcStrmMapCfg(8,30,
 *                                          0,0,0,0,0,0,FR_RFC1490_RTD_NLPID,
 *                                          iHubTx,   iSlotTx,   iPortTx );
 *
 *              // 9 - 10
 *              FRSetDefaultPvcStrmMapCfg(9,40,
 *                                          0,0,0,0,0,0,FR_RFC1490_RTD_NLPID,
 *                                          iHubTx,   iSlotTx,   iPortTx );
 *
 *              // STREAM CONTROL MESSAGE:
 *              // The FRStreamControl structure allows the user to
 *              // modify one or more fields on a single streams.
 *              // We can use HTSetFrameRelayStreamCntl to setup this structure
 *              for(i=0; i<10; i++)      // number of streams
 *              {
 *                FRSetStreamCntl(
 *                i,          //iStreamId,
 *                1,          //iEnable
 *                0,          //ucFcsError,
 *                0,          //ucAbortFlag,
 *                iHubTx,  iSlotTx,   iPortTx );
 *              }
 *
 *              // PVC CONTROL MESSAGE:
 *              // FRPvcControl structure is used to disable/enable a PVC.
 *              // We can use HTSetFrameRelayPVCCntl to setup this structure
 *              for(i=1; i<=4; i++)
 *              {
 *                FRSetPVCCntl(
 *                10 * i,     //iDLCI,
 *                1,          //iEnable
 *                iHubTx,  iSlotTx,  iPortTx );
 *              }
 *
 *              for(i=1; i<=4; i++)
 *              {
 *                FRSetPVCCntl(
 *                10 * i,     //iDLCI,
 *                1,          //iEnable
 *                iHubRx,  iSlotRx,  iPortRx );
 *              }
 *
 *              // Command FR_ENABLE_PORT ,   Enable WAN port
 *              FREnablePort(iHubTx,   iSlotTx,   iPortTx );
 *              FREnablePort(iHubRx,   iSlotRx,   iPortRx );
 *
 *              // Command FR_COMMIT_CFG,Commit PVC,stream and IP subnet config.
 *              FRCommitCfg(iHubTx,   iSlotTx,   iPortTx );
 *              FRCommitCfg(iHubRx,   iSlotRx,   iPortRx );
 *
 *   Example 2. Run histogram testing
 *              Base on the configuration at Example 1, we can do histogram test
 *
 *              unsigned long  ulHistogramType = FR_HIST_V2_LATENCY_INFO;
 *
 *              FRHistogram  FRHist;
 *              memset((void*)&FRHist, 0, sizeof(FRHistogram));
 *              FRHist.ulHistType = (unsigned long)ulHistogramType;
 *              FRHist.ulTimeBucket = 1000L;
 *              unsigned long  latref[16] =
 *              {
 *                1L,2L,5L,10L,20L,50L,100L,200L,500L,1000L,2000L,5000L,
 *                10000L,20000L,(unsigned short)50000L,(unsigned short)65535L
 *              };
 *              memcpy(FRHist.ulLatRef, latref, 16*sizeof(unsigned long));
 *
 *              HTSetStructure( FR_HISTOGRAM, 0, 0, 0,
 *                              (void*)&FRHist, sizeof(FRHistogram),
 *                              iHubRx,   iSlotRx,   iPortRx );
 *
 *              FRHistReset    pRH;
 *              memset( (void*)&pRH, -1, sizeof(pRH) );
 *              pRH.ulHistType = (unsigned long)ucHistogramType;
 *              HTSetStructure( FR_HIST_RESET, 0, 0, 0,
 *                              (void*)&pRH, sizeof(FRHistReset),
 *              iHubRx,   iSlotRx    iPortRx );
 *
 *              HTRun(HTRUN, iHubTx,   iSlotTx,   iPortTx);
 *
 *   Example 3. Retrieve histogram testing data
 *              // After finished testing or after for a certain time,
 *              // Stop the testing by:
 *              HTRun(HTSTOP, iHubTx,   iSlotTx,   iPortTx);
 *
 *              unsigned long  pulHistRecCount,  RecStart = 0;
 *              int  recv_page;
 *
 *              // to check how much data for histogram testing
 *              HTGetStructure( FR_HIST_TYPE_INFO,0,0,0,
 *                              (void*)&pulHistRecCount, sizeof(unsigned long),
 *                              iHubRx,   iSlotRx,   iPortRx);
 *
 *             while(pulHistRecCount)
 *             {
 *               recv_page = pulHistRecCount > 20 ? 20 : pulHistRecCount;
 *               pulHistRecCount  -= recv_page;
 *
 *               Layer3LongLatencyInfo pRLI[20];
 *               memset( (void*)&pRLI, -1, sizeof(pRLI) );
 *               HTGetStructure( iHistogramType,  RecStart,  recv_page,  0,
 *                               (void*)&pRLI,
 *                               recv_page*sizeof(Layer3LongLatencyInfo),
 *                               iHubRx,   iSlotRx,   iPortRx);
 *               // Here we can analysis and display result data
 *               RecStart  += recv_page;
 *             }
 *
 ****************************************************************************/

/****************************************************************************/

/****************************************************************************/
/*  NOTE:                                                                   */
/*  In this header file WAN refers to the following family of cards:        */
/*   WN-3405, WN-3410                                                       */
/****************************************************************************/

/*--------------------------------------------------------------------------*/
/*------ Frame Relay SmartCard Parameters and Data Structures --------------*/
/*--------------------------------------------------------------------------*/

/****************************************************************************/
/****************************************************************************/
/* Message definition */

/*------ Frame Relay iType1 values  ----------------------------------------*/
#define FR_PORT_SETTINGS        0

/* start common defines */
/*----------- iType1 -------------------------------------------------------*/
/* #define FR_DEFINE_STREAM        0x100 */
/* Config a new or overwrite an existing stream  */
#define FR_DEFINE_SMARTBITS_STREAM  NS_DEFINE_SMARTBITS_STREAM /* raw stream */
#define FR_DEFINE_802_3_STREAM		NS_DEFINE_802_3_STREAM 	/* 802_3 used in conjunction with bridged encap. */
#define FR_DEFINE_IP_STREAM			NS_DEFINE_IP_STREAM  	/* Define an IP stream */
#define FR_DEFINE_IPX_STREAM  		NS_DEFINE_IPX_STREAM 	/* Define an IPX stream */
#define FR_DEFINE_UDP_STREAM  		NS_DEFINE_UDP_STREAM 	/* Define a UDP stream */
#define FR_DEFINE_ARP_STREAM  		NS_DEFINE_ARP_STREAM 	/* not currently supported */

#define FR_DEFINE_MULTI_SMARTBITS_STREAM  NS_DEFINE_MULTI_SMARTBITS_STREAM
			  /* reserved */
#define FR_DEFINE_MULTI_802_3_STREAM NS_DEFINE_MULTI_802_3_STREAM/* reserved */
#define FR_DEFINE_MULTI_IP_STREAM    NS_DEFINE_MULTI_IP_STREAM   /* reserved */
#define FR_DEFINE_MULTI_IPX_STREAM   NS_DEFINE_MULTI_IPX_STREAM  /* reserved */
#define FR_DEFINE_MULTI_UDP_STREAM   NS_DEFINE_MULTI_UDP_STREAM  /* reserved */
#define FR_DEFINE_MULTI_ARP_STREAM   NS_DEFINE_MULTI_ARP_STREAM  /* reserved */

/* Duplicate an existing stream - TBD */
#define FR_DUP_STREAM						NS_DUP_STREAM  /* reserved - duplicate streams */

/* Modify one or more fields of an existing stream - reserved */
#define FR_MOD_SMARTBITS_STREAM			NS_MOD_SMARTBITS_STREAM    /* reserved */
#define FR_MOD_802_3_STREAM				NS_MOD_802_3_STREAM        /* reserved */
#define FR_MOD_IP_STREAM					NS_MOD_IP_STREAM           /* reserved */
#define FR_MOD_IPX_STREAM					NS_MOD_IPX_STREAM          /* reserved */
#define FR_MOD_UDP_STREAM					NS_MOD_UDP_STREAM          /* reserved */
#define FR_MOD_ARP_STREAM     			NS_MOD_ARP_STREAM   			/* not currently supported */

#define FR_MOD_STREAMS_DELTA				NS_MOD_STREAMS_DELTA    	/* reserved */
#define FR_MOD_STREAMS_ARRAY				NS_MOD_STREAMS_ARRAY     	/* reserved */

/*----------------------- HTGetStructure ------------------------------------*/
/*----------- iType1 ---------------*/
#define FR_DEFINED_STREAM_COUNT_INFO	NS_STREAM_COUNT_INFO
#define FR_STREAM_INFO     				0x99D6
#define FR_SMARTBITS_STREAM_INFO  		NS_SMARTBITS_STREAM_INFO/* Get raw stream config info. */
#define FR_802_3_STREAM_INFO      		NS_802_3_STREAM_INFO  	/* Get 802_3 stream config info. */
#define FR_IP_STREAM_INFO         		NS_IP_STREAM_INFO     	/* Get IP stream config info. */
#define FR_IPX_STREAM_INFO        		NS_IPX_STREAM_INFO    	/* Get IPX stream config info. */
#define FR_UDP_STREAM_INFO        		NS_UDP_STREAM_INFO    	/* Get UDP stream config info. */
#define FR_ARP_STREAM_INFO        		NS_ARP_STREAM_INFO 		/*not currently supported	*/

/* Retrieve card address info */
#define FR_TX_ADDRESS_INFO    			NS_TX_ADDRESS_INFO    	/* Get card addr info */
#define FR_ARP_TIMES_INFO     			NS_ARP_TIMES_INFO     	/* not currently supported */

#define FR_HIST_ACTIVE_TEST_INFO  		NS_HIST_ACTIVE_TEST_INFO  /* Get number of records, and which Histogram is active */
/*#define FR_HIST_LATENCY_PRECISION_INFO  NS_HIST_LATENCY_PRECISION_INFO*/
#define FR_HIST_START 						NS_HIST_START
#define FR_HIST_SEQUENCE 					NS_HIST_SEQUENCE               /* Activate Sequence Histogram on RX card */
#define FR_HIST_LATENCY   					NS_HIST_LATENCY
#define FR_HIST_LATENCY_PER_STREAM 		NS_HIST_LATENCY_PER_STREAM
#define FR_HIST_LATENCY_DISTRIBUTION	NS_HIST_LATENCY_DISTRIBUTION  /* Activate Latency Distribution Histogram on RX card */
#define FR_HIST_V2_LATENCY_DISTRIBUTION NS_HIST_V2_LATENCY_DISTRIBUTION
#define FR_HIST_RAW_TAGS 					NS_HIST_RAW_TAGS              /* Activate Raw Tags Histogram on RX card */
#define FR_HIST_V2_LATENCY					NS_HIST_V2_LATENCY            /* Activate Latency-Over-Time Histogram on RX card */
#define FR_HIST_V2_LATENCY_PER_STREAM	NS_HIST_V2_LATENCY_PER_STREAM /* Activate LatDist/LatPerStrm/Sequenc Histogram on RX card */
#define FR_HIST_LATENCY_PRECISION   	NS_HIST_LATENCY_PRECISION
#define FR_HIST_MULTICAST_LATENCY		NS_HIST_MULTICAST_LATENCY
#define FR_HIST_V2_LATENCY_DE				((NS_HIST_V2_LATENCY&0xFFF0)|0x0011)  /* local used by WAN only */

/* Retrieve histogram test result */
#define FR_HIST_SEQUENCE_INFO             NS_HIST_SEQUENCE_INFO             /*Retrieve Sequence Histogram Records */
#define FR_HIST_LATENCY_INFO              NS_HIST_LATENCY_INFO
#define FR_HIST_LATENCY_PER_STREAM_INFO   NS_HIST_LATENCY_PER_STREAM_INFO
#define FR_HIST_LATENCY_DISTRIBUTION_INFO NS_HIST_LATENCY_DISTRIBUTION_INFO /*Retrieve Latency Distribution Histogram Records */
#define FR_HIST_RAW_TAGS_INFO             NS_HIST_RAW_TAGS_INFO             /*Retrieve Raw Tags Histogram Records */
#define FR_HIST_V2_LATENCY_INFO           NS_HIST_V2_LATENCY_INFO           /*Retrieve Latency-Over-Time Histogram Records */
#define FR_HIST_V2_LATENCY_PER_STREAM_INFO  NS_HIST_V2_LATENCY_PER_STREAM_INFO
                                                                            /*Retrieve LatDist/LatPerStrm/Sequenc Histogram Records */
/* #define FR_HIST_REPORT        			NS_HIST_REPORT */
#define FR_HIST_V2_LATENCY_DE_INFO        ((NS_HIST_V2_LATENCY_INFO&0xFFF0)|0x0011)

/* following are the ID firmware needed */
#define FR_HIST_L3_SEQUENCE					1
#define FR_HIST_L3_LATENCYBYTIME				2
#define FR_HIST_L3_LATENCYBYSTREAM			3
#define FR_HIST_L3_LATENCYDISTRIBUTION		4
#define FR_HIST_L3_PACKETTAG					5
#define FR_HIST_L3_LONGLATENCY				6
#define FR_HIST_L3_LONGSTREAMLATENCY		7
#define FR_HIST_L3_RX_DELTA					8
#define FR_HIST_L3_ARPEXCHANGE				9
#define FR_HIST_L3_LONGLATENCY_DE			17

#define FR_HIST_SUMMARY_INFO					   NS_HIST_SUMMARY_INFO						/* Get summary results of active test */
#define FR_AGGREGATE_INFO  					   NS_AGGREGATE_INFO                   /* Get summary results of active test */
#define FR_AGGR_SEQUENCE_INFO					   NS_AGGR_SEQUENCE_INFO					/* Get Sequence Tracking histogram results */
#define FR_AGGR_LATENCY_INFO					   NS_AGGR_LATENCY_INFO						/* Get 16-bit Latency over Time histogram results */
#define FR_AGGR_LATENCY_PER_STREAM_INFO	   NS_AGGR_LATENCY_PER_STREAM_INFO		/* Get 16-bit Latency per Stream histogram results */
#define FR_AGGR_LATENCY_DISTRIBUTION_INFO	   NS_AGGR_LATENCY_DISTRIBUTION_INFO	/* Get Full Latency Distribution histogram results */
#define FR_AGGR_RAW_TAGS_INFO					   NS_AGGR_RAW_TAGS_INFO					/* Get Raw Tags information */
#define FR_AGGR_V2_LATENCY_INFO				   NS_AGGR_V2_LATENCY_INFO					/* Get 32-bit Latency over Time histogram results */
#define FR_AGGR_V2_LATENCY_PER_STREAM_INFO	NS_AGGR_V2_LATENCY_PER_STREAM_INFO	/* Get 32-bit Latency Distribution and Per Stream histogram results */
#define FR_AGGR_MC_LATENCY_PER_STREAM_INFO	NS_AGGR_MC_LATENCY_PER_STREAM_INFO  /* MulticastIP Latency Dist hist with 1st and last Rx timestamp */

/* Retrieve captured frames and info - reserved */
#define FR_CAPTURE_COUNT_INFO           		NS_CAPTURE_COUNT_INFO
#define FR_CAPTURE_PACKET_INFO          		NS_CAPTURE_PACKET_INFO  /* not L3 */
#define FR_CAPTURE_PACKET_DATA_INFO     		NS_CAPTURE_PACKET_DATA_INFO

/*-------- Layer 3 protocol types (from stmitems.h) ---------*/
#define FR_STREAM_SMARTBITS        STREAM_PROTOCOL_SMARTBITS
#define FR_STREAM_8023             STREAM_PROTOCOL_8023
#define FR_STREAM_IP               STREAM_PROTOCOL_IP
#define FR_STREAM_IPX              STREAM_PROTOCOL_IPX
#define FR_STREAM_UDP              STREAM_PROTOCOL_UDP
#define FR_STREAM_UDPDHCP          STREAM_PROTOCOL_UDPDHCP
/* end common defines */

/* Parameter setups */
#define FR_LOAD_CODE_IMAGE			1
#define FR_LOAD_FPGA_IMAGE			2
#define FR_PVC							3 	/* Config a new or existing PVC */
#define FR_PVC_DELETE_ALL			4	/* Delete all existing PVCs */
#define FR_STREAM_DELETE_ALL		5 	/* Delete all existing streams */
#define FR_LMI            			6 	/* Config LMP signaling timers, counter and mode */
#define FR_LINE						7 	/* Config physical layer */
#define FR_TRIGGER					8 	/* Config global tx and receive triggers */
#define FR_CARD_CFG					10 	/* Config global card params */
#define FR_FILL_PATTERN				11 	/* Config global background fill pattern */
#define FR_VFD3_BUFFER				12 	/* Config global VFD3 buffer - OBSOLETE */
#define FR_PVC_STREAM_MAP_CFG		13	/* Config per stream PVC related params */

/* #define FR_STREAM_INFO			14  */
#define FR_CARD_VERSION_INFO 		15	/* Get card firmware versions */

#define FR_DUP_PVC         		115	/* Duplicate an existing PVC config */
#define FR_DUP_PVC_MAP     		18	/* Duplicate PVC mapping for an existing stream */

#define FR_MOD_PVC         		20	/* TBD - Modify one or more PVC config param */
#define FR_MOD_PVC_MAP     		21	/* TBD - Modify one or more PVC-stream mapping config param */

#define FR_SET_START_CFG   		22 	/* Start PVC, stream and IP subnet addr. config */
#define FR_COMMIT_CFG      		23 	/* Commit PVC, stream and IP subnet config. */

#define FR_IP_SUBNET_REG   		25 	/* Config a new or existing IP subnet addr */
#define FR_IP_SUBNET_DEREG 		26 	/* Remove a new or existing IP subnet addr */

#define FR_SET_PROTO_STACK			28	/* set card protoocol stack and encapsulation  */

/* #define FR_ASSIGNED_ADDRESS 27*/ /* The assigned addr for Layer 3 operations */

/* Information retrieval */
/* Statistics/ data Request, and Control Message Types */

/* #define FR_STRM_COUNT_INFO   24  */
/* #define FR_DEFINED_STREAM_COUNT_INFO 0x120  */
/* as in L3_DEFINED_STREAM_COUNT_INFO */

#define FR_LINK_INFO         		31 	/* Get link statistics counters */
#define FR_PVC_INFO          		32 	/* Get per-PVC statistics counters */
/* #define FR_RX_SINGLE_PVC_INFO  32  */
/* OBSOLETE - Get per-PVC statistics counters - receive only */
#define FR_TX_SINGLE_PVC_INFO		33 	/* OBSOLETE - Get per-PVC statistics counters - xfer only */
#define FR_RX_AGGREGATE_PVC_INFO	34 	/* OBSOLETE - Get multiple-PVC statistics counters - receive only */
#define FR_TX_AGGREGATE_PVC_INFO	35 	/* OBSOLETE - Get multiple-PVC statistics counters - xfer only */
#define FR_ALL_PVC_INFO				36 	/* OBSOLETE */
#define FR_LMI_INFO					37 	/* Get LMP statistics counters */

#define FR_PVC_STATUS_INFO   		38 	/* Get PVC status for all 1024 PVCs */
#define FR_LINK_STATUS_INFO  		39		/* Get link status */
#define FR_INTERVALTIME_INFO  	40		/* Get Interval Time. */

/* Control */
#define FR_DISABLE_PORT    		41 	/* Disable WAN port */
#define FR_ENABLE_PORT     		42 	/* Enable WAN port */

#define FR_PVC_CTRL      			43 	/* Control a single PVC : disable/enable */
#define FR_STRM_CTRL     			44 	/* Control a stream:  disable/enable, generate errs etc */

#define FR_SET_PORT_LMI_STATUS 	45 	/* OBSOLETE */
#define FR_SET_PORT_LMI_ENQ    	46 	/* OBSOLETE */

 /* Capture */
#define FR_SET_RELEASE_CAP_CNT 	51 	/* reserved */
#define FR_CAP_CNT_INFO        	52 	/* reserved */
#define FR_CAPTURE_INFO        	53 	/* reserved */

/* IY - should be taken out as a latency application feature */

 /* Histogram parameter setup */
#define FR_HISTOGRAM        		61 	/* Config histogram type etc */
#define FR_HIST_RESET       		62 	/* Reset histogram state */
#define FR_HIST_SCALE       		63 	/* Config time scale for histogram */

 /* Histogram result retrieval */
#define FR_HIST_DATA_TYPE_INFO 	64 	/* uses iType2 to spec hist type */
#define FR_HIST_TYPE_INFO			65 	/* Get histogram result data */
/*#define FR_HIST_SUMMARY_INFO  	66 */
/* TBD : Get histogram summary result data */

/* IY - should be generic for all intelligent card */
/* MISC command */
#define FR_DUMP_MEM_INFO			71 	/* Send debug screen entered key */
#define FR_DEBUG_SCREEN_INFO		0xF2	/*Get debug screen output from keyed input*/

#define FR_T1E1_LINE				113 	/* Config T1E1 physical layer */
#define FR_T1E1_LINE_INFO			114 	/* Get T1E1 physical layer info */

/* IY - Should be hidden from the API */
/* Back-plane Commands */
#define FR_LED_STATUS_INFO			100 /* Get 32 bit LED status */
#define FR_GROUP_START_CMD			101 /* Start transmission if belong to group */
#define FR_GROUP_STEP_CMD			102 /* Send one frame if belong to group */
#define FR_GROUP_STOP_CMD			103 /* Stop transmission if belong to group */
#define FR_START_CMD					104 /* Start transmission */
#define FR_STEP_CMD					105 /* Sent one frame */
#define FR_STOP_CMD					106 /* Stop transmission */
#define FR_RESET_CARD_CMD			107 /* line reset */
#define FR_GROUP_MEMBER_CMD		108 /* Set card to be a member of group */
#define FR_NON_GROUP_CMD			109 /* unset card from group */
#define FR_CLEAR_COUNTERS_CMD		110 /* Clear all statistic counters */
#define FR_LOAD_IMAGE_CMD			111 /* load and S3 message */
#define FR_INPUT_MSG_CMD			112 /* Send an encoded API message */

/* end block of user defines */
/******************************************************************************
 * LINE INTERFACE PARAMS
 *
 * FRLineCfg Description:

Line configurations cause the line to be restarted. The new
parameters are stored in non-volatile memory. The line is brought
down for only a short duration (much less than 1 second). If
the line is disabled, it will remain so.

NOTE: Currently, an interface with physical DTE interface
MUST use external clocking whereas a DCE MUST use internal
clocking. This limitation will be removed in the near future.

 ******************************************************************************/
/* Min. InterBurst gap */
#define MIN_GAP_VALUE       		1

/* Line physical mode */
#define FR_CARD_DTE         		0
#define FR_CARD_DCE         		1

/* Encoding methods */
#define FR_NRZ_ENCODE       		1
#define FR_NRZI_ENCODE      		2

/* Line clocking type */
#define FR_CARD_CLK_EXTERNAL    	0
#define FR_CARD_CLK_INTERNAL    	1
#define FR_LOOP_TIMED_CLOCK		0

/* Clock polarity */
#define FR_CLK_RISING_EDGE      	0
#define FR_CLK_FALLING_EDGE     	1

/* Supported line speed */
#define FR_LINE_SPEED_19200L		19200L
#define FR_LINE_SPEED_38400L		38400L
#define FR_LINE_SPEED_48400L		48400L
#define FR_LINE_SPEED_56000L		56000L
#define FR_LINE_SPEED_64000L		64000L
#define FR_LINE_SPEED_128000L		128000L
#define FR_LINE_SPEED_192000L		192000L
#define FR_LINE_SPEED_256000L		256000L
#define FR_LINE_SPEED_320000L		320000L
#define FR_LINE_SPEED_384000L		384000L
#define FR_LINE_SPEED_448000L		448000L
#define FR_LINE_SPEED_512000L		512000L
#define FR_LINE_SPEED_576000L		576000L
#define FR_LINE_SPEED_640000L		640000L
#define FR_LINE_SPEED_704000L		704000L
#define FR_LINE_SPEED_768000L		768000L
#define FR_LINE_SPEED_832000L		832000L
#define FR_LINE_SPEED_896000L		896000L
#define FR_LINE_SPEED_960000L		960000L
#define FR_LINE_SPEED_1024000L	1024000L
#define FR_LINE_SPEED_1088000L	1088000L
#define FR_LINE_SPEED_1152000L	1152000L
#define FR_LINE_SPEED_1216000L	1216000L
#define FR_LINE_SPEED_1280000L	1280000L
#define FR_LINE_SPEED_1344000L	1344000L
#define FR_LINE_SPEED_1408000L	1408000L
#define FR_LINE_SPEED_1472000L	1472000L
#define FR_LINE_SPEED_1536000L	1536000L
#define FR_LINE_SPEED_1600000L	1600000L
#define FR_LINE_SPEED_1664000L	1664000L
#define FR_LINE_SPEED_1728000L	1728000L
#define FR_LINE_SPEED_1792000L	1792000L
#define FR_LINE_SPEED_1856000L	1856000L
#define FR_LINE_SPEED_1920000L	1920000L
#define FR_LINE_SPEED_1984000L	1984000L
#define FR_LINE_SPEED_2048000L	2048000L
#define FR_LINE_SPEED_4096000L	4096000L
#define FR_LINE_SPEED_6144000L	6144000L
#define FR_LINE_SPEED_8192000L	8192000L

typedef struct tagFRLineCfg
{
 unsigned long ulSpeed;    	/* Line speed in bps as defined by
										FR_LINE_SPEED_XXX above             */
 unsigned long ulProgBits;		/* reserved - MUST BE SET TO 0         */
										/* The Program Bit Pattern (21-25 bits) from   */
										/* BitCalc utility for programming the ICD-2053*/
										/* Clock Chip driving the HDLC controller for  */
										/* line speeds of 56K-8Mega Bits Per Sec.      */

 unsigned long ulProgBitsLen;	/* reserved - MUST BE SET TO 0      */
										/* Length of the above program bit pattern  */
										/* BitCalc utility */

 unsigned char ucLineMode; 	/* line physical mode */
										/* FR_CARD_DTE or FR_CARD_DCE */
 unsigned char ucClocking; 	/* clocking type */
										/* FR_CARD_CLK_EXTERNAL or FR_CARD_CLK_INTERNAL */
 unsigned char ucClkPolarity;	/* clock edge for tx data */
										/* FR_CLK_RISING_EDGE or FR_CLK_FALLING_EDGE */
 unsigned char ucEncoding; 	/* tx/rx data encoding */
										/* FR_NRZ_ENCODE or FR_NRZI_ENCODE */
 unsigned char ucGapCtl;   	/* min. # of interFrame flags */
										/* MIN. GAP VALUE or greater */
 unsigned char ucLoopbackOn;	/* 1 = on or 0 off */
 unsigned char ucCrcOff;		/* 1 = CRC off */
 unsigned char ucUseCRC32;		/* 1 = CRC32, 0 = CRC16 */
 unsigned char ucDataUnchanged;/* 1 = no zero insertion,
											0 = zero insertion */
 /* set indicate to turn on/detect signal */
 unsigned char ucDsrOn;			/* DCE */
 unsigned char ucCtsOn;			/* DCE */
 unsigned char ucDcdOn;			/* DCE */
 unsigned char ucTmOn;			/* DCE */
 unsigned char ucDtrOn;			/* DTE */
 unsigned char ucRtsOn;			/* DTE */
 unsigned char ucRdlOn;			/* DTE : reserved */
 unsigned char ucLlbOn;			/* DTE : reserved */

 unsigned char ucRxClocking;	/* clocking type  - applies only */
				/* if ucLineMode,above, is set to FR_CARD_DCE */
				/* FR_CARD_CLK_EXTERNAL (use pin 113 Tx) */
				/* or FR_CARD_CLK_INTERNAL */
 unsigned char ucRxClkPolarity; /* clock edge for tx data */
				/* FR_CLK_RISING_EDGE or FR_CLK_FALLING_EDGE */
				/* if unsure, try FR_CLK_FALLING_EDGE */
 unsigned char ucReserved[13];
} FRLineCfg;	/* FR_LINE_CFG_PARAM_T; */


typedef struct tagFRT1E1LineCfg
{
 unsigned char	ucLineMode;			/* line physical mode */
 unsigned char	ucClocking;			/* Tx clocking type */
 unsigned char	ucDataEncoding;	/* NRZ v.s. NRZI */
 unsigned char	ucGapCtl;			/* # of interFrame flags */
 unsigned char	ucCrcOff;			/* boolean - TRUE : CRC off */
 unsigned char	ucUseCRC32; 		/* boolean - TRUE : CRC32 */
 unsigned char	ucDataUnchanged;	/* boolean */
											/* Set Indicates Rcv DataIn Unchanged
											(No Zero deletion or Crc check) */
 /* Line interface control flags */
 unsigned char	ucLoopbackEnable;	/* Loopback mode              */
 unsigned char	ucLineBuildout;	/* Pulse shaping for PHY		*/
 unsigned char	ucLineCoding;		/* Line symbol coding			*/
 unsigned char	ucLineFraming;		/* Framing format for PHY		*/
 unsigned char	ucChannels[32];/* T1-24, E1-32 channels, 0: not selected*/
 unsigned char	ucReserved[9];	/* reserved and should be set to 0 in any											
											download.  */
} FRT1E1LineCfg;

/* Line interface control flags */
#define FR_CARD_CPE					  		0
#define FR_CARD_NET					  		1

#define FR_LOOPBACK_DISABLED				0
#define FR_LOOPBACK_LOCAL_PHY				1
#define FR_LOOPBACK_REMOTE_PHY			2

#define FR_DS1_0_TO_133_BUILDOUT		WAN_DS1_0_TO_133_BUILDOUT		/* 0 to 133 feet		*/
#define FR_DS1_133_TO_266_BUILDOUT	WAN_DS1_133_TO_266_BUILDOUT	/* 133 to 266 feet	*/
#define FR_DS1_266_TO_399_BUILDOUT	WAN_DS1_266_TO_399_BUILDOUT	/* 266 to 399 feet	*/
#define FR_DS1_399_TO_533_BUILDOUT	WAN_DS1_399_TO_533_BUILDOUT	/* 399 to 533 feet	*/
#define FR_DS1_533_TO_655_BUILDOUT	WAN_DS1_533_TO_655_BUILDOUT	/* 533 to 655 feet	*/
#define FR_DS1_N7X5_DB_BUILDOUT		WAN_DS1_N7X5_DB_BUILDOUT		/* -7.5 dB of attenuation	*/
#define FR_DS1_N15_DB_BUILDOUT		WAN_DS1_N15_DB_BUILDOUT			/* -15 dB of attenuation	*/
#define FR_DS1_N22X5_DB_BUILDOUT		WAN_DS1_N22X5_DB_BUILDOUT		/* -22.5 dB of attenuation	*/

#define FR_E1_75_OHM_NORMAL				1
#define FR_E1_75_OHM_HIRL					2
#define FR_E1_120_OHM_NORMAL				3
#define FR_E1_120_OHM_HIRL					4

#define FR_E1_BUILDOUT						WAN_E1_BUILDOUT

#define FR_DS1_AMI_ENCODING				WAN_DS1_AMI_ENCODING
#define FR_DS1_B8ZS_ENCODING				WAN_DS1_B8ZS_ENCODING
#define FR_DS1_B3ZS_ENCODING				2

#define FR_DS1_D4_LINE_FRAMING			WAN_DS1_D4_LINE_FRAMING
#define FR_DS1_ESF_LINE_FRAMING			WAN_DS1_ESF_LINE_FRAMING

#define FR_CRC4_DISABLE_LINE_FRAMING	WAN_DS1_D4_LINE_FRAMING
#define FR_CRC4_ENABLE_LINE_FRAMING		WAN_DS1_ESF_LINE_FRAMING

#define FR_E1_AMI_ENCODING					WAN_E1_AMI_ENCODING
#define FR_E1_HDB3_ENCODING				WAN_E1_HDB3_ENCODING

#define FR_E1_CRC4_ENABLE					1
#define FR_E1_CRC4_DISABLE					0

#define FR_DS3_CBIT_LINE_FRAMING			2
#define FR_DS3_M13_LINE_FRAMING			3
/*******************************************************************/
/*
 * DS1/E1 LINE STATISTICS
 */
typedef struct tagFRT1E1LineInfo
{
 unsigned short uiAlarmCurrent;
 unsigned short uiAlarmHistory;

 unsigned long	ulCodeVviolationC;
 unsigned long	ulFrameErrorC;			/* SEF errors */
 unsigned long	ulSyncErrorC;

 unsigned long	ulCodeViolationR;
 unsigned long	ulFrameErrorR;
 unsigned long	ulSyncErrorR;
 unsigned long	reserve[4];
} FRT1E1LineInfo;

/* DS1/E1 alarm flags */
#define FR_DS1_E1_LOCD_ALARM					WAN_DS1_E1_LOCD_ALARM
#define FR_DS1_E1_OOF_ALARM					WAN_DS1_E1_OOF_ALARM
#define FR_DS1_E1_LOS_ALARM					WAN_DS1_E1_LOS_ALARM
#define FR_DS1_E1_YELLOW_ALARM				WAN_DS1_E1_YELLOW_ALARM
#define FR_DS1_E1_AIS_ALARM					WAN_DS1_E1_AIS_ALARM
#define FR_DS1_E1_B8ZS_ALARM					WAN_DS1_E1_B8ZS_ALARM
#define FR_DS1_E1_EXCESS_ZEROS_ALARM		WAN_DS1_E1_EXCESS_ZEROS_ALARM
#define FR_DS1_E1_SEV_ERROR_FRAME_ALARM	WAN_DS1_E1_SEV_ERROR_FRAME_ALARM

/*********************************************************************
 * CARD PARAMETERS
*/
/*	FRCardCfg Description:

	This structure sets the transmit mode, histogram type, latency
scale and protocol frames for the card. All local IP addresses
can be set here, but IP subnet registering structure should be
used.

Note that protocol frames are restarted every time this
structure is received. Transmit traffic will continue. The new
transmit mode will become effective when test traffic is restarted.

Card configuration is stored in non-volatile memory.

********************************************************************/

/* Transmit mode */
#define FR_TX_CONTINUOUS               0 /* Continuous mode          */
#define FR_TX_SINGLE_BURST             1 /* Single burst mode        */
#define FR_TX_MULTI_BURST              4 /* Multiple burst mode      */
#define FR_TX_CONTINUOUS_MULTI_BURST   5 /* Continuous multiple mode */
#define FR_TX_ECHO                     3 /* reserved */

typedef struct tagFRCardCfg
{
 unsigned long ulMultiBurstCnt;  		/* Number of bursts to repeat */
 unsigned long ulBurstCnt;       		/* Number of frames per burst */
 unsigned long ulInterBurstGap;  		/* Number of Flags between bursts*/
 unsigned long ulTransmitMode;   		/* Transmit mode */
						/* FR_TX_CONTINUOUS  or FR_TX_SINGLE_BURST or */
						/* FR_TX_MULTI_BURST or FR_TX_CONTINUOUS_MULTI_BURST */

 unsigned char ucCardNum;        		/* card number */

 unsigned char ucGroupMember;    		/* boolean TRUE: group member */

 unsigned char ucMACAddress[6];  		/* Ethernet MAC address for card: for bridging only */
 unsigned char ucIPAddress[4];   		/* IP addr of card if IP routing */
 unsigned char ucNetmask[4];     		/* IP netmask */
 unsigned char ucDefaultGateway[4];		/* IP default gateway addr */
 unsigned char ucPingTargetAddress[4];	/* Ping target IP addr.    */

 unsigned char ucLatencyScaling; 		/* Time scale for histogram latency test */
				 /* TBD */
 unsigned char ucHistogramType;  		/* Histogram type */
				 /* HIST_OFF or HIST_SEQ_TRACK or HIST_LAT_TIME or */
				 /* HIST_LAT_STREAM or HIST_LAT_DISTRIBUTION or   */
				 /* HIST_RAW_TAGS or HIST_LONG_LAT_TIME or */
				 /* HIST_LONG_LAT_STREAM */

 /* Async/signaling frames control */
 unsigned char ucLmiOn;         		/* OBSOLETE */
 unsigned char ucSnmpFrames;    		/* 1 = send periodic SNMP frame */
 unsigned char ucProtocolFrames;		/* 1 = send periodic RIP frame */
 unsigned char ucPingFrames;    		/* 1 = send ping frame */

 /* Async frames timer config */
 unsigned char ucRipPeriod;     		/* RIP frame cycle in second  */
 unsigned char ucSnmpPeriod;    		/* SNMP frame cycle in second */
 unsigned char ucPingPeriod;    		/* PING frame cycle in second */

 unsigned char ucGeneralIPResponse; /* TRUE: reply to ALL ARP req.
													not destined to card IP or stream source IP addr */
 unsigned char ucEncapType;			/* obssolete */
 unsigned char	reserve1[3];/* reserved */
 unsigned char ucHistogramNoDE;		/* DE flag*/
 unsigned char ucFrmDistType;			/* Frame Distribution  uniform=0, back to back=1 */
 unsigned char ucIntervalTime;		/* Get Interval time. refer to structure FRIntervalTimeInfo */
 unsigned char ucHistogramPerPVC;	/* Latency over time on a per PVC basis */
 unsigned char ucReserved[11];
} FRCardCfg; 								/* FR_CARD_CFG_PARAM_T; */

/* WAN Protocol Stack/Encapsulation  structure       Message ID: FR_SET_PROTO_STACK */
typedef struct tagFRCardProtoCfgParmType
{
	unsigned char		ucProtoStack;	/* Protocol stack */
												/* FR only  (set to PROTO_FR_ONLY) */
												/* PPP Over HDLC (set to PROTO_PPP_ONLY) */
	unsigned char  	ucEncapType;	/* Protocol Encapsulation for card */
												/* FR_RFC1490_BRIDGED_SNAP or FR_RFC1490_RTD_NLPID or */
												/* FR_RFC1662_RTD_PPP */
	unsigned char 		pad[2];
	unsigned long		reserved[10];
} FRCardProtocolCfg;			 			/*  44-byte  */

/* WAN Protocol Stack */
#define UNKNOWN_STACK				0
#define PROTO_FR_ONLY				1
#define PROTO_PPP_ONLY				2

/* RFC1490 Protocol Encapsulation type */
#define FR_NO_ENCAP					0 		/* Raw payload with VFD1/2 and background fill only */
#define FR_RFC1490_BRIDGED_SNAP	1 		/* RFC1490 Ethernet bridged SNAP encapsulation */
#define FR_RFC1490_RTD_NLPID		2 		/* RFC1490 Routed format with NLPID=0xCC for IP */
#define FR_RFC1662_RTD_PPP			4		/* Routed format over PPP and HDLC only for IP */
#define FR_RFC1490_MAX_TYPE		4 		/* Maximum number of encapsulation type */
#define FR_CISCO_HDLC_RTD_IP		5
#define FR_CISCO_HDLC_RTD_UDP	   6


/* The FRLayer3LongLatencyDEInfo is created for testing with no DE future */
/* message ID: FR_HIST_V2_LATENCY_DE, FR_HIST_V2_LATENCY_INFO_DE          */
typedef struct tagFRLayer3LongLatencyDEInfo
{
 unsigned long ulMinimum;   		/* min frame latency in this interval    */
 unsigned long ulMaximum;  		/* max frame latency in this interval    */
 U64           u64Total;    		/* sum of all latencies in this interval */
 unsigned long ulFrames;    		/* frames with signatures, received in this interval */
 unsigned long ulDEMinimum;   	/* min frame latency in this interval    */
 unsigned long ulDEMaximum;   	/* max frame latency in this interval    */
 U64           u64DETotal;    	/* sum of all latencies in this interval */
 unsigned long ulDEFrames;    	/* frames with signatures, received in this interval */
} FRLayer3LongLatencyDEInfo;

/*****************************************************************************/
/*
 * TRIGGER PARAMETERS
 *
FRTriggerCfg definition:

Defines the conditions which will count as a trigger event.

The offset is specified in bytes from the start of the frame
header. Mask values determine which bits are compared
in the pattern against the frame.  If the bit in the mask is
set then the corresponding bit in the pattern is tested.  If
the bit is zero then the corresponding bit is ignored.  The
match field causes the trigger to be fired on matching
pattern. Note that there direction control does not have any
effect now. The trigger pattern is used for both incoming and
outgoing frames.

All trigger configuration changes are effective immediately.

*/

/* ucEnable values for FRTriggerCfg */
#define FR_TRIG_DISABLE     		0
#define FR_TRIG_ENABLE      		1

/* ucDirection values for FRTriggerCfg */
#define FR_TRIG_DIR_RX      		0  	/* receive only */
#define FR_TRIG_DIR_TX      		1  	/* xmit only */

/* ucCompCombo values for FRTriggerCfg */
#define FR_TRIG_NO_TRIG     		0		/* no trigger */
#define FR_TRIG_COMP1_ONLY			1		/* match only trigger 1 */
#define FR_TRIG_COMP2_ONLY  		2		/* match only trigger 2 */
#define FR_TRIG_COMP1_AND_COMP2	3  	/* match trigger 1 and trigger 2 */
#define FR_TRIG_COMP1_OR_COMP2   4  	/* match trigger 1 or trigger 2 */


typedef struct tagFRTriggerCfg
{
 unsigned char  ucEnable;    	   /* Enable/disable triggers */
 unsigned char  ucDirection; 	   /* Tx or Rx - currently used for both*/
 unsigned char  ucCompCombo; 	   /* Trigger types: one of FR_TRIG_COMP*/
 unsigned char  ucReserved1;

 unsigned short uiTrig1Offset;     /* Offset into frame for pattern test in bytes */
 unsigned short uiTrig1Range;      /* Number of bytes to match */
 unsigned char  ucTrig1Pattern[6]; /* Pattern to match */
 unsigned char  ucTrig1Mask[6];    /* Bit mask for pattern */

 unsigned short uiTrig2Offset;     /* Offset into frame for pattern test in byte */
 unsigned short uiTrig2Range;      /* Number of bytes to match */
 unsigned char  ucTrig2Pattern[6]; /* Pattern to match */
 unsigned char  ucTrig2Mask[6];    /* Bit mask for pattern */

 unsigned char  ucReserved[20];
} FRTriggerCfg; 				   /* FR_TRIG_PARAM_T; */

/******************************************************************/
/*
 * REGISTER/DE-REGISTER IP SUBNET ADDRESS.
 *
FRIPSubnetRegister and FRIPSubnetDeRegister Description:

This structure is used to register and de-register IP subnets for
the line. One or more PVC can belong to the same IP subnet. So,
up to FR_MAX_IPSUBNET_ID IP subnets can be registered for each
WAN card, with one PVC for each IP subnet. In each register
structure, one or more IP subnets can be defined, with the first short word
indicating the number of IP subnets to follow. In each de-register structure,
the number of IP subnets to de-register and the starting IP subnet ID must
be provided. The IP subnet ID ranges from 0 to FR_MAX_IPSUBNET_ID.

Example:

To register two IP subnet addresses, 192.100.1.1 and 192.100.2.1
with netmask of 255.255.255.0 and default gateway of 192.100.2.2

		byte      content
		 0         00
		 1         02
		 2         192    beginning of first IP subnet
		 3         100
		 4         001
		 5         001
		 6         255
		 7         255
		 8         255
		 9         000
		 10        192
		 11        100
		 12        002
		 13        002
		 14        192     beginning of second IP subnet
		 15        100
		 16        002
		 17        001
		 18        255
		 19        255
		 20        255
		 21        000
		 22        192
		 23        100
		 24        002
		 25        002
 */

/* uiIPSubnetId values */
#define FR_IPSUBNET_NOT_DEFINED 0xFFFF 	/*No IPSubnetId is defined for the PVC*/
#define FR_MAX_IPSUBNET_ID      (FR_NUM_PVCS -1)

typedef struct tagFRIPSubnetRegister
{
 unsigned short   uiIPSubnetId;  			/* ID starting as 0 */
 unsigned char    ucIPAddress[4];			/* Local IP addr for this subnet */
 unsigned char    ucNetmask[4];  			/* Local network mask */
 unsigned char    ucDefaultGateway[4]; 	/* Default gateway */
} FRIPSubnetRegister;

typedef struct tagFRIPSubnetDeRegister
{
 unsigned short   uiSubnetCount; 		/* No. of subnets to delete */
 unsigned short   uiIPSubnetId;  		/* Starting IP subnet ID */
} FRIPSubnetDeRegister;

/******************************************************************************
 * START/COMMIT CONFIGURATION
 *
 * Start Configuration
 * The idea of having a start and commit configuration command is to ensure
 * that all configuration data sent to the card becomes active at the same time
 * and that all internal data structures are made consistent. The only thing
 * that a start configuration does is to stop test traffic and indicate that
 * configuration is pending. If a COMMIT configuration command is not issued
 * before test traffic is started again, a COMMIT would be done before test
 * traffic is started.
 *
 * Commit Configuration
 * A COMMIT command performs all internal structure linkage between PVC, IP
 * subnet, stream configuration structures, internal test traffic frames
 * creation, rate calculations and all run-time initialization to transmit test
 * traffic. Test traffic is stopped immediately if it is running.
 */

/******************************************************************************
 * CONFIGURE A PVC
 *
FRPvcTableEntry Description:

Since the WAN firmware does not allow the deletion of a single PVC,
a new PVC configuration setup requires a FR_PVC_DELETE_ALL command
to remove all old PVCs. All test traffic is automatically stopped.
Then PVC configuration command is used to add/modify a PVC
configuration. If a PVC is modified, test traffic is immediately
stopped. However, adding a PVC does not stop test traffic. In
other words, the PVC won't be used until test traffic is started
next time after a COMMIT CONFIGURATION  command. When a PVC is
added/modified, it will appear as a new and inactive PVC when UNI
mode is DCE, as an active PVC when UNI is disabled and as a
configured PVC when UNI mode is DTE. The link status will not be
affected.

If ulDLCI exists, the PVC is overwritten with the new configuration.

 */

#define FR_MAX_PVCS					256 	/* Maximum number of PVCs allowed */
#define FR_NUM_PVCS					256  	/* Maximum number of PVCs allowed */

/* IY should be used internally to set the FR header */
#define  MAX_ENCAPHEADER_LEN     16  	/* Maximum length of user-defined FR header and content */

#define FR_STREAM_CNT_MAX        256 	/* Max. number of streams allowed */
#define FR_MAX_PROTOCOL_STREAMS  256 	/* Max. number of streams allowed */
#define FR_PVC_AGGREGATE_CNT_MAX 256 	/* OBSOLETE */


typedef struct tagFRPvcTableEntry
{
 unsigned long  ulCIR;			   	/* Committed Info. Rate in bps */
 unsigned short uiDLCI;					/* Local DLCI number: 1-1022 */
 unsigned short uiFrameSize;  		/* OBSOLETE */
 unsigned long  ulBc;         		/* reserved - Committed burst size in kbits */
 unsigned long  ulAccessRate; 		/* reserved - Physical Access Rate. NA for F/R */
 unsigned long  ulBe;         		/* reserved - Excess Burst size in kbits */
 unsigned short uiFrameRate;  		/* Frame rate per seconds */
 unsigned short uiStreamCount;		/* OBSOLETE: No. configured streams */
 unsigned short uiIPSubnetId; 		/* IP subnet ID:
												If not defined, set to FR_IPSUBNET_NOT_DEFINED
												otherwise set to 0 - FR_MAX_IPSUBNET_ID */
 unsigned char   ucReserved[12];
} FRPvcTableEntry; 						/* FR_PVC_CFG_TBL_ENT_T; */

/* Max IP subnet ID number */
/* IY - this should be moved to general stream config structure */
#define MAX_PHEADER_LEN   			64 	/* Max. length of protocol headers for stream */
/* VFD (1/2) pattern types */
#define FR_VFD_OFF               0 		/* OFF */
#define FR_VFD_RANDOM            1 		/* random */
#define FR_VFD_INCREASING        2 		/* increasing */
#define FR_VFD_DECREASING        3 		/* decreasing */
#define FR_VFD_STATIC            4 		/* static */
#define FR_MAX_VFD_PATTERNS      4 		/* Maximum VFD patterns */


/**********************************************************************
 * CONFIGURE A STREAM AND STREAM-PVC MAPPING
 *
FRPvcStrmMapCfg Description:

Since the WAN firmware does not allow the deletion of a single
stream, a new stream configuration setup requires a
FR_STREAM_DELETE_ALL command to remove all existing streams.
All test traffic is automatically stopped. Then Stream
Configuration command is used to add/modify a stream configuration.
Test traffic will continue. However, some of the stream parameters
like protocol type change will not go into effect until test
traffic is restarted again. Note that the new stream will not be
included in test traffic until test traffic is restarted.

After the usual stream configuration is done. More stream
parameters related to WAN is configured for each stream using
the FRPvcStramMapCfg structure. It is used to determine length
of global background fill to use, FCS and ABORT error insertion,
to set FECN, BECN, DE and CR bit in the Q.922 header for frame
relay, and also the RFC1490 encap type. Note also it is not
recommended to mix bridging and routing encap on the same PVC.

EITHER USE ALL BRIGDGING OR ALL ROUTING FORMAT. RAW ENCAP CAN
ALWAYS BE COMBINED WITH BRIDGEING AND ROUTING.

A streamID must exist when a mapping structure is used. Otherwise
it has no effect. A utStreamID of FR_STREAMID_NOT_DEFINED must be
used if a new stream configuration is used. However, ulSteamID MUST
be set to the proper ID.

 *********************************************************************/
#define FR_STREAMID_NOT_DEFINED 0xFFFF /*No IPSubnetId is defined for the PVC*/

typedef struct tagFRPvcStrmMapCfg
{
 unsigned long  ulStreamId;
 unsigned short uiDLCI;
 unsigned short uiVfdState;       	/* reserved */
 unsigned short uiBgFillLen;        /* number of bytes to copy to frame from background field */
 unsigned short uiMinFrameSize;		/*reserved - if Random Frame size  */
 unsigned short uiMaxFrameSize;		/*reserved - is enabled for stream */
 unsigned char  ucFcsError;  			/* 1 = cause FCS error */
 unsigned char  ucAbortFlag; 			/* 1 = gen abort flag following frame*/
 unsigned char  ucEncapType; 			/* RFC encap. type for this PVC */
 unsigned char  ucCR;  					/* 1=set CR bit on all frames in stream */
 unsigned char  ucFECN;					/* 1=set FECN bit on all frames in stream */
 unsigned char  ucBECN;					/* 1=set BECN bit for all frames in stream */
 unsigned char  ucDE;  					/* 1=set DE bit on all frames in stream */
 unsigned char  ucReserved1;
 unsigned char  ucEncapHeader[MAX_ENCAPHEADER_LEN];
										/* reserved -Starting from xfr header + RFC1490 */
 unsigned char  ucReserved[12];
} FRPvcStrmMapCfg; 						/* FR_PVC_STREAM_MAP_CFG_T; */


/*******************************************************************/
/*
 * Signaling (LMP) Parameter Configuration Table (sigParamTbl)
 */
/* Link management protocol */
#define FR_LMP_DISABLE              0
#define FR_LMP_LMI                  1
#define FR_LMP_ANNEX_D_PARM         2
#define FR_LMP_ANNEX_A_PARM         3

/* UNI Mode */
#define FR_UNI_DTE						0
#define FR_UNI_DCE						1


typedef struct tagFRLmiCfg
{
 unsigned char		ucLinkManagement; 	/* LMP protocol version */
 unsigned char		ucUNIMode;        	/* UNI mode */
 unsigned char		ucNN1;    				/* n391/nN1 : DTE Full Polling Cycle */
 unsigned char		ucNN2;    				/* NA */
 unsigned char		ucNN3;    				/* n393/nN3 : Monitor events count */
 unsigned char		ucNN4;    				/* NA */
 unsigned char		ucNT1;    				/* T391/nT1 : DTE Link Integrity Verification Timer (secs) */
 unsigned char		ucNT2;    				/* T392/nT2:  DCE Polling Verification Timer (secs) */
 unsigned char		ucNT3;    				/* NA */
} FRLmiCfg;   								/* FR_LMI_CFG_PARAMS_T; */

/******************************************************************************
 ******************************************************************************
 * INFORMATION RETRIEVAL
 *************************************************************************
 *************************************************************************/


/*********************************************************************
 * FIRMWARE VERSION
 *
FRVersionInfo Description:

This structure will return the revision information
associated with the firmware, and diagnostic and
identification information associated with the hardware.
The format of the version information for the main firmware
version is as follows:

  Bit 15: TBD - General release flag: Set: Released, Unset: Beta

  Bits 0-14: Versioning information

  Major release:  (ushort/100)%10
  Minor release:  ushort%100
  Build:          (ushort/1000)&0x1F;

*/

typedef struct tagFRVersionInfo
{
 unsigned short     uiMainFwVersion; 	/* firmware version number */
 unsigned short     uiBootFwVersion; 	/* reserved */
 unsigned short     uiFpgaVersion; 		/* reserved */
} FRVersionInfo;   							/* FR_WANS_IDENTS_T; */

/******************************************************************************
 * LED STATUS
 *
 * Status bits definitions for the 32 bit status returned to the ET1000
 *  Bits 23..20 are DTE Eia signals : bit set indicates signal logical high
 *   Bits 19..16 are DCE Eia signals : bit set indicates signal logical high
 ******************************************************************************/

/* LED Status bit mask definitions */
#define FR_ETSTAT_LINKINTEGRITY  0x00000200 	/* set: Link up */
#define FR_ETSTAT_GROUPMEMBER    0x00000400 	/* set: Group member */
#define FR_ETSTAT_TRANSMITTING   0x00000800 	/* NA */
#define FR_ETSTAT_LINEWAITING    0x00001000 	/* NA */
#define FR_ETSTAT_CARDCONFIG     0x00004000 	/* NA */
#define FR_ETSTAT_UNI_UP   		0x00008000 	/* set: UNI signaling frames exchanging */
#define FR_ETSTAT_FRAMEWAITING   0x00010000 	/* NA */

#define FR_ETSTAT_TXLED      		0x00000002  /* set : transmitting test traffic */
#define FR_ETSTAT_TRIGLED    		0x00000008 	/* set : RX triggered rate non-zero during last second */
#define FR_ETSTAT_CRCLED     		0x00000010 	/* set : RX CRC err. rate non-zero during last second */
#define FR_ETSTAT_RXLED      		0x00000020 	/* set : RX test byte rate non-zero during last second */

#define FR_NIC_EIA_RD_DSR    		0x00010000L
#define FR_NIC_EIA_RD_CTS    		0x00020000L
#define FR_NIC_EIA_RD_DCD    		0x00040000L
#define FR_NIC_EIA_RD_TM     		0x00080000L
#define FR_NIC_EIA_RD_DTR    		0x00100000L
#define FR_NIC_EIA_RD_RTS    		0x00200000L
#define FR_NIC_EIA_RD_RDL    		0x00400000L
#define FR_NIC_EIA_RD_LLB    		0x00800000L

/******************************************************************************
 * LINK CONFIG/STATUS
 *
FRLinkStatusInfo Description:

This structure is used to retrieve physical line info. such as
external clock line speed.

******************************************************************************/

typedef struct tagFRLinkStatusInfo
{
 unsigned long  ulSpeed;    		/* actual line speed in kbps for both DTE and DCE */
 unsigned long  ulReserved[19];
} FRLinkStatusInfo;  				/* FR_LINE_STATUS_T */


/****************************************************************************
 * PVC Status
 *
FRPVCStatusInfo Description:

PVC status is returned in an array of bitmap starting with PVC 0
to PVC 1022 bit  = 1 indicates ACTIVE, CONFIGURED or ENABLED.
The application can request one, two or three groups of PVC
status values in that order.

The status values are stored in three separate contiguous
bitmaps with length equal to one, two or three times
FR_PVC_STATUS_BITMAP_LEN.

Example bit map of 128 bytes for DLCI 17 active/configured/enabled

 *               BIT MAP
 *
 *               MSB           LSB
 *  byte 0       0 0 0 0 0 0 0 0
 *  byte 1       0 0 0 0 0 0 0 0
 *  byte 2       0 1 0 0 0 0 0 0      DLCI 17 active
 *   ...
 *   ...
 *  byte 127     0 0 0 0 0 0 0 0
 *
 *  byte 128     0 0 0 0 0 0 0 0
 *  byte 129     0 0 0 0 0 0 0 0
 *  byte 130     0 1 0 0 0 0 0 0      DLCI 17 configured
 *   ...
 *   ...
 *  byte 255     0 0 0 0 0 0 0 0
 *
 *  byte 256     0 0 0 0 0 0 0 0
 *  byte 257     0 0 0 0 0 0 0 0
 *  byte 258     0 1 0 0 0 0 0 0      DLCI 17 enabled
 *   ...
 *   ...
 *  byte 383     0 0 0 0 0 0 0 0

 */
#define FR_MAX_PVC_STATUS_TYPE    3   /* Max. number of PVC status types */

#define FR_PVC_RET_ACTIVE_STATUS  1   /* Get only active/inactive status */
#define FR_PVC_RET_CONF_STATUS    2   /* Get config including active status */
#define FR_PVC_RET_ADMIN_STATUS   3   /* Get enable/disable status including config and active */
#define FR_PVC_STATUS_BITMAP_LEN  128 /* Bit map len for each status group */
#define FR_MAX_STATUS_BITMAP_LEN  384 /* Bit map len for all three statuses groups */


typedef struct tagFRPVCStatusInfo
{
 unsigned char ucBitMap[FR_MAX_STATUS_BITMAP_LEN];
} FRPVCStatusInfo;


/******************************************************************************
 *
 * Per Link (CARD) Cumulative Statistics structure.
 *
FRLinkInfo Description:

Counter values reflects counts since last cleared.

Link statistics are returned as in the link statistics
structure. All ARP, INARP, PING, RIP and SNMP frames are
considered as stack frames for transmission purpose. All frames
with errors are counted in the receive byte count, but not in the
receive frame count. LMI is not counted in the link statistics.
However, all ARP, RIP, SNMP and PING are counted in link receive
statistics. So ARP and PING are counted on the link receive
statistics  and separately in their own counters. Furthermore,
DE bit, FECN and BECN are counted on top of the regular statistics.

 */
typedef struct  tagFRLinkInfo
{
 unsigned long  ulTimestamp;      		/* timestamp of last rate update*/
 unsigned long  ulRxFrameRate;    		/* Rate Rx frames */
 unsigned long  ulRxByteRate;     		/* Rate Rx bytes */
 unsigned long  ulRxFcsErrRate;   		/* Rate Rx frames with FCS error*/
 unsigned long  ulRxTriggerRate;  		/* Rate Rx Trigger Match */
 unsigned long  ulRxAbortRate;    		/* Rate Rx Abort frames */
 unsigned long  ulRxInvLenErrRate;		/* Rate Rx Invalid Length frames*/
 unsigned long  ulRxNonOctetAlignedErrRate; /* Rate of Non-octet alignment error frames */
 unsigned long  ulRxOverflowErrRate;	/* Rate Rx overflow err frames*/

 unsigned long  ulRxFrames;       		/* Count Rx frames */
 unsigned long  ulRxBytes;        		/* Count Rx bytes */
 unsigned long  ulRxFcs_err;      		/* Count Rx FCS errors */
 unsigned long  ulRxTrigger;      		/* Count Rx Trigger Match Count */
 unsigned long  ulRxAbort;        		/* Count Rx Invalid length frms */
 unsigned long  ulRxInvLenErr;    		/* Count Rx invalid length error*/
 unsigned long  ulRxNonOctetAlignedErr;	/* Count Rx non-oct alignment error frames */
 unsigned long  ulRxOverflowErr;  		/* Count Rx overflow error */

 unsigned long  ulRxIdleSeq;      		/* No. Rx Idle sequence */
 unsigned long  ulRxDeFrames;   			/* No. Rx frames with DE bit set  */
 unsigned long  ulRxBECNCount;  			/* No. Rx frames with BECN bit set*/
 unsigned long  ulRxFECNCount;  			/* No. Rx frames with FECN bit set*/
 unsigned long  ulRxInvalidPVC; 			/* No. Rx frames with unconfigured PVC  */
 unsigned long  ulRxTrigLatency;			/* First Rx Trig Match Time(100ns)*/

 unsigned long  ulRxTags;   				/* Rx frames with Netcom signature tag*/
 unsigned long  ulRxStack;  				/* Rx frames destined for local IP addr
													or source IP addr. in stream */
 unsigned long  ulRxInvARPReq;    		/* Rx Inverse ARP frame */
 unsigned long  ulRxARPReq;       		/* RX ARP request frame */
 unsigned long  ulRxARPReply;     		/* RX ARP reply frame */

 unsigned long  ulRxPingReq;				/* Rx ICMP PING command */
 unsigned long  ulRxPingReply;			/* Rx ICMP PING response */

 unsigned long  ulTxFrameRate;			/* Rate Tx frames */
 unsigned long  ulTxByteRate;				/* Rate Tx bytes */
 unsigned long  ulTxFcsErrRate;			/* Rate Tx FCS error */
 unsigned long  ulTxAbortRate;			/* Rate Tx abort error */
 unsigned long  ulTxTriggerRate;			/* Rate Tx trigger match */

 unsigned long  ulTxFrames;				/* Count Tx frames */
 unsigned long  ulTxBytes;					/* Count Tx bytes */
 unsigned long  ulTxFcsErr;				/* Count Tx FCS error */
 unsigned long  ulTxAbort;					/* Count Tx Abort */
 unsigned long  ulTxTrigger;				/* Count Tx trigger match */

 unsigned long  ulTxDeFrames;				/* Count Tx DE bit set */
 unsigned long  ulTxBECNFrames;			/* Count Tx BECN bit set */
 unsigned long  ulTxFECNFrames;			/* Count Tx FECN bit set */

 unsigned long  ulTxTrigLatency;			/* Trigger 1st Match Time(100ns)*/

 unsigned long  ulTxStack;					/* non-test frames originating from CARD for ICMP, PING, etc */
 unsigned long  ulTxInvARPReq;			/* Count Tx Inverse ARP request */
 unsigned long  ulTxARPReq;				/* Count Tx ARP request */
 unsigned long  ulTxARPReply;				/* Count Tx ARP reply */
 unsigned long  ulTxPingReq;				/* Count Tx PING (ICMP) request */
 unsigned long  ulTxPingReply;			/* Count Tx PING (ICMP) reply */

 unsigned long  ulReserved[20];
} FRLinkInfo;   /* FR_LINK_STATS_T; */


/******************************************************************************
 *
 * LMP Statistics structure.
 ******************************************************************************/
typedef struct tagFRLmiInfo
{
 unsigned long ulConfiguredPvc;  		/* No. configured PVC */
 unsigned long ulActivePvc;      		/* No. active PVC */
 unsigned long ulInactivePvc;    		/* No. disable PVC */
 unsigned long ulDisabledPvc;    		/* No. disable PVC */

 unsigned long ulTxStatusReq;    		/* No. STATUS ENQUIRY sent */
 unsigned long ulTxStatusMsg;     		/* No. STATUS MESSAGE sent */
 unsigned long ulTxFullStatusReq; 		/* No. FULL STATUS ENQUIRY sent */
 unsigned long ulTxFullStatusMsg; 		/* No. FULL STATUS MESSAGE sent */
 unsigned long ulTxStatusUpdate;  		/* reserved */

 unsigned long ulRxStatusReq;				/* No. STATUS ENQUIRY received  */
 unsigned long ulRxStatusMsg;				/* No. STATUS MESSAGE received  */
 unsigned long ulRxFullStatusReq;		/* No. FULL STATUS ENQUIRY Rcvd */
 unsigned long ulRxFullStatusMsg;		/* No. FULL STATUS MESSAGE Rcvd */
 unsigned long ulRxStatusUpdate;			/* No. STATUS UPDATE MESSAGE Rcvd*/

 unsigned long ulPvcCongestion;			/* reserved */
 unsigned long ulNewPvc;					/* No. new PVCs */
 unsigned long ulPvcDeleted;				/* No. deleted PVCs */
 unsigned long ulPvcDeactivated;			/* No. timers PVC deactivated */
 unsigned long ulMulticastIe;				/* reserved */
 unsigned long ulInvalidFrame;			/* No. invalid LMP frames Rcvd */

 unsigned long ulReserved[3];
} FRLmiInfo;   /* FR_LMI_STATS_T; */

/******************************************************************************
 * Per-PVC Statistics
 */
typedef struct tagFRPvcMainInfo
{
 unsigned short  uiPadding;
 unsigned short  uiDLCI;

 unsigned long  ulTxFrameRate;			/* Rate Tx frames */
 unsigned long  ulTxByteRate;				/* Rate Tx bytes */
 unsigned long  ulTxFrames;				/* Total Tx frames */
 unsigned long  ulTxBytes;					/* Total Tx bytes */
 unsigned long  ulTxDeFrames;				/* Tx frames with DE bit set */
 unsigned long  ulTotFECNsSent;			/* Tx frames with FECN bit set */
 unsigned long  ulTotBECNsSent;			/* Tx frames with BECN bit set */
 unsigned long  ulTxFcsErr;				/* Tx Frames with  FCS error */
 unsigned long  ulTxAbort;					/* Tx Frames set to abort */

 unsigned long  ulRxFrameRate;			/* Rate Rx frames */
 unsigned long  ulRxByteRate;				/* Rate Rx bytes */
 unsigned long  ulRxFrames;				/* Cumulative Total Rx frames */
 unsigned long  ulRxBytes;					/* Cumulative Total Rx bytes */
 unsigned long  ulRxDeFrames;				/* Rx frames with DE bit set */
 unsigned long  ulFECN;						/* Rx frames with FECN bit set */
 unsigned long  ulBECN;						/* Rx frames with BECN bit set */

 unsigned long  ulReserved[4];
} FRPvcMainInfo;    /* FR_PVC_MAIN_STATS_T; */


/******************************************************************************/
/******************************************************************************/
/* Control messages */
/******************************************************************************/
/******************************************************************************/

/******************************************************************************
 * DISABLE/ENABLE A LINK
 *
 * Set Link Status
 * Disabling a link will de-assert all EIA signals,  disable the HDLC transmit
 * and receive driver, flush all pending frames, stop all protocol frame and
 * reset LMI. Enabling a link will assert all EIA signals, enable the HDLC
 * transmit and receive driver, start protocol frames and LMI signaling.
 */

/******************************************************************************
 * STREAM CONTROL MESSAGE
 *
FRStreamControl Definition:

Allows the user to modify one or more fields on a single streams.
If is mainly used to temporarily exclude a stream from transmitting
test frames without downloading the complete configuration for the
stream.

Enabling and disabling a stream  will add or remove the stream from
transmit traffic. Also error generation can be modified by this
command.

It will be effective when on the next start command.
Disabling a stream is the better way to temporarily remove a stream
from traffic generation.

 */

typedef  struct tagFRStreamControl
{
 unsigned long   ulStreamId;  			/* stream ID */
 unsigned char   ucEnable;    			/* 1 = enable; 0 = disable */
 unsigned char   ucFcsErr;    			/* 1 = cause FCS error */
 unsigned char   ucAbortFlag; 			/* 1 = generate abort flag following frame */
 unsigned char   ucReserved;
 unsigned long   ulReserved[4];
} FRStreamControl;  							/* FR_STREAM_CTL_T; */

/******************************************************************************
 * PVC CONTROL MESSAGE
 *
FRPvcControl Definition:

Used to disable/enable a PVC. As a result, test traffic generated
can be excluded from a PVC.

Enabling and disabling a PVC will activate and deactivate a PVC
according to the above section on adding a PVC. A disabled PVC
will not become active and any transmit traffic on that PVC will
stop at the next update. (Note that traffic still goes out on
inactive PVC).

This command has no effect on an un-configured  PVC.

 */

typedef  struct tagFRPvcControl
 {
 unsigned short  uiDLCI;     			/* PVC dlci number */
 unsigned char   ucEnable;   			/* 1 = enable; 0 = disable */
 unsigned char   ucReserved[3];
 unsigned long   ulReserved[4];
 } FRPvcControl;  						/* FR_PVC_CTL_T */


/******************************************************************************/
/******************************************************************************/
/*
 * Get capture count - FR_GET_CAP_CNT_MT
 * Command structure : NONE
 * RESULT: FR_GET_CAP_CNT_RST_T
 */

typedef struct tagFRGetCaptureCountInfo
 {
 unsigned long  ulCaptureCnt;
 } FRGetCaptureCountInfo;  				/* FR_GET_CAP_CNT_RST_T; */

/*
 * Get capture - FR_GET_CAPTURE_MT
 * Command structure : FR_GET_CAPTURED_FRAME_CMD_T.
 * RESULT: n bytes of data = size of captured frame
 */

typedef struct tagFRGetCaptureFrameCmdInfo
 {
 unsigned long ulFrameNum;
 } FRGetCaptureFrameCmdInfo;   			/*FR_GET_CAPTURED_FRAME_CMD_T; */

/*
 * Release capture frame - FR_RELEASE_CAP_MT
 * Command structure : FR_REL_CAPTURED_CMD_T
 * RESULT : NONE
 */

typedef struct tagFRReleaseCaptureFrameInfo
 {
 unsigned long ulCaptureType;			/* New capture type */
 } FRReleaseCaptureFrameInfo;			/* FR_REL_CAPTURED_CMD_T; */


/******************************************************************************/
/*
 * FR_DUMP_MEM_MT - dump memory
 * Command structure : FR_DUMPMEM_CMD_T.
 * RESULT : len bytes of data.
 *
 */
typedef struct tagFRMemoryDumpInfo
 {
 unsigned long  ulAddr;
 unsigned long ulLen;
 } FRMemoryDumpInfo;   					/* FR_DUMPMEM_CMD_T; */

/******************************************************************************/
/*
 * FR_ADDRESS_MT - set board global address, ping, snmp, rip info
 * Command structure : FR_ADDRESS_CMD_T;
 * RESULT : NONE.
 */
typedef struct tagFRAssignAddress
 {
 unsigned char  ucMACAddress[6];			/*Used to communicate with the card*/
 unsigned char  ucIPAddress[4];
 unsigned char  ucNetmask[4];
 unsigned char  ucDefaultGateway[4];
 unsigned char  ucPingTargetAddress[4];
 unsigned char  ucHistogramType;
 unsigned char  ucSnmpArp;        		/* 1 = send snmp packet */
 unsigned char  ucProtocolFrames; 		/* 1 = send rip packet  */
 unsigned char  ucPingFrames;     		/* 1 = send ping packet */

 unsigned char  ucRipPeriod;      		/* in seconds */
 unsigned char  ucSnmpPeriod;     		/* in seconds */
 unsigned char  ucPingPeriod;     		/* in seconds */
 } FRAssignAddress;   						/* FR_ADDRESS_CMD_T; */


/******************************************************************************/
/*
 * Histogram Type Structure
 */

/*#define FR_MAX_HISTOGRAM_TYPES	7*/

#define HIST_OFF						0
#define HIST_SEQ_TRACK				1
#define HIST_LAT_TIME				2
#define HIST_LAT_STREAM				3
#define HIST_LAT_DISTRIBUTION		4
#define HIST_RAW_TAGS				5
#define HIST_LONG_LAT_TIME			6
#define HIST_LONG_LAT_STREAM		7

#define HIST_LAT_SORT				4
#define HIST_LAT_STREAM32			10
#define HIST_MULTICAST_LAT_STREAM	11
#define HIST_FRDE_LONG_LAT_TIME	17
#define MAX_HISTOGRAM_TYPES		17

/******************************************************************************/
/*
 * FR_SETHIST_TYPE_MT - set histogram type
 * Command structure : FR_SETHIST_TYPE_CMD_T
 * RESULT : NONE
 */
typedef struct tagFRHistogram
 {
 unsigned long   ulHistType;
 unsigned long   ulTimeBucket;
 unsigned long   ulLatRef[16];
 } FRHistogram;     					/* FR_SETHIST_TYPE_CMD_T; */

/*
 * FR_RESET_HIST_MT - reset histogram type
 * Command structure : FR_RESET_HIST_CMD_T
 * RESULT : NONE
 */
typedef struct tagFRHistReset
{
 unsigned long   ulHistType;
} FRHistReset;      					/* FR_SET_RESETHIST_CMD_T; */

typedef struct tagFRHistScale
{
 unsigned long   ulScale;
} FRHistScale;     					/* FR_SET_LATENCY_SCALE_CMD_T; */

typedef struct tagFRHistTypeInfo
{
 unsigned long  ulHistType;
 unsigned long  ulStart;
 unsigned long  ulRange;
} FRHistDataInfo;     				/* FR_GET_HISTDATA_TYPE_CMD_T; */

/*
 * FR_GET_HIST_DATA_MT - get histogram data
 * Command structure : NONE
 * RESULT : see frHist.h
 */

/* Get Transmit and receive time info structure.   */
/* Message ID: FR_INTERVALTIME_INFO,  */
typedef struct tagFRIntervalTimeInfo
{
 unsigned long  ulTxStart;
 unsigned long  ulTxStop;
 unsigned long  ulRxStart;
 unsigned long  ulRxStop;
} FRIntervalTimeInfo;


#if 0
/*
 * Seqtrack pack
 */
typedef struct tagFRSequenceTrackingInfo
{
 unsigned long  ulStreamNumber;
 unsigned long  ulRawPackets;
 unsigned long  ulInSequence;
 unsigned long  ulDuplicate;
 unsigned long  ulLost;
} FRSequenceTrackingInfo;				/* seqtrack_result; */
/* Layer3SequenceInfo */

/*
 * latstream pack
 */
typedef struct FRStreamLatencySummaryInfo
{
 unsigned long  ulStreamNumber;
 unsigned short  uiAverage;
 unsigned short  uiMin;
 unsigned short  uiMax;
 unsigned long  ulpacketCount;
} FRStreamLatencySummaryInfo;			/* latstream_result; */
/* Layer3StreamLatencyInfo */

/*
 * latstream pack
 */
typedef struct tagFRStreamLatencyInfo
{
 unsigned long  ulStreamNumber;
 U64			ullLatTotal;
 unsigned long  ulMin;
 unsigned long  ulMax;
 unsigned long  ulPacketCount;
 unsigned long  ulInSequence;
 unsigned long  ulDuplicate;
 unsigned long  ulLost;
 unsigned long  ulBuckets[16];
} FRStreamLatencyInfo;					/* llatstream_result; */
/* Layer3StreamLongLatencyInfo */

typedef struct tagFRStreamSortedLatencyInfo
{
 unsigned long  ulStreamNumber;
 unsigned long  ulPackets[16];
} FRStreamSortedLatencyInfo;			/* sortlat_result; */
/* Layer3StreamDistributionInfo */
#endif

/*--------------------------------------------------------------------------
 *------------ WAN WN3445A SmartCard Parameters and Data Structures --------
 *--------------------------------------------------------------------------
*/

#define WN_DS3_CARD_BASE						6000
/* ---------------------------------- 
 *  HTSetStructure  message ID		  
 * ---------------------------------- 
*/
#define WN_CARD_IDENT							15 /*FR_CARD_VERSION_INFO*/
#define WN_FILL_PATTERN							(WN_DS3_CARD_BASE + 2)		/* Define the fill pattern. */
#define WN_CARD_CFG								(WN_DS3_CARD_BASE + 3)		/* Sets the global parameters */
#define WN_PERIOD_CFG							(WN_DS3_CARD_BASE + 4)

/* DS3 message ID */
#define WN_DS3_LINE_CTRL						(WN_DS3_CARD_BASE + 20)		/* Enable/disable a DS3 line. */
#define WN_DS3_LINE_CFG							(WN_DS3_CARD_BASE + 21)		/* Configure DS3 line physical characteristics. */

/* Channel - message ID */
#define WN_CHANNEL_CTRL							(WN_DS3_CARD_BASE + 30)		/* Enable/disable channels. */ 
#define WN_CHANNEL_DEL							(WN_DS3_CARD_BASE + 31)		/* Delete a channel. */
#define WN_CHANNEL_DEL_ALL						(WN_DS3_CARD_BASE + 32)		/* Delete all channels. */

/* Channel - Physcial message ID */
#define WN_CHANNEL_PHYS_CFG						(WN_DS3_CARD_BASE + 40)		/* Configure channel physical characteristics. */
#define WN_CHAN_PHYS_COPY_CFG					(WN_DS3_CARD_BASE + 41)
#define WN_CHAN_PHYS_FILL_CFG					(WN_DS3_CARD_BASE + 42)
#define WN_CHAN_PHYS_MOD_CFG					(WN_DS3_CARD_BASE + 43)

/* Channel - logical message ID */
#define WN_CHANNEL_ATTRIB_CFG					(WN_DS3_CARD_BASE + 50)		/* Define channel attributes. */
#define WN_CHAN_ATTR_COPY_CFG					(WN_DS3_CARD_BASE + 51)
#define WN_CHAN_ATTR_FILL_CFG					(WN_DS3_CARD_BASE + 52)
#define WN_CHAN_ATTR_MOD_CFG					(WN_DS3_CARD_BASE + 53)

/* T1 Line message ID */
#define WN_T1E1_LINE_CTRL						(WN_DS3_CARD_BASE + 60)		/* Enable/disable a T1/E1 line. */
#define WN_T1E1_LINE_CFG						(WN_DS3_CARD_BASE + 61)		/* Configure T1/E1 line characteristics. */
#define WN_T1E1_LINE_COPY_CFG					(WN_DS3_CARD_BASE + 62)
#define WN_T1E1_LINE_FILL_CFG					(WN_DS3_CARD_BASE + 63)
#define WN_T1E1_LINE_MOD_CFG					(WN_DS3_CARD_BASE + 64)
#define WN_T1E1_LINE_DEL						(WN_DS3_CARD_BASE + 65)		/* Delete a T1 or E1 line. */
#define WN_T1E1_LINE_DEL_ALL					(WN_DS3_CARD_BASE + 66)		/* Delete all T1 or E1 lines. */

/* Stream message ID */
#define WN_STREAM_CTRL							(WN_DS3_CARD_BASE + 70)		/* Enable/disable a stream (to stop sending traffic down a stream). iType2 = Stream ID. */
#define WN_STREAM_CFG							(WN_DS3_CARD_BASE + 71)
#define WN_STREAM_COPY_CFG						(WN_DS3_CARD_BASE + 72)
#define WN_STREAM_FILL_CFG						(WN_DS3_CARD_BASE + 73)
#define WN_STREAM_MOD_CFG						(WN_DS3_CARD_BASE + 74)
#define WN_STREAM_DEL							(WN_DS3_CARD_BASE + 75)		/* Delete a stream.  iType2 = Stream ID. */
#define WN_STREAM_DEL_ALL						(WN_DS3_CARD_BASE + 76)		/* Delete all configured streams. */

/* PVC message ID */
#define WN_PVC_CTRL								(WN_DS3_CARD_BASE + 80)		/* Enable/disable a PVC. */
#define WN_PVC_CFG								(WN_DS3_CARD_BASE + 81)		/* Configure a PVC. */ 
#define WN_PVC_COPY_CFG							(WN_DS3_CARD_BASE + 82)
#define WN_PVC_FILL_CFG							(WN_DS3_CARD_BASE + 83)
#define WN_PVC_MOD_CFG							(WN_DS3_CARD_BASE + 84)
#define WN_PVC_DEL								(WN_DS3_CARD_BASE + 85)		/* Delete a PVC. */
#define WN_PVC_DEL_ALL							(WN_DS3_CARD_BASE + 86)		/* Delete all PVC configurations. */

/*  LMI message ID */
#define WN_LMI_CFG								(WN_DS3_CARD_BASE + 10)		/* LMI parameter configuration. */
#define WN_LMI_COPY_CFG							(WN_DS3_CARD_BASE + 11)
#define WN_LMI_FILL_CFG							(WN_DS3_CARD_BASE + 12)
#define WN_LMI_MOD_CFG							(WN_DS3_CARD_BASE + 13)
#define WN_LMI_DEL								(WN_DS3_CARD_BASE + 14)		/* Delete an LMI. */
#define WN_LMI_DEL_ALL							(WN_DS3_CARD_BASE + 15)		/* Delete all LMI configurations. */

/* Stream Extension */
#define WN_STREAM_EXT_CFG						(WN_DS3_CARD_BASE + 90)		/* Set up stream additional stream characteristics (stream extensions). iType2 = Stream ID. */
#define WN_STREAMEXT_COPY_CFG					(WN_DS3_CARD_BASE + 91)
#define WN_STREAMEXT_FILL_CFG					(WN_DS3_CARD_BASE + 92)
#define WN_STREAMEXT_MOD_CFG					(WN_DS3_CARD_BASE + 93)

/* Trigger message ID */
#define WN_TRIGGER_CTRL							(WN_DS3_CARD_BASE + 100)	/* Enable/disable triggers. */
#define WN_TRIGGER_CFG							(WN_DS3_CARD_BASE + 101)	/* Define trigger control bits. */
#define WN_TRIGGER_DEL							(WN_DS3_CARD_BASE + 102)	/* Delete a trigger. */
#define WN_TRIGGER_DEL_ALL						(WN_DS3_CARD_BASE + 103)	/* Delete all configured triggers. */

/* Logical IP connections message ID */
#define WN_IP_SUBNET_CFG						(WN_DS3_CARD_BASE + 110)
#define WN_IP_SUBNET_DEL						(WN_DS3_CARD_BASE + 111)
#define WN_IP_SUBNET_DEL_ALL					(WN_DS3_CARD_BASE + 112)

/* Histogram message ID */
#define WN_HIST_CHAN_CFG						(WN_DS3_CARD_BASE + 120)
#define WN_HIST_RESET_CFG						(WN_DS3_CARD_BASE + 121)
#define WN_HIST_LATENCY_SCALE					(WN_DS3_CARD_BASE + 122)
#define WN_HIST_CTRL							(WN_DS3_CARD_BASE + 123)	/* Enable/disable histograms on a T1/E1 line. */
#define WN_HIST_CTRL_ALL						(WN_DS3_CARD_BASE + 124)	/* Enable/disable histograms on all T1/E1 lines. */

/* Capture message ID */
#define WN_CAPTURE_CFG							L3_CAPTURE_SETUP
#define WN_CAPTURE_CTRL							(WN_DS3_CARD_BASE + 128)	/* Enable/disable data capture on a T1/E1 line. */
#define WN_CAPTURE_CTRL_ALL						(WN_DS3_CARD_BASE + 129)	/* Enable/disable data capture on all T1/E1 lines. */
#define WN_CAP_RELEASE_CNT						(WN_DS3_CARD_BASE + 130)

#define WN_DEFINE_SMARTBITS_STREAM				(WN_DS3_CARD_BASE + 131)	/* Define a SmartBits stream */
#define WN_DEFINE_IP_STREAM						(WN_DS3_CARD_BASE + 132)	/* Define an IP stream */
#define WN_DEFINE_UDP_STREAM  					(WN_DS3_CARD_BASE + 133)	/* Define a UDP stream */

#define WN_DEFINE_MULTI_SMARTBITS_STREAM		(WN_DS3_CARD_BASE + 135)
#define WN_DEFINE_MULTI_IP_STREAM				(WN_DS3_CARD_BASE + 136)	/* reserved */
#define WN_DEFINE_MULTI_UDP_STREAM				(WN_DS3_CARD_BASE + 137)	/* reserved */
#define WN_CHANNEL_TX_CFG						(WN_DS3_CARD_BASE + 138)	/* Transmit Configurations */
/* ---------------------------------- 
 *  HTGetStructure  message ID		  
 * ---------------------------------- 
 */
#define WN_CARD_CAPABILITY_INFO					(WN_DS3_CARD_BASE + 200)
#define WN_CARD_CFG_INFO						(WN_DS3_CARD_BASE + 201)
#define WN_PERIODIC_CFG_INFO					(WN_DS3_CARD_BASE + 202)

/* LMI message ID */
#define WN_LMI_INFO								(WN_DS3_CARD_BASE + 210)	/* Get LMI status information. */

/* DS3 message ID */
#define WN_DS3_LINE_CFG_INFO					(WN_DS3_CARD_BASE + 220)
#define WN_DS3_ALARM_COUNTER_INFO				(WN_DS3_CARD_BASE + 221)	/* Get DS3 line statistics. */
/* Change the value of WN_DS3_LINE_INFO in SmartLib 5.00-32. Between SmartLib 5.00-3 and
   SmartLib 5.00-31, this command will always return -506 error. The reason was that this command
   shares the same iType1 value with WN_DS3_ALARM_COUNTER_INFO while using different structures.
   The change made in SmartLib 5.00-3 (CR20369) cannot handle this case properly so that error -506
   is returned. Change the value of WN_DS3_LINE_INFO fixes the problem. */
//#define WN_DS3_LINE_INFO						WN_DS3_ALARM_COUNTER_INFO
#define WN_DS3_LINE_INFO						(WN_DS3_CARD_BASE + 224)
#define WN_DS3_LINE_STATUS						(WN_DS3_CARD_BASE + 222)	/* Get DS3 line status. */
#define WN_PORT_INFO							(WN_DS3_CARD_BASE + 223)	/* Get port status information. */

/* Channel - Physical */
#define WN_CHAN_CFG_INFO						(WN_DS3_CARD_BASE + 230)

/* Channel - Logical Attributes */
#define WN_CHAN_ATTRIB_CFG_INFO					(WN_DS3_CARD_BASE + 240)
#define WN_CHANNEL_INFO							(WN_DS3_CARD_BASE + 241)	/* Get T1/E1 channel characteristics. */
#define WN_CHANNEL_STATUS						(WN_DS3_CARD_BASE + 242)	/* Get channel status. */

/* T1/E1 Line */
#define WN_T1E1_LINE_CFG_INFO					(WN_DS3_CARD_BASE + 250)
#define WN_T1E1_ALARM_COUNTER_INFO				(WN_DS3_CARD_BASE + 251)	/* T1/E1 alarm counter. */
#define WN_T1E1_LINE_STATUS						(WN_DS3_CARD_BASE + 252)	/* Get T1E1 line status. */

/* Stream */
#define WN_STREAM_CFG_INFO						L3_STREAM_INFO
#define WN_STREAM_STATUS						(WN_DS3_CARD_BASE + 261)

/* PVC */
#define WN_PVC_CFG_INFO							(WN_DS3_CARD_BASE + 270)
#define WN_PVC_INFO								(WN_DS3_CARD_BASE + 271)	/* Get PVC statistics. */
#define WN_PVC_STATUS							(WN_DS3_CARD_BASE + 272)	/* Get PVC status information. */
	
/* Stream Extension parameter  */
#define WN_STREAMEXT_CFG_INFO					(WN_DS3_CARD_BASE + 280)

/* Logical IP connection */
#define WN_IP_SUBNET_CFG_INFO					(WN_DS3_CARD_BASE + 290)

/* Capture message ID */
#define WN_CAPTURE_COUNT_INFO					L3_CAPTURE_COUNT_INFO
#define WN_CAPTURE_DATA_INFO					L3_CAPTURE_PACKET_DATA_INFO
#define WN_CAPTURE_DETAIL_INFO					L3_CAPTURE_DETAIL_INFO	
/* Internal Capture Message ID */
#define WN_CAPTURE_ADD_LINE						(WN_DS3_CARD_BASE + 300)
#define WN_CAPTURE_DEL_LINE						(WN_DS3_CARD_BASE + 301)

/* Internal Histogram Message */
#define WN_HIST_ADD_LINE						(WN_DS3_CARD_BASE + 310)
#define WN_HIST_DEL_LINE						(WN_DS3_CARD_BASE + 311)

/* ---------------------------------- 
 *  HTSetCommand  message ID			  
 * ---------------------------------- 
*/
#define WN_START_CFG							(WN_DS3_CARD_BASE + 400)	/* Indicates that configuration is pending. As a result, test traffic will stop. */
#define WN_COMMIT_CFG							(WN_DS3_CARD_BASE + 401)	/* Apply the new configuration and perform all the processing necessary to make the card ready for operation. */
#define WN_CAPTURE_START						L3_CAPTURE_START
#define WN_CAPTURE_STOP							L3_CAPTURE_STOP

/* Stream Configuration Data Structure 
*----------------------------------------------------------------------------
*  Throughout the following structures all references to the ChannelId field 
*  complies to the following definition, A channel ID consists of a given    
*  given T1/E1 line number and the associated Channel number within it(1-24) 
*  The high 1 byte contains T1/E1 number, and the low 1 byte contains the    
*  associated channel number.                                                
*        15  13              8 7                0                            
*        +--------------------+-----------------+                            
*        |  |  T1/E1 Line No. |Channel No.(1-24)|                            
*        +--------------------+-----------------+                            
*                                                                            
*----------------------------------------------------------------------------
*/
#define PROTOCOL_TYPE_OFF						0	/* Raw HDLC frame		*/		
#define PROTOCOL_TYPE_8023						1	/* 802.3				*/ 
#define PROTOCOL_TYPE_IP						2	/* IP					*/
#define PROTOCOL_TYPE_IPX						3	/* IPX					*/

#define PROTOCOL_TYPE_IPUDP						4	/* IPUDP				*/
#define PROTOCOL_TYPE_ARP						5	/* probably obsolete	*/		
#define MAX_PROTOCOL_TYPES						5
#define MAX_PHEADER_LEN							64
#define MAX_ENCAPHEADER_LEN						16

#define WN_STREAM_CNT_MAX						8000

/* VFD pattern types */
#define WN_VFD_OFF								0
#define WN_VFD_RANDOM							1
#define WN_VFD_INCREASING						2
#define WN_VFD_DECREASING						3
#define WN_VFD_STATIC							4
#define MAX_VFD_PATTERNS						4

/* DS3 alarm flags  */
#define DS3_LOCD_ALARM							0x0001
#define DS3_OOF_ALARM							0x0002
#define DS3_LOS_ALARM							0x0004
#define DS3_YELLOW_ALARM						0x0008
#define DS3_AIS_ALARM							0x0010
#define DS3_B3ZS_ALARM							0x0020
#define DS3_EXCESS_ZEROS_ALARM					0x0040
#define DS3_SEV_ERROR_FRAME_ALARM				0x0400

/* WN Card Configuration */
/* WNCardCfg Description:
*/							
typedef struct tagWNCardCfg
{
	unsigned long ulSlotNo;	/* slot no of card location (ignore if >= 20) */
	unsigned long ulBoxTag;	/* used to refer to a particular chassis 
										(valid range: 1 - 15) */
	unsigned char ucReserved[88];
} WNCardCfg;

/*   << WNDS3LineCfg ucLineFraming		 */
#define WN_DS3_CBIT_LINE_FRAMING				0
#define WN_DS3_M13_LINE_FRAMING					1
/*   >> WNDS3LineCfg ucLineFraming      */

/*  << WNDS3LineCfg ucClocking          */
#define WN_CARD_CLK_INTERNAL					1
#define WN_LOOP_TIMED_CLOCK						0		/* External clock. */
/*  >> WNDS3LineCfg ucClocking          */

/*   << WNDS3LineCfg ucLineEncoding     */ 
#define WN_DS3_ENCODING_B3ZS					0
/*   >> WNDS3LineCfg ucLineEncoding     */

/*   << WNDS3LineCfg ucChannelized      */
#define WN_DS3_CHANNELIZED						0
#define WN_DS3_UNCHANNELIZED					1
/*   >> WNDS3LineCfg ucChannelized      */

/*   << WNDS3LineCfg ucLineBuildout		 */
#define WN_DS3_BUILDOUT_GT225					1		/* Greater Than 225 feet */
#define WN_DS3_BUILDOUT_LT225					0		/* Less Than 225 feet	 */
/*   >> WNDS3LineCfg ucLineBuildout		 */

/* DS3 Physical Line Configuration */
/* WNDS3LineCfg Description:
This structure sets DS3 line physical configuration.
*/							
typedef struct tagWNDS3LineCfg
{
	unsigned long  ulCount;				/* Reserved - internally set to 1.*/
	unsigned char  ucLineFraming;		/* Possible values are:
											WN_DS3_CBIT_LINE_FRAMING
											WN_DS3_M13_LINE_FRAMING */
	unsigned char  ucClocking;			/* Possible values are:
											WN_CARD_CLK_INTERNAL
											WN_LOOP_TIMED_CLOCK	*/
	unsigned char  ucLoopbackEnable;	/* 1 = enable, 0 = disable */
	unsigned char  ucLineEncoding;		/* Possible values are:
											WN_DS3_ENCODING_B3ZS */
	unsigned char  ucChannelized;		/* Possible values are:
											WN_DS3_CHANNELIZED  
											WN_DS3_UNCHANNELIZED */
	unsigned char  ucActive;			/* 1 = enable, 0 = disable */
	unsigned char  ucLineBuildout;		/* Possible values are:
								WN_DS3_BUILDOUT_LT225 (Greater than 225 feet)
								WN_DS3_BUILDOUT_GT225 (Less than 225 feet)
										*/
	unsigned char  ucReserved[9];
} WNDS3LineCfg;                    

typedef struct tagWNDS3LineCtrl
{
  unsigned long ulCount;				/* Reserved - internally set to 1. */
  unsigned char ucEnable;				/* 1 = enable, 0 = disable */
  unsigned char ucReserved[7];
} WNDS3LineCtrl;

/* WAN card T1/E1 Line Configuration Structures */

/* Tx Line clocking type */
/*  << WNT1E1LineCfg ucClocking           */
#define WN_CARD_CLK_INTERNAL					1
#define WN_LOOP_TIMED_CLOCK						0
/*  >> WNT1E1LineCfg ucClocking           */

/*  << WNT1E1LineCfg ucLoopbackEnable     */
#define WN_LOOPBACK_DISABLED					0
#define WN_LOOPBACK_LOCAL_PHY					1
#define WN_LOOPBACK_REMOTE_PHY					2
/*  >> WNT1E1LineCfg ucLoopbackEnable     */

#define WN_E1_75_OHM_NORMAL						1
#define WN_E1_75_OHM_HIRL						2
#define WN_E1_120_OHM_NORMAL					3
#define WN_E1_120_OHM_HIRL						4

#define WN_E1_AMI_ENCODING						0
#define WN_E1_HDB3_ENCODING						1

#define WN_E1_CRC4_ENABLE						1
#define WN_E1_CRC4_DISABLE						0

/*  << WNT1E1LineCfg ucLineBuildout     */
#define WN_DS1_0_TO_110_BUILDOUT				1	/* Applies to WN-3441A (T1 card) only */
#define WN_DS1_110_TO_220_BUILDOUT				2	/* Applies to WN-3441A (T1 card) only */
#define WN_DS1_220_TO_440_BUILDOUT				3	/* Applies to WN-3441A (T1 card) only */
#define WN_DS1_440_TO_660_BUILDOUT				4	/* Applies to WN-3441A (T1 card) only */
/*  >> WNT1E1LineCfg ucLineBuildout     */

/*  << WNT1E1LineCfg ucLineEncoding		*/
#define WN_DS1_AMI_ENCODING						0	/* Applies to WN-3441A (T1 card) only */
#define WN_DS1_B8ZS_ENCODING					1	/* Applies to WN-3441A (T1 card) only */
#define WN_E1_AMI_ENCODING						0	/* Applies to WN-3442A (E1 card) only */
#define WN_E1_HDB3_ENCODING						1	/* Applies to WN-3442A (E1 card) only */
/*  >> WNT1E1LineCfg ucLineEncoding		*/

/*  << WNT1E1LineCfg ucLineFraming		*/
#define WN_DS1_D4_LINE_FRAMING	 				0	/* Applies to WN-3441A and WN-3445A */
#define WN_DS1_ESF_LINE_FRAMING					1	/* Applies to WN-3441A and WN-3445A */
#define WN_E1_CRC4_DISABLE						0	/* Applies to WN-3442A (E1 card) only */
#define WN_E1_CRC4_ENABLE						1	/* Applies to WN-3442A (E1 card) only */
/*  >> WNT1E1LineCfg ucLineFraming		*/


/* Wan card T1/E1 Line configuration	*/
/* WNT1E1LineCfg Description:
*/

typedef struct tagWNT1E1LineCfg
{
	unsigned long  ulLineNo;			/* T1/E1 line number */
	unsigned long  ulCount;				/* Reserved - internally set to 1. */
	unsigned char  ucClocking;			/* T1/E1 only - Possible values are:
											WN_CARD_CLK_INTERNAL  
											WN_LOOP_TIMED_CLOCK 
										   DS3 (WN-3445A) should always be 
										   set to WN_CARD_CLK_INTERNAL */		
	unsigned char  ucLoopbackEnable;	/* Possible values are:
											WN_LOOPBACK_DISABLED
											WN_LOOPBACK_LOCAL_PHY
											WN_LOOPBACK_REMOTE_PHY */
	unsigned char  ucLineBuildout;		/* Applies to T1 cards only - 
											Possible values are:
											WN_DS1_0_TO_110_BUILDOUT
											WN_DS1_110_TO_220_BUILDOUT
											WN_DS1_220_TO_440_BUILDOUT
											WN_DS1_440_TO_660_BUILDOUT */
	unsigned char  ucLineEncoding;		/* Applies to T1/E1 cards only - 
											Possible values are:
											WN_DS1_AMI_ENCODING		(T1 card)
											WN_DS1_B8ZS_ENCODING	(T1 card)
											WN_E1_AMI_ENCODING		(E1 card)
											WN_E1_HDB3_ENCODING		(E1 card) */
	unsigned char  ucLineFraming;		/* Possible values are:
											WN_DS1_D4_LINE_FRAMING	
												(Applies to T1 and DS3 cards)
											WN_DS1_ESF_LINE_FRAMING	
												(Applies to T1 and DS3 cards)
											WN_E1_CRC4_DISABLE		
												(Applies to E1 cards only)
											WN_E1_CRC4_ENABLE		
												(Applies to E1 cards only) */
	unsigned char  ucActive;			/* 1 = enable, 0 = disable */
	unsigned char  ucReserved[6];          
} WNT1E1LineCfg;                      

/* T1/E1 Line Control message */
typedef struct tagWNT1E1LineCtrl
{
	unsigned long  ulLineNo;			/* T1/E1 line number */
	unsigned long  ulCount;				/* Reserved - internally set to 1. */
	unsigned char  ucEnable;			/* 1 = enable, 0 = disable */
	unsigned char  ucReserved[7];
} WNT1E1LineCtrl; 

/*
WNT1E1LineDel Description:
*/
typedef struct tagWNT1E1LineDel
{
 unsigned long   ulLineNo;			/* T1/E1 line number */
 unsigned long   ulCount;			/* Reserved - internally set to 1. */
} WNT1E1LineDel;

/* Channel Physical Configuration Structure */
typedef struct tagWNChannelPhysCfg         
{
 unsigned long	ulLineNo;				/* T1/E1 line number */
 unsigned long	ulChannelNo;			/* Channel No within T1/E1 line. */
 unsigned long	ulCount;				/* Reserved - internally set to 1. */
 unsigned char  ucTimeSlots[32];		/* DS0 Time slot Mask - 
										   1 = enable, 0 = disable */
 unsigned char  ucMinFlags;				/* min. # of flag separations */
 unsigned char  ucCRCOff;				/* 1 = CRC off, 0 = CRC on   */
 unsigned char  ucUseCRC32;				/* 1 = CRC32, 0 = not CRC32  */
 unsigned char  ucDataUnchanged;		/* Reserved - internally set to 0. */
 unsigned char  ucReserved[8];
} WNChannelPhysCfg;

/*  Channel Attribute Configuration Structure */

/* << WNChannelAttribCfg ucTXMode			*/
#define	WN_TX_CONTINUOUS						0
#define	WN_TX_SINGLE_BURST						1
/* >> WNChannelAttribCfg ucTXMode			*/

/* << WNChannelAttribCfg ucConnType			*/
#define	WN_CONN_FRAME_RELAY						1
#define	WN_CONN_PPP								2
/* >> WNChannelAttribCfg ucConnType			*/

/*
WNChannelAttribCfg Description:
*/
typedef struct tagWNChannelAttribCfg	/* Channel Attribute Configuration Data Type */   
{
 unsigned long	 ulLineNo;			/* T1/E1 line number */
 unsigned long	 ulChannelNo;		/* Channel No within T1/E1 line. */
 unsigned long	 ulCount;			/* Reserved - internally set to 1. */
 unsigned char   ucEnable;			/* 1 = enable channel, 
									   0 = don't enable */
 unsigned char   ucConnType;		/* Possible values are:
										WN_CONN_FRAME_RELAY
										WN_CONN_PPP */
 unsigned char   ucTXMode;			/* Transmit mode - 
										Possible values are:
										WN_TX_CONTINUOUS
										WN_TX_SINGLE_BURST */
 unsigned char   ucFCSErr;			/* 1 = cause FCS error, 
									   0 = not cause FCS error	*/
 unsigned char   ucAbortFlag;		/* 1 = generate abort flag on following 
									   frame, 0 = don't generate abort flag*/
 unsigned long   ulBurstCount;		/* Number of frames per burst */
 unsigned char   ucReserved[27];
} WNChannelAttribCfg;

typedef struct tagWNChannelCtrl
{
 unsigned long   ulLineNo;			/* T1/E1 line number */
 unsigned long	 ulChannelNo;		/* Channel No within T1/E1 line. */
 unsigned long   ulCount;			/* Reserved - internally set to 1. */
 unsigned char   ucEnable;			/* 1 = enable, 0 = disable */
 unsigned char   ucReserved[7];	
} WNChannelCtrl;

typedef struct tagWNChannelDel
{
 unsigned long   ulLineNo;			/* T1/E1 line number */
 unsigned long   ulChannelNo;		/* Channel No within T1/E1 line. */
 unsigned long   ulCount;			/* Reserved - internally set to 1. */
} WNChannelDel;

/* PVC configuration structure */
#define	WN_PVC_CNT_MAX							1024
#define	WN_PVC_AGGREGATE_CNT_MAX				16
#define	WN_PVC_FRM_LEN_DFLT						1600

/*  << WNPVCCfg ucEncapType					*/
#define WN_NO_ENCAP								0	
#define WN_RFC1490_BRIDGED_SNAP 				1
#define WN_RFC1490_RTD_NLPID					2
#define WN_RFC1490_RTD_PPP_FR					3
#define WN_RFC1662_RTD_PPP 						4
/*  >> WNPVCCfg ucEncapType					*/

#define WN_RFC1490_MAX_TYPE						4			

/* WNPVCCfg Description:

	The PVC configuration command is used to add/modify a PVC configuration. 
	If a PVC is modified, test traffic is immediately stopped. However,
	adding a PVC does not stop test traffic. In other words, the PVC won't 
	be used until test traffic is started next time after WN_COMMIT_CFG
	is called.  When a PVC is added/modified, it will appear 
	as a new and inactive PVC when UNI mode is DCE, as an active PVC 
	when UNI is disabled and as an unconfigured PVC when UNI mode is DTE. 
	The link status will not be affected.

	If ulDLCI exists, the PVC is overwritten with the new configuration.
*/

typedef struct tagWNPVCCfg
{
 unsigned long	ulDLCI;				/* Local DLCI number: 1-1022	*/
 unsigned long	ulDLCICount;		/* Reserved */
 unsigned long	ulLineNo;			/* T1/E1 line number */
 unsigned long  ulChannelNo;		/* Channel No within T1/E1 line. */
 unsigned char	ucPVCEnable;		/* 1 = enable, 0 = disable.		*/
 unsigned char	ucEncapType;		/* Reserved */
 unsigned long ulCIR;        		/* Reserved - 
										Committed Info. Rate in bps */
 unsigned long ulBC;         		/* Reserved - 
										Committed burst size in kbits */
 unsigned long ulBE;         		/* Reserved - 
										Excess Burst size in kbits */
 unsigned char	ucLocalIPAddr[4];	/* Local IP Address */
 unsigned char	ucPeerIPAddr[4];	/* Remote IP Address */
 unsigned char	ucNetMask[4];		/* IP Network mask */
 unsigned char  ucReserved[2];
} WNPVCCfg;


/* WNPVCCtrl Description:
	Used to disable/enable a PVC.

	Enabling and disabling a PVC will activate and deactivate a PVC
	according to the above section on adding a PVC. A disabled PVC
	will not become active.  Note that traffic still goes out on
	inactive PVC.
*/

typedef struct tagWNPVCCtrl
{
 unsigned long	  ulDLCI;			/* Local DLCI number */
 unsigned long	 ulDLCICount;		/* Reserved */
 unsigned long	 ulLineNo;			/* T1/E1 line number */
 unsigned long   ulChannelNo;		/* Channel No within T1/E1 line. */
 unsigned char   ucEnable;			/* 1 = enable, 0 = disable  */
 unsigned char	 ucReserved[3];
} WNPVCCtrl;

/* WNPVCDel Description :
   PVC Deletion 
*/
typedef struct tagWNPVCDel
{
 unsigned long	 ulDLCI;			/* Local DLCI number */
 unsigned long	 ulDLCICount;		/* Reserved */
 unsigned long	 ulLineNo;			/* T1/E1 line number */
 unsigned long   ulChannelNo;		/* Channel No within T1/E1 line. */
} WNPVCDel;

/* Stream Configurations structure */
typedef struct tagWNStreamCtrl
{		
 unsigned long   ulCount;			/* Reserved - internally set to 1. */ 	  
 unsigned char   ucEnable;			/* 1 = enable; 0 = disable */
 unsigned char   ucReserved[7];
} WNStreamCtrl;

typedef struct tagWNStreamDel
{
 unsigned long   ulCount;			/* Reserved - internally set to 1. */ 
 unsigned long	 ulLineNo;			/* T1/E1 line number */
 unsigned long   ulChannelNo;		/* Channel No within T1/E1 line. */
 unsigned char	 ucReserved[4];
} WNStreamDel;

/* WNStreamExtCfg Description:

RFC1490 Protocol Encapsulation
Values for ucEncapType:
  FR_NO_ENCAP			      0 	(Raw payload with VFD1/2 & background fill only) 
  FR_RFC1490_RTD_NLPID	   2 	(RFC1490 Routed format with NLPID=0xCC for IP) 
  FR_RFC1662_RTD_PPP	      4	(Routed format over PPP & HDLC only for IP)
  FR_CISCO_HDLC_RTD_IP		5
  FR_CISCO_HDLC_RTD_UDP	   6
*/
/* Stream Extension Configuration */
typedef struct tagWNStreamExtCfg
{
 unsigned long	 ulCount;		/* Number of streams */
 unsigned long   ulDLCI;		/* 0: PPP only, otherwise: DLCI No. */
 unsigned long	 ulLineNo;		/* T1/E1 line number */
 unsigned long   ulChannelNo;	/* Channel number within the T1/E1 line. */
 unsigned char   ucEncapType;	/* Protocol encapsulation for this stream 
									Possible values are:
									FR_NO_ENCAP	
									FR_RFC1490_RTD_NLPID
									FR_RFC1662_RTD_PPP
                           FR_CISCO_HDLC_RTD_IP
                           FR_CISCO_HDLC_RTD_UDP */
	/* Following 4 entries applies to PVC connection only */
 unsigned char   ucCR;	/* 0/1 pertains to frame relay header definition */ 
 unsigned char   ucFECN;		/* 0/1 pertains to frame relay header def. */
 unsigned char   ucBECN;		/* 0/1 pertains to frame relay header def. */
 unsigned char   ucDE;			/* 0/1 pertains to frame relay header def. */
 unsigned long   ulFrameRate;	/* frame rate (per second) for this stream */
 unsigned char	  ucIPManipulateMode;	/* IP manipulate mode; 
										Possible values are:
											IP_INC_SRC_IP
											IP_INC_DST_IP
											IP_DEC_SRC_IP
											IP_DEC_DST_IP */
 unsigned char	  ucStepCount;		/* IP address increment/decrement
										step count: 1,3,5,etc.*/
 unsigned short  uiIPLimitCount;	/* IP address flow mask - 
										0x00FF (increase 1 byte) 
										or 0xFFFF (increase 2 bytes) */
 unsigned char   ucReserved[23];
} WNStreamExtCfg;


/* LMI Parameter Configuration */
/*  << WNLMICfg ucLinkMgmt			*/
#define C_DISABLE							0
#define C_LMI_PARM							1
#define C_ANNEX_D_PARM						2
#define C_ANNEX_A_PARM						3
/*  >> WNLMICfg ucLinkMgmt			*/

/*  << WNLMICfg ucUNIMode					*/
#define UNI_DTE								0
#define UNI_DCE								1
/*  >> WNLMICfg ucUNIMode					*/

/* WNLMICfg Description:
*/
typedef struct tagWNLMICfg
{
 unsigned long   ulLineNo;		/* T1/E1 line number */
 unsigned long	 ulChannelNo;	/* Channel number within the T1/E1 line. */
 unsigned long   ulCount;		/* Reserved - internally set to 1. */
 unsigned char   ucLinkMgmt;	/* LMP protocol version; Possible values are:
									C_DISABLE
									C_LMI_PARM
									C_ANNEX_D_PARM
									C_ANNEX_A_PARM */
 unsigned char   ucUNIMode;		/* Possible values are:
									UNI_DTE
									UNI_DCE */
 unsigned char   ucNN1;    		/* n391/nN1 : DTE Full Polling Cycle */
 unsigned char   ucNN2;    		/* NA */
 unsigned char   ucNN3;    		/* n393/nN3 : Monitor events count */
 unsigned char   ucNN4;    		/* NA */
 unsigned char   ucNT1;    		/* T391/nT1 : DTE Link Integrity 
									Verification Timer (secs) */
 unsigned char   ucNT2;    		/* T392/nT2:  DCE Polling Verification
									Timer (secs) */
 unsigned char   ucNT3;    		/* NA */
 unsigned char   ucReserved[3];
} WNLMICfg;

typedef struct tagWNLMIDel
{
 unsigned long   ulLineNo;		/* T1/E1 line number */
 unsigned long	 ulChannelNo;	/* Channel No within T1/E1 line. */
 unsigned long   ulCount;		/* Reserved - internally set to 1. */
} WNLMIDel;

/* IP subnet Interface Configurations Structure */
typedef struct tagIPSubnetReg
{
 unsigned long   ulIPSubnetId;
 unsigned long   ulCount;
 unsigned char   ucIPAddr[4];
 unsigned char   ucNetmask[4];
 unsigned char   ucGateway[4];
} IPSubnetReg;

typedef struct tagIPSubnetDeReg
{
 unsigned long   ulIPSubnetId;
 unsigned long   ulCount;
} IPSubnetDeReg;

/* Trigger Configuration Structure */
/* Trigger control bit definitions */ 
/*  << WNTriggerCfg ucDirection			*/
#define WN_TRIG_DIR_RX						0
#define WN_TRIG_DIR_TX						1
#define WN_TRIG_ENABLE						1
/*  >> WNTriggerCfg ucDirection			*/

/*  << WNTriggerCfg ucCompCombo			*/
#define WN_TRIG_NO_TRIG						0
#define WN_TRIG_COMP1_ONLY					1
#define WN_TRIG_COMP2_ONLY					2
#define WN_TRIG_COMP1_AND_COMP2				3
#define WN_TRIG_COMP1_OR_COMP2				4
/*  >> WNTriggerCfg ucCompCombo			*/

/* WNTriggerCfg Description:
The ordering of bytes for the data comparator parameters could be 
explained by using the following examples:

This configuration example will set up a trigger for frames that have 
the byte 0xCC at an offset of 3 bytes from the beginning of the frame.  
The field ucTrig1Pattern[0] is the MSByte, and ucTrig1Pattern[5] is the LSByte.
Therefore, if uiTrig1Range field is less than 6, the pattern that is used
will be from left to right. 

   set TriggerCfg(uiTrig1Offset) 3
   set TriggerCfg(uiTrig1Range)  1 
   set TriggerCfg(ucTrig1Pattern) {0x00 0x00 0x00 0x00 0x00 0xCC} 	
   set TriggerCfg(ucTrig1Mask) {0x00 0x00 0x00 0x00 0x00 0xFF} 	

Here is another configuration example. This one is matching a 2-byte pattern, 
so uiTrig1Range should be set to 2. 
IP frames, at an offset of 2 bytes, always contain the data 0x03CC to indicate
that this is an IP header.  So this trigger will count all IP frames.  
ucTrig1Pattern[4] is set to 0x03 (the byte at offset 2), 
and ucTrig1Pattern[5] is set to 0xCC (the byte at offset 3).

   set TriggerCfg(uiTrig1Offset) 2
   set TriggerCfg(uiTrig1Range)  2 
   set TriggerCfg(ucTrig1Pattern) {0x00 0x00 0x00 0x00 0x03 0xCC} 	
   set TriggerCfg(ucTrig1Mask) {0x00 0x00 0x00 0x00 0xFF 0xFF} 	

*/
typedef struct tagWNTriggerCfg
{
 unsigned long   ulLineNo;		/* T1/E1 line number */
 unsigned long	 ulChannelNo;	/* Channel number within the T1/E1 line. */
 unsigned long   ulCount;		/* Reserved - internally set to 1. */
 unsigned char   ucEnable;    	/* Enable/disable triggers */
 unsigned char   ucDirection; 	/* Tx or Rx - currently used for both 
									Possible values are:
									WN_TRIG_DIR_RX
									WN_TRIG_DIR_TX
									WN_TRIG_ENABLE */
 unsigned char   ucCompCombo; 	/* Trigger types; Possible values are:
									WN_TRIG_NO_TRIG (no trigger) 
									WN_TRIG_COMP1_ONLY (match only trigger 1)
									WN_TRIG_COMP2_ONLY (match only trigger 2)
									WN_TRIG_COMP1_AND_COMP2 
										(match trigger 1 and trigger 2)
									WN_TRIG_COMP1_OR_COMP2 
										(match trigger 1 or trigger 2) */
 /* Data comparator parameters */ 
 unsigned short  uiTrig1Offset;		/* Offset into frame for pattern test 
									   (in bytes) */
 unsigned short  uiTrig1Range;		/* Number of bytes to match */
 unsigned char   ucTrig1Pattern[6];	/* Pattern to match */
 unsigned char   ucTrig1Mask[6];	/* Bit mask for pattern */
 unsigned short  uiTrig2Offset;		/* Offset into frame for pattern test 
									   (in bytes) */
 unsigned short  uiTrig2Range;		/* Number of bytes to match */
 unsigned char   ucTrig2Pattern[6];	/* Pattern to match */
 unsigned char   ucTrig2Mask[6];	/* Bit mask for pattern */
 unsigned char	 ucReserved;
} WNTriggerCfg; 						

typedef struct tagWNTriggerCtrl
{
 unsigned long   ulLineNo;			/* T1/E1 line number */
 unsigned long	 ulChannelNo;		/* Channel No within T1/E1 line. */
 unsigned long   ulCount;			/* Reserved - internally set to 1. */
 unsigned char   ucEnable;			/* 1 = enable; 0 = disable */
 unsigned char	 ucReserved[3];
}WNTriggerCtrl;

typedef struct tagWNTriggerDel
{		
 unsigned long   ulLineNo;			/* T1/E1 line number */
 unsigned long	 ulChannelNo;		/* Channel No within T1/E1 line. */
 unsigned long   ulCount;			/* Reserved - internally set to 1. */
}WNTriggerDel;

/* WNFeatureCtrl Description:
You may send an array of data structures if you want to enable/disable 
the feature on multiple lines.
*/
typedef struct tagWNFeatureCtrl
{
	unsigned long  ulLineNo;			/* T1/E1 line number */
	unsigned char  ucEnableFeature;  /* 1=enable feature on line; 0=disable */
	unsigned char  ucReserved[11];
} WNFeatureCtrl;

/* WNFeatureCtrlAll Description:.
*/
typedef struct tagWNFeatureCtrlAll
{
	unsigned char  ucEnableFeature;  /* 1 = enable feature; 0 = disable */
	unsigned char  ucReserved[3];
} WNFeatureCtrlAll;


/*********************************************************************************
 * Structure:   WNChannelTxCfg
 * iType1:      WN_CHANNEL_TX_CFG
 * Function:    HTSetStructure
 * Description: Configures Transmit configurations
 **********************************************************************************/
typedef struct tagWNChannelTxCfg
{
	unsigned long ulLineNo;				/* T1/E1 line number */
	unsigned long ulChannelNo;			/* Channel Number within T1/E1 line */
	unsigned long ulCount;				/* Reserved - internally set to 1 */
	unsigned char ucTXMode;				/* Transmit mode -
										Possible values are:
										WN_TX_CONTINUOUS
										WN_TX_SINGLE_BURST */
	unsigned long ulBurstCount;      /* Number of frames per burst */
 	unsigned long ulInterBurstGap;   /* Number of Flags between bursts, currently user cannot set but set by FW*/
	unsigned char ucReserved[20];
	
} WNChannelTxCfg;
/*  HTGetStructure structure */
#define WN_FEATURES_PER_CHAN_TRIGGERS		0x0001
#define WN_FEATURES_PER_PORT_TRIGGERS		0x0001
#define WN_FEATURES_PER_CHAN_BURST			0x0002
#define WN_FEATURES_PER_PORT_BURST			0x0002
#define WN_FEATURES_PER_STREAM_RATE			0x0004
#define WN_FEATURES_PER_PVC_RATE			0x0004
#define WN_FEATURES_FR						0x0004
#define WN_FEATURES_PPP						0x0004
#define WN_FEATURES_PPP_FR					0x0004
#define WN_FEATURES_PROTOCOL_TRACE			0x0008
#define WN_FEATURES_STREAM_COPY_PASTE		0x0010
#define WN_FEATURES_STATE_TRACKING			0x0020

typedef FRVersionInfo  WNVersionInfo;

typedef struct tagWNCardCapInfo
{
 unsigned short  	uiMaxPorts;
 unsigned short  	uiMaxStreams;
 unsigned short  	uiMaxConnect;
 unsigned short  	uiMaxChannels;
 unsigned short  	uiMaxPvcs;
 unsigned long   	ulMaxHostTxBuf;
 unsigned long   	ulMaxHostRxBuf;
 unsigned short  	uiSupportFeatures;
 unsigned char   	ucReserved[4];
} WNCardCapInfo;

typedef struct  tagWNPortInfo
{
 unsigned long		ulCount;			/* Reserved - internally set to 1. */
 unsigned long		ulTimestamp;      	/* Reserved */
 unsigned long		ulRxFrameRate;    	/* Rate Rx frames */
 unsigned long		ulRxByteRate;     	/* Rate Rx bytes */
 unsigned long		ulRxTriggerRate;  	/* Rate Rx Trigger Match */

 unsigned long		ulRxFrames;			/* Count Rx frames */
 unsigned long		ulRxBytes;			/* Count Rx bytes */
 unsigned long		ulRxFCSErr;			/* Count Rx FCS errors */
 unsigned long		ulRxTrigger;		/* Count Rx Trigger Match Count */
 unsigned long		ulRxAbort;			/* Count Rx Invalid length frms */
 unsigned long		ulRxOversize;		/* Oversize frames */
 unsigned long		ulRxNonOctetAlignedErr;	/* Count Rx non-oct alignment 
												error frames */
 unsigned long		ulRxOverflowErr;		/* Count Rx overflow error */

 unsigned long		ulRxUndersize;	/* Undersize frames */
 unsigned long		ulRxDEFrames;	/* No. Rx frames with DE bit set  */
 unsigned long		ulRxBECNCount;	/* No. Rx frames with BECN bit set*/
 unsigned long		ulRxFECNCount;	/* No. Rx frames with FECN bit set*/
 unsigned long		ulRxInvalidPVC;	/* No. Rx frames with unconfigured PVC */
 unsigned long		ulRxTrigLatency;	/* Reserved - 
											First Rx Trig Match Time(100ns)*/

 unsigned long		ulRxTags;   	/* Rx frames with signature field */
 unsigned long		ulRxStack;  	/* Rx frames destined for local IP addr
										or source IP addr. in stream */
 unsigned long		ulRxInvARPReq;	/* Rx Inverse ARP frame */
 unsigned long		ulRxARPReq;		/* RX ARP request frame */
 unsigned long		ulRxARPReply;	/* RX ARP reply frame */

 unsigned long		ulRxPingReq;	/* Rx ICMP PING command */
 unsigned long		ulRxPingReply;	/* Rx ICMP PING response */

 unsigned long		ulTxFrameRate;	/* Rate Tx frames */
 unsigned long		ulTxByteRate;	/* Rate Tx bytes */
 unsigned long		ulTxTriggerRate;	/* Rate Tx trigger match */

 unsigned long		ulTxFrames;		/* T1/E1 cards only - Count Tx frames */
 unsigned long		ulTxBytes;		/* T1/E1 cards only - Count Tx bytes */
 unsigned long		ulTxFCSErr;		/* T1/E1 cards only -Count Tx FCS error*/
 unsigned long		ulTxAbort;		/* T1/E1 cards only - Count Tx Abort */
 unsigned long		ulTxTrigger;	/* T1/E1 cards only - 
										Count Tx trigger match */

 unsigned long		ulTxDEFrames;	/* Reserved - Count Tx DE bit set */
 unsigned long		ulTxBECNFrames;	/* Reserved - Count Tx BECN bit set */
 unsigned long		ulTxFECNFrames;	/* Reserved - Count Tx FECN bit set */

 unsigned long		ulTxTrigLatency;	/* Reserved - 
											Trigger 1st Match Time(100ns)*/

 unsigned long		ulTxStack;		/* non-test frames originating from CARD 
										for ICMP, PING, etc */
 unsigned long		ulTxInvARPReq;	/* Count Tx Inverse ARP request */
 unsigned long		ulTxARPReq;		/* Count Tx ARP request */
 unsigned long		ulTxARPReply;	/* Count Tx ARP reply */
 unsigned long		ulTxPingReq;	/* Count Tx PING (ICMP) request */
 unsigned long		ulTxPingReply;	/* Count Tx PING (ICMP) reply */

 unsigned char		ucReserved[12];
} WNPortInfo;									

/* DS3 Alarm bit patterns */
#define	WN_DS3_FRMR_STATUS_ACE		0x80		
#define	WN_DS3_FRMR_STATUS_RED		0x40
#define	WN_DS3_FRMR_STATUS_CBIT		0x20
#define	WN_DS3_FRMR_STATUS_FERF		0x10
#define	WN_DS3_FRMR_STATUS_IDL		0x08
#define	WN_DS3_FRMR_STATUS_AIS		0x04
#define	WN_DS3_FRMR_STATUS_OOF		0x02
#define WN_DS3_FRMR_STATUS_LOS		0x01

/* WNDS3AlarmCounterInfo Description:
*/
typedef struct tagWNDS3AlarmCounterInfo
{
 unsigned long	ulCount;			/* Reserved - internally set to 1. */
 unsigned short	uiAlarmCurrent;		/* Possible values are:
										WN_DS3_FRMR_STATUS_ACE	
										WN_DS3_FRMR_STATUS_RED	
										WN_DS3_FRMR_STATUS_CBIT
										WN_DS3_FRMR_STATUS_FERF
										WN_DS3_FRMR_STATUS_IDL	
										WN_DS3_FRMR_STATUS_AIS		
										WN_DS3_FRMR_STATUS_OOF		
										WN_DS3_FRMR_STATUS_LOS */
 unsigned short	uiAlarmHistory;				/* Possible values are same as 
												for uiAlarmCurrent */
 unsigned long		ulCodeViolationCount;	/* Line Code Violation Count */
 unsigned long		ulFrameErrCount;		/* Framing Error Count */
 unsigned long		ulSyncErrCount;			/* Excessive Zeros */
 unsigned long		ulCBitParityErrCount;	/* C-bit Parity Error */
 unsigned long		ulPBitParityErrCount;	/* P-bit Parity Error */
 unsigned long		ulFEBEErrCount;			/* Far End Block Error */
 unsigned long		ulCodeViolationRate;	/* Line Code Violation Rate */
 unsigned long		ulFrameErrRate;			/* Framing Error Rate */
 unsigned long		ulSyncErrRate; 			/* Excessive Zeros Rate */
 unsigned char		ucReserved[20];
} WNDS3AlarmCounterInfo;

/******************************************************************************
Structure:	WNDS3LineInfo
iType1:		WN_DS3_LINE_INFO
Function:	HTGetStructure

WNDS3LineInfo Description:

This structure is identical to the WNDS3AlarmCounterInfo structure.  See
WNDS3AlarmCounterInfo for a more complete description.
******************************************************************************/
typedef WNDS3AlarmCounterInfo WNDS3LineInfo; 

#define LINE_UP			0		/* DS3 or T1/E1 Link States */	
#define LINE_DOWN		1
#define LINE_DISABLED	2

#define PORT_UP			LINE_UP		
#define PORT_DOWN		LINE_DOWN
#define PORT_DISABLED	LINE_DISABLED

typedef struct tagWNDS3LineStatus
{
 unsigned long		ulCount;	/* Reserved - internally set to 1. */
 unsigned char	  	ucStatus;	/* DS3 line status.  Possible values are:
									LINE_UP
									LINE_DOWN
									LINE_DISABLED */
 unsigned char   	ucReserved[3];
} WNDS3LineStatus;

/* Channel States */
#define FR_UNI_DISABLED		0
#define FR_UNI_DOWN			1
#define FR_UNI_UP			2

#define CHANNEL_DOWN		1
#define CHANNEL_UP			2
#define CHANNEL_DISABLED	3

/* LCP/NCP States */
#define LCP_UP				0
#define LCP_DOWN			1
#define LCP_AUTH			2
#define LCP_NOT_CFGD		3

#define NCP_UP				0
#define NCP_DOWN			1
#define NCP_NOT_CFGD		2

typedef struct tagWNChannelStatus
{
 unsigned long		ulLineNo;		/* Input- T1/E1 line number */	
 unsigned long		ulChannelNo;	/* Input- Channel No within T1/E1 line.*/	
 unsigned char		ucStatus;		/* Channel status.  
										Possible values are:
										CHANNEL_DOWN
										CHANNEL_UP
										CHANNEL_DISABLED */
 unsigned char		ucPPPLCPStatus;	/* PPP LCP session status. 
										Possible values are:
										LCP_UP
										LCP_DOWN
										LCP_AUTH
										LCP_NOT_CFGD */
 unsigned char		ucPPPNCPStatus;	/* PPP NCP session status. 
										Possible values are:
										NCP_UP
										NCP_DOWN
										NCP_NOT_CFGD */
 unsigned char		ucUNIStatus;	/* FR UNI status if LMI is running. 
										Possible values are:
										FR_UNI_DISABLED
										FR_UNI_DOWN
										FR_UNI_UP */
} WNChannelStatus;

typedef struct  tagWNChannelInfo 
{
 unsigned long		ulLineNo;			/* Input - T1/E1 line number */
 unsigned long		ulChannelNo;		/* Input - Channel No within T1/E1 line. */
 unsigned long		ulCount;			/* Reserved - internally set to 1. */
 unsigned long		ulTimestamp;      	/* Reserved */

 unsigned long		ulRxFrameRate;    	/* Rate Rx frames */
 unsigned long		ulRxByteRate;     	/* Rate Rx bytes */
 unsigned long		ulRxTriggerRate;  	/* Rate Rx Trigger Match */

 unsigned long		ulRxFrames;       	/* Count Rx frames */
 unsigned long		ulRxBytes;        	/* Count Rx bytes */
 unsigned long		ulRxFCSErr;      		/* Count Rx FCS errors */
 unsigned long		ulRxTrigger;      	/* Count Rx Trigger Match Count */
 unsigned long		ulRxAbort;        	/* Count Rx Invalid length frms */
 unsigned long		ulRxOversize;    	/* Oversize frames */
 unsigned long		ulRxNonOctetAlignedErr;	/* Count Rx non-oct alignment 
												error frames */
 unsigned long		ulRxOverflowErr;	/* Count Rx overflow error */

 unsigned long		ulRxUndersize;  /* Undersize frames */
 unsigned long		ulRxDEFrames;   /* No. Rx frames with DE bit set  */
 unsigned long		ulRxBECNCount;  /* No. Rx frames with BECN bit set*/
 unsigned long		ulRxFECNCount;  /* No. Rx frames with FECN bit set*/
 unsigned long		ulRxInvalidPVC; /* No. Rx frames with unconfigured PVC */
 unsigned long		ulRxTrigLatency;	/* First Rx Trig Match Time(100ns)*/

 unsigned long		ulRxTags;   	/* Rx frames with Netcom signature tag */
 unsigned long		ulRxStack;  	/* Rx frames destined for local IP addr
										or source IP addr. in stream */
 unsigned long		ulRxInvARPReq;  /* Rx Inverse ARP frame */
 unsigned long		ulRxARPReq;     /* RX ARP request frame */
 unsigned long		ulRxARPReply;   /* RX ARP reply frame */

 unsigned long		ulRxPingReq;	/* Rx ICMP PING command */
 unsigned long		ulRxPingReply;	/* Rx ICMP PING response */

 unsigned long		ulTxFrameRate;	/* Rate Tx frames */
 unsigned long		ulTxByteRate;	/* Rate Tx bytes */
 unsigned long		ulTxTriggerRate;	/* Rate Tx trigger match */

 unsigned long		ulTxFrames;		/* Count Tx frames */
 unsigned long		ulTxBytes;		/* Count Tx bytes */
 unsigned long		ulTxFCSErr;		/* Count Tx FCS error */
 unsigned long		ulTxAbort;		/* Count Tx Abort */
 unsigned long		ulTxTrigger;	/* Count Tx trigger match */

 unsigned long		ulTxDEFrames;	/* Count Tx DE bit set */
 unsigned long		ulTxBECNFrames;	/* Count Tx BECN bit set */
 unsigned long		ulTxFECNFrames;	/* Count Tx FECN bit set */

 unsigned long		ulTxTrigLatency;	/* Trigger 1st Match Time(100ns)*/

 unsigned long		ulTxStack;		/* non-test frames originating from CARD 
										for ICMP, PING, etc */
 unsigned long		ulTxInvARPReq;	/* Count Tx Inverse ARP request */
 unsigned long		ulTxARPReq;		/* Count Tx ARP request */
 unsigned long		ulTxARPReply;	/* Count Tx ARP reply */
 unsigned long		ulTxPingReq;	/* Count Tx PING (ICMP) request */
 unsigned long		ulTxPingReply;	/* Count Tx PING (ICMP) reply */

 unsigned char		ucReserved[8];
} WNChannelInfo;


/* T1/E1 alarm flags  */
#define	WN_DS1_E1_LOCD_ALARM				0x0001
#define WN_DS1_E1_OOF_ALARM					0x0002
#define WN_DS1_E1_LOS_ALARM					0x0004
#define WN_DS1_E1_YELLOW_ALARM				0x0008
#define WN_DS1_E1_AIS_ALARM					0x0010
#define WN_DS1_E1_B8ZS_ALARM				0x0020	
#define WN_DS1_E1_EXCESS_ZEROS_ALARM		0x0040
#define WN_DS1_E1_SEV_ERROR_FRAME_ALARM		0x0400


/* WNT1E1AlarmCounterInfo Description:
*/
typedef struct tagWNT1E1AlarmCounterInfo
{
 unsigned long  ulLineNo;		/* Input - T1/E1 line number */
 unsigned long  ulCount;		/* Reserved - internally set to 1. */
 unsigned short	uiAlarmCurrent;	/* Possible values are:
									WN_DS1_E1_LOCD_ALARM
									WN_DS1_E1_OOF_ALARM
									WN_DS1_E1_LOS_ALARM
									WN_DS1_E1_YELLOW_ALARM
									WN_DS1_E1_AIS_ALARM
									WN_DS1_E1_B8ZS_ALARM
									WN_DS1_E1_EXCESS_ZEROS_ALARM
									WN_DS1_E1_SEV_ERROR_FRAME_ALARM */
 unsigned short	uiAlarmHistory;	/* Possible values are same as 
									for uiAlarmCurrent */
 unsigned long		ulCodeViolationCount;	/* Line Code Violation Count */ 
 unsigned long		ulFrameErrCount;		/* Framing Error Count */
 unsigned long		ulSyncErrCount;			/* Excessive Zeros */
 unsigned long		ulFEBEErrCount;			/* E1 cards only - 
											   Far End Block Error Count */
 unsigned long		ulCodeViolationRate;	/* Line Code Violation Rate */
 unsigned long		ulFrameErrRate;			/* Framing Error Rate */
 unsigned long		ulSyncErrRate;			/* Excessive Zeros */
 unsigned long		ulFEBEErrRate;			/* E1 cards only - 
										       Far End Block Error Rate */
 unsigned char   	ucReserved[8];
} WNT1E1AlarmCounterInfo;

typedef struct tagWNT1E1LineStatus
{
 unsigned long		ulLineNo;		/* Input- T1/E1 line number */
 unsigned long		ulCount;		/* Reserved - internally set to 1. */
 unsigned char	  	ucStatus;		/* T1/E1 line status. Possible values are:
										LINE_UP
										LINE_DOWN
										LINE_DISABLED */
 unsigned char   	ucReserved[7];
} WNT1E1LineStatus;


/******************************************************************************
 * Per-PVC Statistics
 */
#define WN_PVC_RET_ACTIVE_STATUS  FR_PVC_RET_ACTIVE_STATUS /* Get only active/inactive status */
#define WN_PVC_RET_CONF_STATUS    FR_PVC_RET_CONF_STATUS   /* Get config including active status */
#define WN_PVC_RET_ADMIN_STATUS   FR_PVC_RET_ADMIN_STATUS  /* Get enable/disable status including config and active */
#define WN_PVC_STATUS_BITMAP_LEN  FR_PVC_STATUS_BITMAP_LEN /* Bit map len for each status group */

/* WNPVCStatus Description:
Value of:
WN_PVC_STATUS_BITMAP_LEN	128 (Bit map len for each status group) 
*/
typedef struct tagWNPVCStatus
{
 unsigned char		ucStatusType;	/* input; affects size of data returned.
					Possible values are:
					WN_PVC_RET_ACTIVE_STATUS 
					(Get only active/inactive status)
					WN_PVC_RET_CONF_STATUS	
					(Get active/inactive AND config status)
					WN_PVC_RET_ADMIN_STATUS 
					(Get active/inactive, config AND enable/disable status)*/
 unsigned long		ulLineNo;		/* Reserved */
 unsigned long		ulChannelNo;	/* Reserved */

 /* Ordering:	The MSB of byte 0 is for status of DLCI 0 and 
				the LSB of byte 0 is for status of DLCI 7.
				The MSB of byte 1 is for status of DLCI 8 and
				the LSB of byte 1 is for status of DLCI 15, and so on... */
 unsigned char	ucActiveStatus[WN_PVC_STATUS_BITMAP_LEN];	
							/* bitmap for active/inactive status of DLCIs */
 unsigned char	ucConfigStatus[WN_PVC_STATUS_BITMAP_LEN];	
							/* bitmap for configuration status of DLCIs */
 unsigned char	ucEnableStatus[WN_PVC_STATUS_BITMAP_LEN];	
							/* bitmap for enable/disable status of DLCIs */
} WNPVCStatus;		

typedef struct tagWNPVCInfo
{
 unsigned long 	ulDLCI;					/* Input - Local DLCI number */
 unsigned long		ulCount;			/* Reserved - internally set to 1. */
 unsigned long		ulLineNo;			/* Input - T1/E1 line number */
 unsigned long		ulChannelNo;		/* Input - Channel No within T1/E1 line. */
 unsigned long		ulTxFrameRate;		/* Rate Tx frames */
 unsigned long		ulTxByteRate;		/* Rate Tx bytes */
 unsigned long		ulTxFrames;			/* Total Tx frames */
 unsigned long		ulTxBytes;			/* Total Tx bytes */
 unsigned long		ulTxDEFrames;		/* Tx frames with DE bit set */
 unsigned long		ulTotFECNSent;		/* Tx frames with FECN bit set */
 unsigned long		ulTotBECNSent;		/* Tx frames with BECN bit set */

 unsigned long		ulRxFrameRate;		/* Rate Rx frames */
 unsigned long		ulRxByteRate;		/* Rate Rx bytes */
 unsigned long		ulRxFrames;			/* Cumulative Total Rx frames */
 unsigned long		ulRxBytes;			/* Cumulative Total Rx bytes */
 unsigned long		ulRxDEFrames;		/* Rx frames with DE bit set */
 unsigned long		ulFECNCount;		/* Rx frames with FECN bit set */
 unsigned long		ulBECNCount;		/* Rx frames with BECN bit set */
 unsigned char		ucReserved[4];
} WNPVCInfo;    

typedef struct tagWNLMIInfo
{
 unsigned long   	ulLineNo;			/* Input - T1/E1 line number */
 unsigned long   	ulChannelNo;		/* Input - Channel No within T1/E1 line. */
 unsigned long		ulCount;			/* Reserved - internally set to 1. */
 unsigned long		ulConfiguredPVC;  	/* Reserved */
 unsigned long		ulActivePVC;      	/* Reserved */
 unsigned long		ulInactivePVC;    	/* Reserved */
 unsigned long		ulDisabledPVC;    	/* Reserved */

 unsigned long		ulTxStatusReq;    	/* No. STATUS ENQUIRY sent */
 unsigned long		ulTxStatusMsg;     	/* No. STATUS MESSAGE sent */
 unsigned long		ulTxFullStatusReq; 	/* No. FULL STATUS ENQUIRY sent */
 unsigned long		ulTxFullStatusMsg; 	/* No. FULL STATUS MESSAGE sent */
 unsigned long		ulTxStatusUpdate;  	/* Reserved */

 unsigned long		ulRxStatusReq;		/* No. STATUS ENQUIRY received  */
 unsigned long		ulRxStatusMsg;		/* No. STATUS MESSAGE received  */
 unsigned long		ulRxFullStatusReq;	/* No. FULL STATUS ENQUIRY Rcvd */
 unsigned long		ulRxFullStatusMsg;	/* No. FULL STATUS MESSAGE Rcvd */
 unsigned long		ulRxStatusUpdate;	/* No. STATUS UPDATE MESSAGE Rcvd*/

 unsigned long		ulPVCCongestion;	/* Reserved */
 unsigned long		ulNewPVC;			/* No. new PVCs */
 unsigned long		ulPVCDeleted;		/* No. deleted PVCs */
 unsigned long		ulPVCDeactivated;	/* No. timers PVC deactivated */
 unsigned long		ulMulticastIe;		/* Reserved */
 unsigned long		ulInvalidFrame;		/* No. invalid LMP frames Rcvd */
 unsigned long		ucReserved[4];
} WNLMIInfo;  

/*--------------------------------------------------------------------------*/
/*------- End of WAN WN3445A SmartCard Parameters and Data Structures -------*/
/*--------------------------------------------------------------------------*/
#endif

