/*****************************************************************************
 * stmitems.h
 *
 * Data Stream Configuration definitions for Layer 3 SmartCards
 *
 * Copyright (c) 1993-2000, Spirent Communications of Calabasas, Inc.
 * Copyright (c) 1996-2000, Netcom Systems, Inc.
 ****************************************************************************/

/****************************************************************************/

#ifndef _STREAM_ITEMS_H_
#define _STREAM_ITEMS_H_

/*--------------------------------------------------------------------*/
/*------ DataStream SmartCard Parameters and Data Structures ---------*/
/*--------------------------------------------------------------------*/

/*
 *
 * Several Netcom Systems SmartCards generate more than one "Stream" 
 * definition of data.
 * These Streams distinguish themselves at the network protocol
 * level - Layer 3 of the OSI networking model and above.
 *
 * Each Stream is a series of frames generated by a frame blueprint,
 * (a Stream structure).
 * Signature fields are supported. These fields are embeded in the 
 * frame payload and contain identifying information which is unique
 * to each frame.
 * Encoded in the Signature field/tag are:
 * 	1. The slot/card number that sent the frame.
 * 	2. The specific Stream index.
 * 	3. The an incrementing sequence number on a per Stream basis.
 * 	4. The transmit timestamp.
 *	5. two CRC fields and a signature marker used to
 * 	   verify data integrity.
 *
 * When a Multi-Layer aware SmartCard receives any frame with
 * the Signature field, it will mark and record the incoming
 * timestamp value of when the frame was received at the
 * SmartBits port. It will also keep statistics on the data
 * stream. Which statistics are kept is user programmable.
 * These user programmable statistics are commonly referred
 * to as the "Histogram" functions.
 *
 * The Layer 3 and Multi-Layer SmartCards have two
 * sections:
 *
 *		1. TX - Independent Stream transmission with Signatures.
 *		2. RX - Independent frame and Stream analysis (Histograms).
 *
 *
 * 1. The independent data Stream transmission:
 *
 * Each SmartCard keeps a list of Streams which have been defined
 * on that SmartCard. Items in this file are used to setup
 * these Streams. You can define new Streams to add to the list
 * already on a SmartCard. You can modify a Stream already
 * defined in the list. To empty the list of all protocol Streams
 * you can send a define command and pass a NULL pointer to
 * the Stream data.
 *
 * Streams which are setup on each SmartCard are referenced by
 * an index number identifier. This index represents the order in
 * which the Stream appears in the SmartCard list of all defined
 * Streams. This index number is the Stream index which is
 * encoded into the tag during transmission to identify
 * each particular Stream when frames are being sent by
 * this SmartBits port.
 *
 * Included in this header file are some Stream structures,
 * and some defined constants which are used with the
 * HTSetStructure() command to define the Streams on the
 * Layer3 and Multi-Layer SmartCards.
 *
 * 2. Independent data Stream analysis.
 *
 * Also in this file are some defines which control the
 * receive section of these SmartCards.
 *
 * There are several statistical analysis methods that
 * can be programmed. These include:
 *
 *  A. Sequence tracking per stream
 *  B. Latency tracking over time.
 *  C. Latency distribution by time buckets
 *  D. Latency tracking per stream
 *  E. Latency tracking per stream, with time distribution, sequence.
 *  F. Raw tags (signature information per frame)
 *
 *
 *
 *
 */


/*----------------------- HTSetStructure ----------------------*/

/*------------ iType1 values for HTSetStructure ---------------*/

/* This set of constants will cause Layer 3 protocol streams
 * to be defined on the board to which they have been directed.
 * The receiving SmartCard will add the streams to the
 * list of streams already defined on the card
 */

/* This set refers to an array of 0, 1, or more Stream
 * structures and adds these Streams to the end of the
 * list of Streams on the SmartCard.
 */
#define NS_DEFINE_SMARTBITS_STREAM		0x1000	/* Create a single custom Stream (using a structure)*/
																/* or multiple custom Streams (using an array of structures)*/
#define NS_DEFINE_802_3_STREAM			0x1001	/* (Obsolete) Add IEEE 802.3 Tx Streams to list	*/

#define NS_DEFINE_IP_STREAM				0x1002	/* Create a single IP Stream (using a structure)*/
																/* or multiple IP Streams (using an array of structures)*/
#define NS_DEFINE_IPX_STREAM			0x1003	/* Create a single IPX Stream (using a structure)*/
																/* or multiple IPX Streams (using an array of structures)*/
#define NS_DEFINE_UDP_STREAM			0x1004	/* Create a single UDP Stream (using a structure)*/
																/* or multiple UDP Streams (using an array of structures)*/
#define NS_DEFINE_ARP_STREAM			0x1006	/* Create a single ARP Stream (based on a structure) */
																/* or multiple ARP Streams (using an array of structures)*/
#define NS_DEFINE_TCP_STREAM			0x1008	/* Create a single TCP Stream (using a structure) */
																/* or multiple TCP Streams (using an array of structures)*/
#define NS_DEFINE_IP_STREAM_VLAN		0x1009	/* Create a single IP with VLAN Stream (using a structure) */
																/* or multiple IP with VLAN Streams (using an array of structures)*/
#define NS_DEFINE_UDP_STREAM_VLAN		0x1007	/* Create a single UDP with VLAN Stream (using a structure) */
																/* or multiple UDP with VLAN Streams (using an array of structures)*/
#define NS_DEFINE_TCP_STREAM_VLAN		0x1051	/* Create a single TCP with VLAN Stream (using a structure) */
																/* or multiple TCP with VLAN Streams (using an array of structures)*/
#define NS_DEFINE_SMART_TCP_STREAM		0x1056	/* Create a single specific TCP Stream for the SmartTCP tests (using a structure)*/
																/* or multiple TCP Streams for the SmartTCP tests (using an array of structures)*/
#define NS_DEFINE_SMART_TCP_STREAM_VLAN	0x1090	/* Create a single Smart TCP with VLAN Stream (using a structure) */
																/* or multiple Smart TCP with VLAN Streams (using an array of structures)*/
#define NS_DEFINE_ICMP_STREAM			0x1059	/* Create a single ICMP Stream (using a structure) */
																/* or multiple ICMP Streams (using an array of structures)*/
#define NS_DEFINE_STREAM_EXTENSION		0x1062	/* Create a single Stream Extension (using a structure)*/
																/* or multiple Stream Extensions (using an array of structures)*/
#define NS_DEFINE_RTP_STREAM			0x1065	/* Create a single RTP Stream (using a structure) */
																/* or multiple RTP Streams (using an array of structures)*/
#define NS_DEFINE_RTP_STREAM_VLAN		0x1068	/* Create a single RTP with VLAN Stream (using a structure)*/
																/* or multiple RTP with VLAN Streams (using an array of structures)*/

#define NS_DEFINE_SMARTBITS_128_STREAM	0x1072	/* Create a single custom Stream (using StreamSmartBits128 structure)*/

#define NS_DEFINE_VFD					0x106D	/* Create a list of per-stream VFDs. */

#define NS_DEFINE_STREAM_MPLS			0x106B	/* Create a single MPLS Stream (using a structure) */
																/* or multiple MPLS Streams (using an array of structures)*/
#define NS_DEFINE_MPLS					0x1070	/* Create a single MPLS Stream with stream index */
																/* or multiple MPLS Streams (using an array of structures)*/	
#define NS_MOD_MPLS						0x1071	/* Create a single MPLS Stream with stream index */



/* This set refers to a single Stream structure which
 * is inserted into the Stream list at a given index
 * and then replicated a user specified number of times.
 */
#define NS_DEFINE_MULTI_SMARTBITS_STREAM	0x1010		/* Define multiple copies of a SmartBits Stream */
#define NS_DEFINE_MULTI_802_3_STREAM		0x1011		/* Define multiple copies of an IEEE 802.3 Stream */
#define NS_DEFINE_MULTI_IP_STREAM			0x1012		/* Define multiple copies of an IP Stream */
#define NS_DEFINE_MULTI_IPX_STREAM			0x1013		/* Define multiple copies of an IPX Stream */
#define NS_DEFINE_MULTI_UDP_STREAM			0x1014		/* Define multiple copies of a UDP Stream */
#define NS_DEFINE_MULTI_ARP_STREAM			0x1016		/* Define multiple copies of an ARP Stream */
#define NS_DEFINE_MULTI_TCP_STREAM			0x1018		/* Define multiple copies of an TCP Stream */
#define NS_DEFINE_MULTI_IP_STREAM_VLAN		0x1019		/* Define multiple copies of an IP Stream with VLAN tagging */
#define NS_DEFINE_MULTI_UDP_STREAM_VLAN 	0x1020		/* Define multiple copies of a UDP Stream with VLAN tagging */
#define NS_DEFINE_MULTI_TCP_STREAM_VLAN 	0x1052		/* Define multiple copies of a TCP Stream with VLAN tagging */
#define NS_DEFINE_MULTI_SMART_TCP_STREAM 	0x1055		/* Define multiple copies of a TCP Stream for SmartTCP tests */
#define NS_DEFINE_MULTI_ICMP_STREAM			0x1060      /* Define multiple copies of a ICMP Stream  */
#define NS_DEFINE_MULTI_STREAM_EXTENSION	0x1063      /* Define multiple copies of a Stream Extension */
#define NS_DEFINE_MULTI_RTP_STREAM			0x1066      /* Define multiple copies of a RTP Stream  */
#define NS_DEFINE_MULTI_RTP_STREAM_VLAN	0x1069      /* Define multiple copies of a RTP Stream with VLAN tagging  */
#define NS_DEFINE_MULTI_VFD					0x106E		/* Append similar copies of per-stream VFDs. */
#define NS_DEFINE_MULTI_SMARTBITS_128_STREAM	0x1073	/* Define multiple copies of a SmartBits 128 payloaded Stream */




/* This selection will duplicate a given Stream which
 * is at a selected index, and copy it to the end of
 * the Stream list a user specified number of times
 */
#define NS_DUP_STREAM         0x1021 /* Duplicate an existing Stream at the end of the Stream list */ /* not 67xx SmartCards */

/* This set refers to a single Stream structure which
 * is inserted into the Stream list at a given index.
 */
#define NS_MOD_UDP_STREAM_VLAN 			0x1028		/* put one UDP Stream with VLAN in the list at a given index */
#define NS_MOD_IP_STREAM_VLAN 			0x1029		/* put one IP Stream with VLAN in the list at a given index */
#define NS_MOD_SMARTBITS_STREAM			0x1030		/* put one SmartBits Stream in the list at a given index */
#define NS_MOD_SMARTBITS_128_STREAM		0x1039		/* put one SmartBits Stream in the list at a given index */
#define NS_MOD_802_3_STREAM				0x1031		/* put one IEEE 802.3 Stream in the list at a given index */
#define NS_MOD_IP_STREAM					0x1032		/* put one IP Stream in the list at a given index */
#define NS_MOD_IPX_STREAM					0x1033		/* put one IPX Stream in the list at a given index */
#define NS_MOD_UDP_STREAM					0x1034		/* put one UDP Stream in the list at a given index */
#define NS_MOD_ARP_STREAM					0x1036		/* put one ARP Stream in the list at a given index */
#define NS_MOD_TCP_STREAM					0x1038		/* put one TCP Stream in the list at a given index */
#define NS_MOD_TCP_STREAM_VLAN			0x1053		/* put one TCP Stream with VLAN in the list at a given index */
#define NS_MOD_SMART_TCP_STREAM			0x1054		/* put one TCP Stream for SmartTCP tests in the list at a given index */
#define NS_MOD_SMART_TCP_STREAM_VLAN	0x1077		/* put one TCP Stream for SmartTCP tests in the list at a given index */
#define NS_MOD_ICMP_STREAM					0x1061      /* put one ICMP Stream in the list at a given index */
#define NS_MOD_STREAM_EXTENSION			0x1064      /* put one Stream Extension in the list at a given index */
#define NS_MOD_RTP_STREAM					0x1067      /* put one RTP Stream in the list at a given index */
#define NS_MOD_RTP_STREAM_VLAN			0x106A      /* put one RTP Stream with VLAN in the list at a given index */

#define NS_MOD_SMARTBITS_STREAMS			0x1080
#define NS_MOD_802_3_STREAMS				0x1081
#define NS_MOD_IP_STREAMS					0x1082
#define NS_MOD_IPX_STREAMS					0x1083
#define NS_MOD_UDP_STREAMS					0x1084
#define NS_MOD_TCP_STREAMS					0x1085
#define NS_MOD_SMART_TCP_STREAMS			0x1086
#define NS_MOD_ICMP_STREAMS				0x1087
#define NS_MOD_RTP_STREAMS					0x1088
#define NS_MOD_UDPDHCP_STREAMS			0x1089
#define NS_MOD_IP_STREAMS_VLAN			0x108A
#define NS_MOD_UDP_STREAMS_VLAN			0x108B
#define NS_MOD_TCP_STREAMS_VLAN			0x108C
#define NS_MOD_RTP_STREAMS_VLAN			0x108D

#define NS_MOD_VFD							0x106F		/* Overwrite one per-stream VFD in the list at a given index. */


#define NS_MOD_STREAMS_DELTA				0x1040		/* modify a Stream field in a block of Streams by a delta value */
#define NS_MOD_STREAMS_ARRAY				0x1050		/* modify a Stream field in a block of Streams by overlaying an array of values */


// ***********************************************************
// IPV6 stream constants will use ids from 0x10A0 to 0x10BF //

// IPv6 streams
#define NS_DEFINE_IPV6_STREAM				0x10A0
#define NS_DEFINE_TCP_IPV6_STREAM			0x10A1
#define NS_DEFINE_UDP_IPV6_STREAM			0x10A2
#define NS_DEFINE_MULTI_IPV6_STREAM			0x10A3
#define NS_DEFINE_MULTI_TCP_IPV6_STREAM		0x10A4
#define NS_DEFINE_MULTI_UDP_IPV6_STREAM		0x10A5
#define NS_MOD_IPV6_STREAM					0x10A6
#define NS_MOD_TCP_IPV6_STREAM				0x10A7
#define NS_MOD_UDP_IPV6_STREAM				0x10A8
// Reserved: 0x10A9, 0x10AA, 0x10AB, 0x10AC, 0x10AD, 0x10AE, 0x10AF

// IPv6 streams with VLAN
#define NS_DEFINE_IPV6_STREAM_VLAN				0x10B0
#define NS_DEFINE_TCP_IPV6_STREAM_VLAN			0x10B1
#define NS_DEFINE_UDP_IPV6_STREAM_VLAN			0x10B2
#define NS_DEFINE_MULTI_IPV6_STREAM_VLAN		0x10B3
#define NS_DEFINE_MULTI_TCP_IPV6_STREAM_VLAN	0x10B4
#define NS_DEFINE_MULTI_UDP_IPV6_STREAM_VLAN	0x10B5
#define NS_MOD_IPV6_STREAM_VLAN					0x10B6
#define NS_MOD_TCP_IPV6_STREAM_VLAN				0x10B7
#define NS_MOD_UDP_IPV6_STREAM_VLAN				0x10B8
// Reserved: 0x10B9, 0x10BA, 0x10BB, 0x10BC, 0x10BD, 0x10BE, 0x10BF

// ***********************************************************

//ICMP VLAN streams
#define NS_DEFINE_ICMP_STREAM_VLAN           0x10C0
#define NS_DEFINE_MULTI_ICMP_STREAM_VLAN     0x10C1
#define NS_MOD_ICMP_STREAM_VLAN              0x10C2

//ICMP IPV6 streams
#define NS_DEFINE_ICMP_IPV6_STREAM              0x10C3
#define NS_DEFINE_MULTI_ICMP_IPV6_STREAM        0x10C4
#define NS_MOD_ICMP_IPV6_STREAM                 0x10C5
#define NS_DEFINE_ICMP_IPV6_STREAM_VLAN         0x10C6
#define NS_DEFINE_MULTI_ICMP_IPV6_STREAM_VLAN   0x10C7
#define NS_MOD_ICMP_IPV6_STREAM_VLAN            0x10C8


#define NS_VOICE_TEST_SETUP				0x106C      /* configure the voice test */

#define NS_TX_ADDRESS						0x1701		/* set SmartCard device address information */
#define NS_TX_IPV6_ADDRESS					0x1702		/* set SmartCard device address information */
#define NS_TX_IPV6_PROTOCOL				0x1703		/* set SmartCard device address information */
#define NS_DEFINE_STREAM_BINDING			0x1706     /* Bind PPP instances and/or VC index to streams */
#define NS_MOD_STREAM_BINDING				0x1707     /* Modify stream binding to PPP and/or VC's */
#define NS_STREAM_BINDING_INFO			0x1708     /* Readback stream binding configuration */
#define NS_DEFINE_MULTI_STREAM_BINDING	0x1709     /* Bind PPP instances and/or VC index to streams */
/*----------------------- HTGetStructure ----------------------*/
/*----------- iType1 ---------------*/
#define NS_STREAM_COUNT_INFO				0x1500		/* retrieve the count of Streams in the list */

#define NS_SMARTBITS_STREAM_INFO			0x1508		/* Retrieve one SmartBits Stream */
#define NS_802_3_STREAM_INFO				0x1511		/* Retrieve one IEEE 802.3 Stream */
#define NS_IP_STREAM_INFO					0x1512		/* Retrieve one IP Stream */
#define NS_IPX_STREAM_INFO					0x1513		/* Retrieve one IPX Stream */
#define NS_UDP_STREAM_INFO					0x1514		/* Retrieve one UDP Stream */
#define NS_ARP_STREAM_INFO					0x1516		/* Retrieve one ARP Stream */
#define NS_TCP_STREAM_INFO					0x1518		/* Retrieve one TCPP Stream */
#define NS_RTP_COUNTER_INFO				0x1519		/* Retrieve one TCPP Stream */

#define NS_V2_STREAM_INFO					0x1550		/* for internal use only */
#define NS_VFD_INFO							0x1551		/* for internal use only */


#define NS_TX_ADDRESS_INFO					0x1700		/* retrieve SmartCard device address information */
#define NS_TX_IPV6_ADDRESS_INFO				0x1704		/* set SmartCard device address information */
#define NS_ARP_TIMES_INFO					0x1800		/* Retrieve ARP Times for each Stream in the list */

#define NS_STREAM_EXTENSION_INFO			0x0720		/* read back the L3StreamExtension structure */


/*----------------------- HTSetCommand ----------------------*/
/*----------- iType1 ---------------*/
#define NS_DELETE_STREAM					0x1801		/* Delete one stream */
#define NS_SET_STREAM_STATE				0x1802		/* Disable Stream=0 Enable Stream=1 Note that this indexes from 1 as the first stream on the card, unlike other commands that index from 0*/
#define NS_ARP_UNRESOLVED					0x1803		/* ReArp streams that did not already get ARP'd */
#define NS_ARP_ONE_STREAM					0x1804		/* Send an ARP from the specified stream */
#define NS_SET_START_STREAM				0x1805		/* Start transmitting from this stream */
#define NS_SET_ARP_GAP						0x1806		/* Sets ARP Gap on all streams */
#define NS_ENABLE_TAGS_ALL_STREAMS		0x1807		/* Enable tag fields on all streams */
#define NS_DISABLE_TAGS_ALL_STREAMS		0x1808		/* Disable tag fields on all streams */
#define NS_ENABLE_TAG						0x1809		/* Enable tag fields on a stream */
#define NS_DISABLE_TAG						0x180A		/* Disable tag fields on a stream */

#define NS_HIST_ACTIVE_TEST_INFO			0x3000		/* Reports the number of histogram records, and active histogram */
#define NS_HIST_LATENCY_PRECISION_INFO	0x3001		/* Get Latency precision histogram results */
#define NS_HIST_SEQUENCE_INFO				0x3002		/* Get Sequence Tracking histogram results */
#define NS_HIST_LATENCY_INFO				0x3003		/* Get 16-bit Latency over Time histogram results */
#define NS_HIST_LATENCY_PER_STREAM_INFO		0x3004		/* Get 16-bit Latency per Stream histogram results */
#define NS_HIST_V1_LATENCY_PER_STREAM_INFO	0x3010		/* Get 32-bit Latency per Stream histogram results */
#define NS_HIST_LATENCY_DISTRIBUTION_INFO		0x3005		/* Get Full Latency Distribution histogram results */
#define NS_HIST_RAW_TAGS_INFO				0x3006		/* Get Raw Tags histogram records */
#define NS_HIST_V2_LATENCY_INFO			0x3007		/* Get Latency over Time histogram results */
#define NS_HIST_V2_LATENCY_PER_STREAM_INFO	0x3008		/* Get Latency Distribution and Per Stream histogram results */
#define NS_HIST_MC_LATENCY_PER_STREAM_INFO	0x3009      /* MulticastIP Latency Dist hist with 1st and last Rx timestamp */
#define NS_HIST_JITTER_COMBO_INFO		0x300A		/* Get the results of a 32-bit latency histogram test */
#define NS_HIST_TCP_CONNECTION_INFO		0x300B

#define NS_HIST_V3_LATENCY_DISTRIBUTION_INFO	0x300C
#define NS_HIST_V3_LATENCY_INFO					0x300D
#define NS_HIST_V3_LATENCY_PER_STREAM_INFO	0x300E
#define NS_HIST_V3_SEQUENCE_INFO					0x300F

#define NS_HIST_ACTIVE_TEST_EXPRESS_INFO	0x3050
#define NS_HIST_SEQUENCE_EXPRESS_INFO		0x3052

/* #define NS_HIST_REPORT					0x3009*/	/* */
#define NS_HIST_SUMMARY_INFO					0x3100		/* Get summary results of active test */
#define NS_AGGREGATE_INFO  					NS_HIST_SUMMARY_INFO		/* Get aggregate results of active test */
#define NS_AGGR_LATENCY_PRECISION_INFO		0x3101		/* Get aggregate Latency precision results */
#define NS_AGGR_SEQUENCE_INFO					0x3102		/* Get aggregate Sequence Tracking results */
#define NS_AGGR_LATENCY_INFO					0x3103		/* Get aggregate 16-bit Latency over Time results */
#define NS_AGGR_LATENCY_PER_STREAM_INFO	0x3104		/* Get aggregate 16-bit Latency per Stream results */
#define NS_AGGR_LATENCY_DISTRIBUTION_INFO	0x3105		/* Get aggregate Full Latency Distribution results */
#define NS_AGGR_RAW_TAGS_INFO					0x3106		/* Get aggregate Raw Tags information */
#define NS_AGGR_V2_LATENCY_INFO				0x3107		/* Get aggregate Latency over Time histogram results */
#define NS_AGGR_V2_LATENCY_PER_STREAM_INFO  0x3108		/* Get aggregate Latency Distribution and Per Stream histogram results */
#define NS_AGGR_MC_LATENCY_PER_STREAM_INFO  0x3109		/* Get aggregate Latency Distribution and Per Stream histogram results */

#define NS_CAPTURE_PACKET_INFO				0x2001		/* Get information about the captured frames */
#define NS_CAPTURE_PACKET_DATA_INFO			0x2002		/* Get the captured frame */
#define NS_CAPTURE_DETAIL_INFO				0x2003		/* Get details of the packet */
#define NS_CAPTURE_STATS_INFO					0x2004      /* Get statistics about one or more captured frames */
#define NS_CAPTURE_DATA_INFO					0x2005      /* Get a captured frame  */


#define NS_CAPTURE_OFF_TYPE					0x2010		/* Turn Capture off */
#define NS_CAPTURE_ALL_TYPE					0x2011		/* Capture all frames received */
#define NS_CAPTURE_BAD_TYPE					0x2012		/* Capture errors frames only */
#define NS_CAPTURE_SPECIAL_TYPE				0x2013		/* */
#define NS_CAPTURE_TRIGGERS_TYPE				0x2014		/* Capture Trigger frames only */


#define NS_HIST_START							0x3200		/* Start Histogram statistics gathering */
#define NS_HIST_SEQUENCE						0x3201		/* Set to collect Sequence tracking statistics */
#define NS_HIST_LATENCY							0x3202		/* Set to collect 16-bit Latency over time histogram */
#define NS_HIST_LATENCY_PER_STREAM			0x3203		/* Set to collect 16-bit Latency per Stream histogram */
#define NS_HIST_V1_LATENCY_PER_STREAM		0x3211		/* Set to collect 32-bit Latency per Stream histogram */
#define NS_HIST_LATENCY_DISTRIBUTION		0x3204		/* Set to collect 16-bit Latency Distribution histogram */
#define NS_HIST_RAW_TAGS						0x3205		/* Set to collect raw tag data */
#define NS_HIST_V2_LATENCY						0x3206		/* Set to collect Latency over time histogram  */
#define NS_HIST_V2_LATENCY_PER_STREAM		0x3207		/* Set to collect Latency Distribution histogram */
#define NS_HIST_LATENCY_PRECISION			0x3208		/* Set to collect Sequence tracking statistics */
#define NS_HIST_MULTICAST_LATENCY			0x3209      /* MulticastIP Latency Dist hist with 1st and last Rx timestamp */
#define NS_MULTICAST_COUNTER_INFO			0x3210      /* Multicast Counters*/
#define NS_HIST_V2_LATENCY_DISTRIBUTION	0x3212      /* Set to collect 32-bit Latency Distribution histogram */
#define NS_HIST_JITTER_COMBO					0x3213      /* Set to collect 32-bit Latency histogram test */
#define NS_HIST_TCP_CONNECTION				0x3214      /* Set to collect 32-bit Latency histogram test */
#define NS_HIST_ACTIVE_TEST_PREP				0x3250
#define NS_HIST_SEQUENCE_PREP					0x3251

#define NS_START_ARPS						0x4000		/* Begin ARP exchange on all defined Streams */

#define NS_USB_MODE_ON						0x8000
#define NS_USB_MODE_OFF						0x8001
#define NS_USB_GET_USB_INFO				0x8002
#define NS_USB_SET_POWER					0x8003

#define NS_RNDIS_MODE_ON					0x8500
#define NS_ETHERNET_MODE_ON				0x8501



#define NS_GROUP_DELETE_GROUP				0x7100
#define NS_GROUP_SET_GROUP					0x7101

#define NS_STREAM_GROUP_DEFINE				0x7102		/* Add a stream group. */
#define NS_STREAM_GROUP_DELETE				0x7103		/* Remove a stream group. */

#define NS_STREAM_TRANSMIT_MODE				0x7104		/* Set the transmission mode. */
#define NS_STREAM_TRANSMIT_MODE_INFO		0x7105		/* Get the transmit mode. */

#define NS_DHCP_GET_ADDRESS					0x8700		/* Start DHCP exchange for one or more streams */
#define NS_DHCP_GET_ADDRESS_ALL				0x8701		/* Start DHCP exchange for all streams */
#define NS_DHCP_RELEASE_ADDRESS				0x8702		/* Perform DHCP release for one or more streams */
#define NS_DHCP_RELEASE_ADDRESS_ALL			0x8703		/* Perform DHCP release for all streams */
#define NS_DHCP_STATS_INFO						0x8704		/* Get DHCP stats from a particular card */
#define NS_DHCP_HOST_INFO        			0x8705		/* Get DHCP host info from a card */
#define NS_DHCP_EXTENDED_HOST_INFO   		0x8706		/* Get DHCP host extended info from a card */
#define NS_DHCP_ACTION							0x8707		/* Set DHCP action */
#define NS_DHCP_STATE							0x8708		/* Set DHCP state */
#define NS_DHCP_STREAM_COUNT_INFO			0x8709		/* Get the number of active DHCP-capable streams */
#define NS_DHCP_CONFIG							0x870A		/* Set DHCP Configuration*/

#define NS_STOP_ARPS						      0x870B		/* Stop ARP exchange on all defined Streams */
#define NS_START_NEIGHBOR_DISCOVERY			0x870C		 /* Begin neighbor discovery exchange on all defined IPv6 Streams */
#define NS_STOP_NEIGHBOR_DISCOVERY			0x870D		 /* Begin neighbor discovery exchange on all defined IPv6 Streams */
#define NS_DHCP_CONFIG_INFO					0x870E		/* Retrieve the DHCP Configuration. */
#define NS_DHCP_RENEW      					0x870F		/* Transmit a DHCP renew/request message for one or more streams. */
#define NS_DHCP_PORT_COUNTER_INFO			0x8710		/* Retrieve DHCP summary information for a port */
#define NS_DHCP_PORT_SESSION_INFO			0x8711		/* Retrieves DHCP port session counters information for a port. */

#define NS_DHCP_RESTART							0x8712		/* Re-initiates the DHCP process for one or more DHCP capable active streams that are not in DHCP Bound State */
#define NS_DHCP_RESTART_ALL					0x8713		/* Re-initiates the DHCP process for all DHCP capable active streams that are not in DHCP Bound State */
#define NS_DHCP_V2_HOST_INFO					0x8714		/* Get DHCP host information from a specified port */
#define NS_DHCP_V2_EXTENDED_HOST_INFO		0x8715		/* Get extended DHCP host information from a specified card */	

/*
 * The Stream Structures
 *
 * There are transmit parameters which are common to
 * all Streams defined on the SmartCard, and others
 * which are defined on a per stream basis.
 *
 * Those parameters on each SmartCard which are common
 * to all the streams includes the interframe gap, the
 * transmission mode (continuous, burst, etc.), error
 * generation, collision backoff aggressiveness, background
 * data pattern, etc.
 *
 * Those which vary on a per stream basis are defined
 * using the Stream Structures below. The main variation
 * in the Stream structures is in the specific
 * protocol information following the ucTagField item.
 *
 * Netcom Systems SmartCards these Streams have a common block
 * of information which defines general characteristics of
 * each defined Stream. These can be seen in the first 19
 * members of the various Stream structures below.
 * With those common elements, each stream can
 *  -- Be activated or Disabled
 *  -- Set its protocol type
 *  -- define its own length
 *  -- over-ride the background pattern with random data
 *
 *
 * VFD's are not supported on the ML-7710 SmartCards,
 * with the exception of VFD3 in SmartBits Stream.
 * This implementation of VFD3 is on a per-stream basis.
 *
 * Each of the specific protocol stream definition structures
 * has specific fields following the 19 common elements
 * which define the appropriate elements necessary
 * for that particular protocol.
 *
 *
 */


 /*-------- Stream protocol types  ---------*/
 /* these are the Protocol fields to be used in the
  * ucProtocol field of the Stream structures below
  */
#define STREAM_PROTOCOL_SMARTBITS	0		/* a user defined Stream type */
#define STREAM_PROTOCOL_8023			1		/* an IEEE 802.3 Stream type */
#define STREAM_PROTOCOL_IP				2		/* an IP Stream type */
#define STREAM_PROTOCOL_IPX			3		/* an IPX Stream type */
#define STREAM_PROTOCOL_UDP			4		/* a UDP Stream type */
#define STREAM_PROTOCOL_ARP			5		/* an ARP Stream type */
#define STREAM_PROTOCOL_IP_VLAN		6		/* an IP Stream with VLAN type */
#define STREAM_PROTOCOL_UDP_VLAN		7		/* a UDP Stream with VLAN type */
#define STREAM_PROTOCOL_SMART_TCP	8		/* a TCP Stream unique to running the SmartTCP tests */
#define STREAM_PROTOCOL_ICMP			9		/* a ICMP Stream */
#define STREAM_PROTOCOL_TCP_VLAN		10		/* a TCP Stream type with VLAN */
#define STREAM_PROTOCOL_TCP			11		/* a TCP Stream type */
#define STREAM_PROTOCOL_PPP			12		/* a PPP Stream type */
#define STREAM_PROTOCOL_RTP			13		/* a RTP Stream type */
#define STREAM_PROTOCOL_RTP_VLAN		14		/* a RTP Stream with VLAN type */
#define STREAM_PROTOCOL_FC				15		/* a Fibre Channel stream works with FC cards only */

#define STREAM_PROTOCOL_IPV6			16		/* an IPV6 Stream type */
#define STREAM_PROTOCOL_UDP_IPV6		17		/* a UDP/IPV6 Stream type */
#define STREAM_PROTOCOL_TCP_IPV6		18		/* a TCP/IPV6 Stream type */
#define STREAM_PROTOCOL_IPV6_VLAN		19		/* an IPV6 Stream with VLAN type */
#define STREAM_PROTOCOL_UDP_IPV6_VLAN	20		/* a UDP/IPV6 Stream with VLAN type */
#define STREAM_PROTOCOL_TCP_IPV6_VLAN	21		/* a TCP/IPV6 Stream type with VLAN */
#define STREAM_PROTOCOL_SMART_TCP_VLAN  22      /* for TCP VALN websuite 2.0*/

#define STREAM_PROTOCOL_IP_PPPOA       23    /* a PPPoA IP Stream type (Reserved) */
#define STREAM_PROTOCOL_UDP_PPPOA      24    /* a PPPoA UDP Stream type (Reserved) */
#define STREAM_PROTOCOL_TCP_PPPOA      25    /* a PPPoA TCP Stream type (Reserved) */
#define STREAM_PROTOCOL_IP_PPPOAOE     26    /* a PPPoAoE IP Stream type (Reserved) */
#define STREAM_PROTOCOL_UDP_PPPOAOE    27    /* a PPPoAoE UDP Stream type (Reserved) */
#define STREAM_PROTOCOL_TCP_PPPOAOE    28    /* a PPPoAoE TCP Stream type (Reserved) */

#define STREAM_PROTOCOL_ICMP_VLAN		   29		/* a IPv4 VLAN ICMP Stream */
#define STREAM_PROTOCOL_ICMP_IPV6		   30		/* a IPv6 ICMP Stream */
#define STREAM_PROTOCOL_ICMP_IPV6_VLAN	   31		/* a IPv6 VLAN ICMP Stream */
#define STREAM_PROTOCOL_LLC_BRIDGED 	   32		/* Stream type for ATM LLC_BRIDGED encap VC */
#define STREAM_PROTOCOL_BRIDGED 	   33		/* Stream type for ATM LLC_BRIDGED/VCMUX_BRIDGED encap VC */

/*
StreamSmartBits Description:

This structure contains values for customized streams.

The Background Fill Pattern and the ProtocolHeader[] can be used 
in combination to construct highly customized frames.

Use HTFillPattern to specify the background pattern. Then define
the ProtocolHeader array. This array (of up-to 64 bytes) is used as VFD3.
It overwrites the background pattern at the specified offset and range. 
(ucVFD3Enable must be set to HVFD_ENABLED).

A signature field, used for Histogram results,
is inserted at the end of the payload if ucTagField is enabled
(set to 1).

NOTE:

For the LAN-3710AL, LAN-3710AS and LAN-3710AE modules, the maximum number of
streams that can be created using L3_DEFINE_SMARTBITS_STREAM is 7.  An inactive default
stream will be the first stream created.  
*/
typedef struct tagStreamSmartBits
{
   unsigned char   ucActive;				/* 1=Enable Stream, 0=Disable Stream*/
   unsigned char   ucProtocolType;		/* use STREAM_PROTOCOL_SMARTBITS */

   unsigned char   ucRandomLength;     /* 1 = Enable random frame length, 
                                          0 = use uiFrameLength.  
                                          Available on the LAN and POS TeraMetrics modules.
                                          Need to set the minimum and 
                                          maximum random lengths using 
                                          NS_PORT_TRANSMIT when enabled. */
   unsigned char   ucRandomData;	/* 1 = Random Data, 0 = use the */
											/* cards background pattern     */
											/* not available on             */
											/* ATM Terametrics modules      */

   unsigned short  uiFrameLength;		/* frame length not counting CRC*/
													/* 0 - 2048 for Ethernet        */
													/* 0 - 8196 for Frame Relay     */
													/* 1 - 32767 for ATM            */


   /*****************************************************************
	*                                                                *
	*  For ETHERNET, cards VFD1 and VFD2 structure members are       *
	*  reserved for later use. Set to 0.                             *
	*****************************************************************/


	/** VFD1 and VFD2 structure members are reserved for later use. Set to 0. **/
	unsigned short  uiVFD1Offset;			/* in bits                      */
	unsigned char   ucVFD1Range;			/* in bits                      */
	unsigned char   ucVFD1Pattern;			/* HVFD_ENABLED, HVFD_STATIC,   */
											/* HVFD_INCR, HVFD_DECR,        */
											/* HVFD_RANDOM, HVFD_NONE       */
	unsigned long   ulVFD1PatternCount;		/* from 0(off) to 16,777,215	*/
											/* number to incr. or decr.     */
											/* through when using inc or    */
											/* dec pattern                  */
	unsigned char   ucVFD1StartVal[6];		/*the initial VFD byte pattern	*/

	unsigned short  uiVFD2Offset;			/* in bits                      */
	unsigned char   ucVFD2Range;			/* in bits                      */
	unsigned char   ucVFD2Pattern;			/* HVFD_ENABLED, HVFD_STATIC,   */
											/* HVFD_INCR, HVFD_DECR,*/
											/* HVFD_RANDOM, HVFD_NONE       */
	unsigned long   ulVFD2PatternCount;		/* from 0(off) to 16,777,215	*/
											/* number to incr. or decr.     */
											/* through when using inc or    */
											/* dec pattern                  */
	unsigned char   ucVFD2StartVal[6];		/*the initial VFD byte pattern	*/
	/*****************************************************************/


	unsigned short  uiVFD3Offset;			/* in bytes(not applicable for
                                               the TeraMetrics family of cards) */

	unsigned short  uiVFD3Range;			/* in bytes; Number of elements */
											/* to use from ProtocolHeader   */
											/* No elements are used beyond  */
											/* the single specified range.  */

	unsigned char   ucVFD3Enable;			/* HVFD_ENABLED, HVFD_NONE(not applicable for
                                               the TeraMetrics family of cards) */

	unsigned char   ucTagField;				/* 0 = off, 1 = insert Signature*/
											/* field into each frame        */

	unsigned char   ProtocolHeader[64];		/* Defines up to 64 bytes used as VFD3*/
											
} StreamSmartBits;

/* StreamSmartBits Comment:
IMPORTANT: See the "SmartLib Basics" chapter in the
SmartLib Overview and Procedures manual.
*/


/*
StreamSmartBits128 Description:

This structure contains values for customized streams.

The Background Fill Pattern and the ProtocolHeader[] can be used 
in combination to construct highly customized frames.

Use HTFillPattern to specify the background pattern. Then define
the ProtocolHeader array. This array (of up-to 128 bytes) is used as VFD3.

A signature field, used for Histogram results,
is inserted at the end of the payload if ucTagField is enabled
(set to 1).

IMPORTANT: Before defining streams with this command, you must use NS_PORT_TRANSMIT(NSPortTransmit)
to set the ucEnableExtendedPayload field to 1. This enables the 128-byte header length to
accommodate the longer stream header. When you do this, the maximum number of streams that can be
defined is reduced to half: from 512 to 256 (this applies to all TeraMetrics modules except the
POS-3518/3519A). In addition, any time you switch between enabling and disabling the extended
payload, all currently configured streams will be deleted. 

NOTE:

  For the LAN-3710AL, LAN-3710AS and LAN-3710AE modules, the maximum number of
streams that can be created using L3_DEFINE_SMARTBITS_128_STREAM is 7.  An inactive default
stream will be the first stream created.  
*/
typedef struct tagStreamSmartBits128
{
	unsigned char   ucActive;			/* 1=Enable Stream, 0=Disable Stream*/
	unsigned char   ucProtocolType;		/* use STREAM_PROTOCOL_SMARTBITS */
	unsigned char   ucRandomLength;     /* 1 = Enable random frame length, 
                                          0 = use uiFrameLength.  
                                          Available on the LAN and POS TeraMetrics modules.
                                          Need to set the minimum and 
                                          maximum random lengths using 
                                          NS_PORT_TRANSMIT when enabled. */
	unsigned char   ucRandomData;	/* 1 = Random Data, 0 = use the */
											/* cards background pattern     */
											/* not available on             */
											/* ATM Terametrics modules      */

	unsigned short  uiFrameLength;		/* frame length not counting CRC*/
											/* 0 - 2048 for Ethernet        */
											/* 0 - 8196 for Frame Relay     */
											/* 1 - 32767 for ATM            */


	/*****************************************************************
	*                                                                *
	*  For ETHERNET, cards VFD1 and VFD2 structure members are       *
	*  reserved for later use. Set to 0.                             *
	*****************************************************************/


	/** VFD1 and VFD2 structure members are reserved for later use. Set to 0. **/
	unsigned short  uiVFD1Offset;			/* in bits                      */
	unsigned char   ucVFD1Range;			/* in bits                      */
	unsigned char   ucVFD1Pattern;			/* HVFD_ENABLED, HVFD_STATIC,   */
											/* HVFD_INCR, HVFD_DECR,        */
											/* HVFD_RANDOM, HVFD_NONE       */
	unsigned long   ulVFD1PatternCount;		/* from 0(off) to 16,777,215	*/
											/* number to incr. or decr.     */
											/* through when using inc or    */
											/* dec pattern                  */
	unsigned char   ucVFD1StartVal[6];		/*the initial VFD byte pattern	*/

	unsigned short  uiVFD2Offset;			/* in bits                      */
	unsigned char   ucVFD2Range;			/* in bits                      */
	unsigned char   ucVFD2Pattern;			/* HVFD_ENABLED, HVFD_STATIC,   */
											/* HVFD_INCR, HVFD_DECR,*/
											/* HVFD_RANDOM, HVFD_NONE       */
	unsigned long   ulVFD2PatternCount;		/* from 0(off) to 16,777,215	*/
											/* number to incr. or decr.     */
											/* through when using inc or    */
											/* dec pattern                  */
	unsigned char   ucVFD2StartVal[6];		/*the initial VFD byte pattern	*/
	/*****************************************************************/
	unsigned short  uiVFD3Offset;			/* Reserved                     */
	unsigned short  uiVFD3Range;			/* in bytes; Number of elements */
											/* to use from ProtocolHeader   */
											/* No elements are used beyond  */
											/* the single specified range.  */
	unsigned char   ucVFD3Enable;			/* Reserved				        */
	unsigned char   ucTagField;				/* 0 = off, 1 = insert Signature*/
											/* field into each frame        */
	unsigned char   ProtocolHeader[128];	/* Defines up to 128 bytes used as VFD3*/
} StreamSmartBits128;


/*
Stream8023 Description:

This structure contains values for the IEEE 802.3 
protocol Stream type.

This structure is identical to the StreamSmartBits.

The bytes from the ProtocolHeader[64] field will
be used as the first 64 bytes of each frame.

If the ucTagField is enabled ( set to 1), then the
Netcom Systems signature tag field will be inserted
into each frame at the latter end of the payload.

*/
typedef struct tagStream8023
{
	unsigned char   ucActive;				/* 1 = Enabled, 0 = Disabled		*/
	unsigned char   ucProtocolType;			/* use STREAM_PROTOCOL_xxx			*/
												/* defines above					*/
	unsigned char   ucRandomLength;			/* Reserved							*/
	unsigned char   ucRandomData;				/* 1 = Random Data, 0 = use the		*/
														/* cards background pattern			*/
	unsigned short  uiFrameLength;			/* frame length from 0 to 2048		*/
														/* not counting CRC					*/
	unsigned short  uiVFD1Offset;				/* in bits							*/
	unsigned char   ucVFD1Range;				/* in bits							*/
	unsigned char   ucVFD1Pattern;			/* HVFD_ENABLED, HVFD_STATIC,		*/
														/* HVFD_INCR, HVFD_DECR,			*/
														/* HVFD_RANDOM, HVFD_NONE			*/
	unsigned long   ulVFD1PatternCount;		/* from 0(=off) to 16,777,215.		*/
														/* number to incr. or decr.			*/
														/* through when using inc or		*/
														/* dec pattern						*/
	unsigned char   ucVFD1StartVal[6];		/* the initial VFD byte pattern		*/

	unsigned short  uiVFD2Offset;				/* in bits							*/
	unsigned char   ucVFD2Range;				/* in bits							*/
	unsigned char   ucVFD2Pattern;			/* HVFD_ENABLED, HVFD_STATIC,		*/
														/* HVFD_INCR, HVFD_DECR,			*/
														/* HVFD_RANDOM, HVFD_NONE			*/
	unsigned long   ulVFD2PatternCount;		/* from 0(=off) to 16,777,215.		*/
														/* number to incr. or decr.			*/
														/* through when using inc or		*/
														/* dec pattern						*/
	unsigned char   ucVFD2StartVal[6];		/* the initial VFD byte pattern		*/

	unsigned short  uiVFD3Offset;				/* in bits							*/
	unsigned short  uiVFD3Range;				/* in bytes							*/
	unsigned char   ucVFD3Enable;				/* HVFD_ENABLED, VFD_NONE			*/

	unsigned char   ucTagField;				/* 0 = off, 1 = insert signature	*/
														/* field into each frame			*/
	unsigned char   ProtocolHeader[64];		/* Defines the first 64 bytes		*/
														/* of each frame in the Stream		*/
} Stream8023;

/*
StreamIP Description:

This structure contains values for IP compliant Streams.

The IP checksum is automatically calculated using
the supplied header fields and inserted into the IP header.

For ATM Terametrics modules, IP checksum has to be in the first cell
(within the first 48 bytes) because of card limitation.

A Netcom Systems Signature field, used for Histogram results, is
inserted at the end of the payload if ucTagField is enabled 
(set to 1).

NOTE:  The Signature field is 18 bytes long, and laid into the frame
just before the CRC. Use caution when defining the frame length
so that the Signature does not overwrite important data.
 
For the LAN-3710AL, LAN-3710AS and LAN-3710AE modules, the maximum number of
streams that can be created using L3_DEFINE_IP_STREAM is 7.  An inactive default
stream will be the first stream created.  

For ATM Terametrics modules set ucProtocolType as STREAM_PROTOCOL_IP
when the bound VC is not of BRIDGED encapsulation while set it as
STREAM_PROTOCOL_BRIDGED when the bound VC is of BRIDGED encapsulation

*/
typedef struct tagStreamIP
{
	unsigned char   ucActive;				/* 1=Enable Stream, 0=Disable Stream*/
	unsigned char   ucProtocolType;		/* use STREAM_PROTOCOL_IP, or
                                               STREAM_PROTOCOL_BRIDGED (ATM only)
                                          */
	unsigned char   ucRandomLength;     /* 1 = Enable random frame length, 
                                          0 = use uiFrameLength.  
                                          Available on the LAN and POS TeraMetrics modules.
                                          Need to set the minimum and 
                                          maximum random lengths using 
                                          NS_PORT_TRANSMIT when enabled. */

	unsigned char   ucRandomData;			/* 1 = Random Data, 0 = use the		*/
													/* cards background pattern			*/
													/* not available on Frame Relay		*/
													/* and ATM Terametrics modules 		*/
	unsigned short  uiFrameLength;		/* frame length not counting CRC		*/
													/* 0 - 2048 for Ethernet				*/
													/* 0 - 8196 for Frame Relay			*/



	/*****************************************************************
	*                                                                *
	*  For ETHERNET, cards VFD1, VFD2, and VFD3 structure members    *
	* are reserved for later use. Set to 0.                          *
	*****************************************************************/

	unsigned short  uiVFD1Offset;			/* in bits							*/
	unsigned char   ucVFD1Range;			/* in bits							*/
	unsigned char   ucVFD1Pattern;		/* HVFD_ENABLED, HVFD_STATIC,	*/
													/* HVFD_INCR, HVFD_DECR,      */
													/* HVFD_RANDOM, HVFD_NONE     */
	unsigned long   ulVFD1PatternCount;	/* from 0(off) to 16,777,215	*/
													/* number to incr. or decr.   */
													/* through when using inc or  */
													/* dec pattern                */
	unsigned char   ucVFD1StartVal[6];	/*the initial VFD byte pattern*/


	unsigned short  uiVFD2Offset;			/* in bits							*/
	unsigned char   ucVFD2Range;			/* in bits							*/
	unsigned char   ucVFD2Pattern;		/* HVFD_ENABLED, HVFD_STATIC,	*/
													/* HVFD_INCR, HVFD_DECR,      */
													/* HVFD_RANDOM, HVFD_NONE     */
	unsigned long   ulVFD2PatternCount;	/* from 0(off) to 16,777,215  */
													/* number to incr. or decr.   */
													/* through when using inc or  */
													/* dec pattern                */
	unsigned char   ucVFD2StartVal[6];	/*the initial VFD byte pattern*/


	unsigned short  uiVFD3Offset;			/* in bytes							*/
	unsigned short  uiVFD3Range;			/* in bytes							*/
	unsigned char   ucVFD3Enable;			/* HVFD_ENABLED, HVFD_NONE		*/
	/****************************************************************************/


	unsigned char   ucTagField;			/* 0 = off, 1 = insert Signature	*/
													/* field into each frame			*/

	unsigned char  DestinationMAC[6];	/* the Stream's Dest MAC addr		*/
	unsigned char  SourceMAC[6];			/* the Stream's Source MAC addr	*/
	unsigned char  TypeOfService;			/* The various levels of speed	*/
													/* and/or reliability				*/
	unsigned char  TimeToLive;				/* number of "hops" until frame	*/
													/* will be dropped					*/
	unsigned short InitialSequenceNumber;	/* Initial sequence number			*/
	unsigned char  DestinationIP[4];		/* Dest IP addr(e.g. 192.100.5.3)	*/
	unsigned char  SourceIP[4];			/* Src IP addr (e.g. 192.100.5.4)	*/
	unsigned char  Netmask[4];				/* Network Mask (e.g. 255.255.0.0)	*/
	unsigned char  Gateway[4];				/* Gateway addr (e.g. 192.100.1.1)	*/
	unsigned char  Protocol;				/* 4=IP on the IP assigned list		*/
	unsigned char  extra[17];				/* reserved							*/
	unsigned short uiActualSequenceNumber;	/* Actual Sequence number			*/
	unsigned long  ulARPStart;					/* Return value for the Time of */
													/* the last ARP initiated       */
	unsigned long  ulARPEnd;				/* Return value for the Time of		*/
													/* the last ARP completed			*/
	unsigned long  ulARPGap;				/* The Time between ARPs, in
                                          100ns units; not available
                                          on LAN-3300A, LAN-3301A,
                                          LAN-3310A, or LAN-3311A. */
} StreamIP;

/* StreamIP Comment:
IMPORTANT: See the "SmartLib Basics" chapter in the
SmartLib Overview and Procedures manual.
*/

/*
StreamIPVLAN Description:

This structure contains values for IP compliant Streams that use VLAN tagging.

The IP checksum is automatically calculated using
the supplied header fields and inserted into the IP header.

A Netcom Systems Signature field, used for Histogram results, is
inserted at the end of the payload if ucTagField is enabled
(set to 1).

NOTE:  The Signature field is 18 bytes long, and laid into the frame
just before the CRC. Use caution when defining the frame length
so that the Signature does not overwrite important data.

For the LAN-3710AL, LAN-3710AS and LAN-3710AE modules, the maximum number of
streams that can be created using L3_DEFINE_IP_VLAN_STREAM is 7.  An inactive default
stream will be the first stream created.  
*/
typedef struct tagStreamIPVLAN
{
   unsigned char   ucActive;			/* 1=Enable Stream, 0=Disable Stream */
   unsigned char   ucProtocolType;	/* use STREAM_PROTOCOL_IP_VLAN       */

   unsigned char   ucRandomLength;  /* 1 = Enable random frame length, 
                                       0 = use uiFrameLength.  
                                       Available on the LAN and POS TeraMetrics modules.
                                       Need to set the minimum and 
                                       maximum random lengths using 
                                       NS_PORT_TRANSMIT when enabled. */

   unsigned char   ucRandomData;    /* 1 = Random Data, 0 = use the */
                                    /* cards background pattern     */
                                    /* not available on Frame Relay */
   unsigned short  uiFrameLength;	/* frame length not counting CRC*/
                                    /* 0 - 2048 for Ethernet        */
                                    /* 0 - 8196 for Frame Relay     */
 
 

   /*****************************************************************
   *                                                                *
   *  For ETHERNET, cards VFD1, VFD2, and VFD3 structure members    *
   * are reserved for later use. Set to 0.                          *
   *****************************************************************/

   unsigned short uiVFD1Offset;     /* in bits                      */
   unsigned char	ucVFD1Range;		/* in bits                      */
   unsigned char  ucVFD1Pattern;    /* HVFD_ENABLED, HVFD_STATIC,   */
                                    /* HVFD_INCR, HVFD_DECR,        */
                                    /* HVFD_RANDOM, HVFD_NONE       */
   unsigned long  ulVFD1PatternCount;  /* from 0(off) to 16,777,215 */
                                    /* number to incr. or decr.     */
                                    /* through when using inc or    */
                                    /* dec pattern                  */
   unsigned char  ucVFD1StartVal[6];  /*the initial VFD byte pattern*/


   unsigned short uiVFD2Offset;     /* in bits                      */
   unsigned char  ucVFD2Range;      /* in bits                      */
   unsigned char  ucVFD2Pattern;    /* HVFD_ENABLED, HVFD_STATIC,   */
                                    /* HVFD_INCR, HVFD_DECR,        */
                                    /* HVFD_RANDOM, HVFD_NONE       */
   unsigned long  ulVFD2PatternCount;  /* from 0(off) to 16,777,215 */
                                    /* number to incr. or decr.     */
                                    /* through when using inc or    */
                                    /* dec pattern                  */
   unsigned char  ucVFD2StartVal[6];  /*the initial VFD byte pattern*/


   unsigned short uiVFD3Offset;     /* in bytes                     */
   unsigned short uiVFD3Range;      /* in bytes                     */
   unsigned char  ucVFD3Enable;     /* HVFD_ENABLED, HVFD_NONE      */
   /*****************************************************************/


   unsigned char  ucTagField;       /* 0 = off, 1 = insert Signature */
                                    /* field into each frame         */

   unsigned char  DestinationMAC[6];  /* the Stream's Dest MAC addr  */
   unsigned char  SourceMAC[6];     /* the Stream's Source MAC addr  */
   unsigned char  TypeOfService;    /* */
   unsigned char  TimeToLive;       /* number of "hops" until frame  */
                                    /* will be dropped               */
   unsigned short InitialSequenceNumber;  /* Initial sequence number */
   unsigned char  DestinationIP[4]; /* Dest IP addr(e.g. 192.100.5.3)*/
   unsigned char  SourceIP[4];      /* Src IP addr (e.g. 192.100.5.4)*/
   unsigned char  Netmask[4];       /* Network Mask (e.g. 255.255.0.0) */
   unsigned char  Gateway[4];       /* Gateway addr (e.g. 192.100.1.1) */
   unsigned char  Protocol;			/* 4=IP on the IP assigned list  */
   unsigned char  reserved[5];

   unsigned short VLAN_Pri;         /* VLAN Priority: available constants
                                       VLAN_PRI_0 VLAN_PRI_1 VLAN_PRI_2 VLAN_PRI_3
                                       VLAN_PRI_4 VLAN_PRI_5 VLAN_PRI_6 VLAN_PRI_7
                                       VLAN_PRI_LOWEST VLAN_PRI_HIGHEST */

   unsigned short VLAN_Cfi;         /* VLAN CFI bit: available constants
                                       VLAN_CFI_RIF_ABSENT  VLAN_CFI_RIF_PRESENT */

   unsigned short VLAN_Vid;         /*VLAN identifier                */

   unsigned char  extra[12];        /* reserved                      */
   unsigned long  ulARPStart;       /* Return value for the Time of  */
                                    /* the last ARP initiated        */
   unsigned long  ulARPEnd;         /* Return value for the Time of  */
                                    /* the last ARP completed        */
   unsigned long  ulARPGap;			/* The Time between ARPs, in 100ns
                                       units; not available on LAN-3300A,
                                       LAN-3301A, LAN-3310A, or
                                       LAN-3311A. */
} StreamIPVLAN;

/* StreamIPVLAN Comment:
IMPORTANT: See the "SmartLib Basics" chapter in the
SmartLib Overview and Procedures manual.
*/



/*
StreamUDP Description:

This structure contains values for UDP compliant Streams.

The IP checksums are automatically calculated using
the supplied field value and inserted into the frame.

For ATM Terametrics modules, IP checksum has to be in the first cell
(within the first 48 bytes) because of card limitation.

The UDP checksum is set to 0, and so is not calculated.

A Netcom Systems Signature field, used for Histogram results, is
inserted at the end of the payload if ucTagField is enabled 
(set to 1).

NOTE:

For the LAN-3710AL, LAN-3710AS and LAN-3710AE modules, the maximum number of
streams that can be created using L3_DEFINE_UDP_STREAM is 7.  An inactive default
stream will be the first stream created.  

  For ATM Terametrics modules set ucProtocolType as STREAM_PROTOCOL_UDP
when the bound VC is not of BRIDGED encapsulation while set it as
STREAM_PROTOCOL_BRIDGED when the bound VC is of BRIDGED encapsulation

*/
typedef struct tagStreamUDP
 {
 unsigned char  ucActive;		/* 1=Enable Stream, 0=Disable Stream */
 unsigned char  ucProtocolType;	/* use STREAM_PROTOCOL_UDP, or
                                       STREAM_PROTOCOL_BRIDGED (ATM only)
                                    */
 
 unsigned char  ucRandomLength;  /* 1 = Enable random frame length, 
                                    0 = use uiFrameLength.  
                                    Available on the LAN and POS TeraMetrics modules.
                                    Need to set the minimum and 
                                    maximum random lengths using 
                                    NS_PORT_TRANSMIT when enabled. */

 unsigned char  ucRandomData;	/* 1 = Random Data, 0 = use the */
											/* cards background pattern     */
											/* not available on Frame Relay */
											/* and ATM Terametrics modules  */
 unsigned short uiFrameLength;	/* frame length not counting CRC*/
											/* 0 - 2048 for Ethernet        */
											/* 0 - 8196 for Frame Relay     */


 /*****************************************************************
*                                                                *
*  For ETHERNET, cards VFD1, VFD2, and VFD3 structure members    *
* are reserved for later use. Set to 0.                          *
*****************************************************************/

 unsigned short uiVFD1Offset;	/* in bits                      */
 unsigned char  ucVFD1Range;		/* in bits                      */
 unsigned char  ucVFD1Pattern;	/* HVFD_ENABLED, HVFD_STATIC,   */
											/* HVFD_INCR, HVFD_DECR,        */
											/* HVFD_RANDOM, HVFD_NONE       */
 unsigned long  ulVFD1PatternCount;/* from 0(off) to 16,777,215 */
											/* number to incr. or decr.     */
											/* through when using inc or    */
											/* dec pattern                  */
 unsigned char  ucVFD1StartVal[6];/*the initial VFD byte pattern*/


 unsigned short uiVFD2Offset;	/* in bits                      */
 unsigned char  ucVFD2Range;		/* in bits                      */
 unsigned char  ucVFD2Pattern;	/* HVFD_ENABLED, HVFD_STATIC,   */
											/* HVFD_INCR, HVFD_DECR,        */
											/* HVFD_RANDOM, HVFD_NONE       */
 unsigned long  ulVFD2PatternCount;/* from 0(off) to 16,777,215 */
											/* number to incr. or decr.     */
											/* through when using inc or    */
											/* dec pattern                  */
 unsigned char  ucVFD2StartVal[6];/*the initial VFD byte pattern*/


 unsigned short uiVFD3Offset;	/* in bytes                     */
 unsigned short uiVFD3Range;		/* in bytes                     */
 unsigned char  ucVFD3Enable;	/* HVFD_ENABLED, HVFD_NONE      */

/*****************************************************************/

 unsigned char  ucTagField;		/* 0 = off, 1 = insert signature */
											/* field into each frame         */

 unsigned char  DestinationMAC[6];/* the Stream's Dest MAC addr  */
 unsigned char  SourceMAC[6];		/* the Stream's Source MAC addr */
 unsigned char  TypeOfService;	/* */
 unsigned char  TimeToLive;		/* number of "hops" until frame */
											/* will be dropped */
 unsigned short InitialSequenceNumber;	/* Initial sequence number*/
 unsigned char  DestinationIP[4];/* Dest IP addr(e.g. 192.100.5.3) */
 unsigned char  SourceIP[4];		/* Src IP addr (e.g. 192.100.5.4) */
 unsigned char  Netmask[4];		/* Network Mask (e.g. 255.255.0.0)*/
 unsigned char  Gateway[4];		/* Gateway addr (e.g. 192.100.1.1)*/
 unsigned short UDPSrc;				/* UDP Source Port              */
 unsigned short UDPDest;			/* UDP Dest Port                */
 unsigned short UDPLen;				/* UDP Length field - not used  */
 unsigned char  ucUDPChecksumEnable; /* Only applicable for the LAN-3101A, LAN-3101B cards.
                                       0 = disable, 1 = enable
                                     */                                       
 unsigned char  extra[11];			/* reserved                     */
 unsigned short uiActualSequenceNumber;/* Actual Sequence number */
 unsigned long  ulARPStart;		/* Return value for the Time of */
											/* the last ARP initiated       */
 unsigned long  ulARPEnd;			/* Return value for the Time of */
											/* the last ARP completed       */
 unsigned long  ulARPGap;			/* The Time between ARPs, in 100ns
                                    units; not available on LAN-3300A,
                                    LAN-3301A, LAN-3310A, or
                                    LAN-3311A. */
 } StreamUDP;

/* StreamUDP Comment:
IMPORTANT: See the "SmartLib Basics" chapter in the
SmartLib Overview and Procedures manual.
*/

/*
StreamUDPVLAN Description:

This structure is contains values for UDP compliant 
Streams with VLAN tagging.

The IP checksums are automatically calculated using
the supplied field value and inserted into the frame.

The UDP checksum is set to 0, and so is not calculated.

A Netcom Systems Signature field, used for Histogram results, is
inserted at the end of the payload if ucTagField is enabled 
(set to 1).

NOTE:

For the LAN-3710AL, LAN-3710AS and LAN-3710AE modules, the maximum number of
streams that can be created using L3_DEFINE_UDP_STREAM_VLAN is 7.  An inactive default
stream will be the first stream created.  
*/
typedef struct tagStreamUDPVLAN
 {
 unsigned char  ucActive;		/* 1=Enable Stream, 0=Disable Stream */
 unsigned char  ucProtocolType;	/* use STREAM_PROTOCOL_UDP_VLAN      */
 
 unsigned char  ucRandomLength;  /* 1 = Enable random frame length, 
                                    0 = use uiFrameLength.  
                                    Available on the LAN and POS TeraMetrics modules.
                                    Need to set the minimum and 
                                    maximum random lengths using 
                                    NS_PORT_TRANSMIT when enabled. */
 unsigned char  ucRandomData;	/* 1 = Random Data, 0 = use the */
											/* cards background pattern     */
											/* not available on Frame Relay */
 unsigned short uiFrameLength;	/* frame length not counting CRC*/
											/* 0 - 2048 for Ethernet        */
											/* 0 - 8196 for Frame Relay     */


 /*****************************************************************
*                                                                *
*  For ETHERNET, cards VFD1, VFD2, and VFD3 structure members    *
* are reserved for later use. Set to 0.                          *
*****************************************************************/

 unsigned short uiVFD1Offset;	/* in bits                      */
 unsigned char  ucVFD1Range;		/* in bits                      */
 unsigned char  ucVFD1Pattern;	/* HVFD_ENABLED, HVFD_STATIC,   */
											/* HVFD_INCR, HVFD_DECR,        */
											/* HVFD_RANDOM, HVFD_NONE       */
 unsigned long  ulVFD1PatternCount;/* from 0(off) to 16,777,215 */
											/* number to incr. or decr.     */
											/* through when using inc or    */
											/* dec pattern                  */
 unsigned char  ucVFD1StartVal[6];/*the initial VFD byte pattern*/


 unsigned short uiVFD2Offset;	/* in bits                      */
 unsigned char  ucVFD2Range;		/* in bits                      */
 unsigned char  ucVFD2Pattern;	/* HVFD_ENABLED, HVFD_STATIC,   */
											/* HVFD_INCR, HVFD_DECR,        */
											/* HVFD_RANDOM, HVFD_NONE       */
 unsigned long  ulVFD2PatternCount;/* from 0(off) to 16,777,215 */
											/* number to incr. or decr.     */
											/* through when using inc or    */
											/* dec pattern                  */
 unsigned char  ucVFD2StartVal[6];/*the initial VFD byte pattern*/


 unsigned short uiVFD3Offset;	/* in bytes                     */
 unsigned short uiVFD3Range;		/* in bytes                     */
 unsigned char  ucVFD3Enable;	/* HVFD_ENABLED, HVFD_NONE      */

/*****************************************************************/

 unsigned char  ucTagField;		/* 0 = off, 1 = insert signatre */
											/* field into each frame         */

 unsigned char  DestinationMAC[6];/* the Stream's Dest MAC addr  */
 unsigned char  SourceMAC[6];		/* the Stream's Source MAC addr */
 unsigned char  TypeOfService;	/* */
 unsigned char  TimeToLive;		/* number of "hops" until frame */
											/* will be dropped */
 unsigned short InitialSequenceNumber;	/* Initial sequence number*/
 unsigned char  DestinationIP[4];/* Dest IP addr(e.g. 192.100.5.3) */
 unsigned char  SourceIP[4];		/* Src IP addr (e.g. 192.100.5.4) */
 unsigned char  Netmask[4];		/* Network Mask (e.g. 255.255.0.0)*/
 unsigned char  Gateway[4];		/* Gateway addr (e.g. 192.100.1.1)*/
 unsigned short	UDPSrc;				/* UDP Source Port              */
 unsigned short UDPDest;			/* UDP Dest Port                */
 unsigned short UDPLen;				/* UDP Length field - not used  */

 unsigned short VLAN_Pri;       /*VLAN Priority: available constants
                                   VLAN_PRI_0 VLAN_PRI_1 VLAN_PRI_2 VLAN_PRI_3
                                   VLAN_PRI_4 VLAN_PRI_5 VLAN_PRI_6 VLAN_PRI_7
                                   VLAN_PRI_LOWEST VLAN_PRI_HIGHEST */

 unsigned short VLAN_Cfi;       /*VLAN CFI bit: available constants
                                    VLAN_CFI_RIF_ABSENT  VLAN_CFI_RIF_PRESENT */

 unsigned short VLAN_Vid;       /*VLAN identifier */

 unsigned char  ucUDPChecksumEnable; /* Only applicable for the LAN-3101A, LAN-3101B cards.
                                       0 = disable, 1 = enable
                                     */                                       
 unsigned char  extra[11];			/* reserved                     */
 unsigned long  ulARPStart;		/* Return value for the Time of */
											/* the last ARP initiated       */
 unsigned long  ulARPEnd;			/* Return value for the Time of */
											/* the last ARP completed       */
 unsigned long  ulARPGap;			/* The Time between ARPs, in 100ns
                                    units; not available on LAN-3300A,
                                    LAN-3301A, LAN-3310A, or
                                    LAN-3311A. */
 } StreamUDPVLAN;

/* StreamUDPVLAN Comment:
IMPORTANT: See the "SmartLib Basics" chapter in the
SmartLib Overview and Procedures manual.
*/




/*
StreamIPX Description:

This structure contains values for IPX compliant Streams.

A Netcom Systems Signature field, used for Histogram results, is
inserted at the end of the payload if ucTagField is enabled 
(set to 1).

NOTE:  The Signature field is 18 bytes long, and laid into the frame
just before the CRC. Use caution when defining the frame length
so that the Signature does not overwrite important data.

*/
typedef struct tagStreamIPX
 {
 unsigned char   ucActive;			/* 1=Enable Stream, 0=Disable Stream */
 unsigned char   ucProtocolType;	/* use STREAM_PROTOCOL_IPX      */
 
 unsigned char   ucRandomLength; /* 1 = Enable random frame length, 
                                    0 = use uiFrameLength.  
                                    Available on the LAN and POS TeraMetrics modules.
                                    Need to set the minimum and 
                                    maximum random lengths using 
                                    NS_PORT_TRANSMIT when enabled. */
 unsigned char   ucRandomData;	/* 1 = Random Data, 0 = use the */
											/* cards background pattern     */
											/* not available on Frame Relay */
 unsigned short  uiFrameLength;	/* frame length not counting CRC*/
											/* 0 - 2048 for Ethernet        */
											/* 0 - 8196 for Frame Relay     */


/*****************************************************************
*                                                                *
*  For ETHERNET cards, VFD1, VFD2, and VFD3 structure members    *
* are reserved for later use. Set to 0.                          *
*****************************************************************/

 unsigned short  uiVFD1Offset;	/* in bits                      */
 unsigned char   ucVFD1Range;		/* in bits                      */
 unsigned char   ucVFD1Pattern;	/* HVFD_ENABLED, HVFD_STATIC,   */
											/* HVFD_INCR, HVFD_DECR,        */
											/* HVFD_RANDOM, HVFD_NONE       */
 unsigned long   ulVFD1PatternCount;/* from 0(off) to 16,777,215 */
											/* number to incr. or decr.     */
											/* through when using inc or    */
											/* dec pattern                  */
 unsigned char   ucVFD1StartVal[6];/*the initial VFD byte pattern*/


 unsigned short  uiVFD2Offset;	/* in bits                      */
 unsigned char   ucVFD2Range;		/* in bits                      */
 unsigned char   ucVFD2Pattern;	/* HVFD_ENABLED, HVFD_STATIC,   */
											/* HVFD_INCR, HVFD_DECR,        */
											/* HVFD_RANDOM, HVFD_NONE       */
 unsigned long   ulVFD2PatternCount;/* from 0(off) to 16,777,215 */
											/* number to incr. or decr.     */
											/* through when using inc or    */
											/* dec pattern                  */
 unsigned char   ucVFD2StartVal[6];/*the initial VFD byte pattern*/


 unsigned short  uiVFD3Offset;	/* in bytes                     */
 unsigned short  uiVFD3Range;		/* in bytes                     */
 unsigned char   ucVFD3Enable;	/* HVFD_ENABLED, HVFD_NONE      */

/*****************************************************************/

 
 unsigned char   ucTagField;		/* 0 = off, 1 = insert signature */
                                 /* field into each frame         */

 unsigned char   DestinationMAC[6];	/* the Stream's Dest MAC addr*/
 unsigned char   SourceMAC[6];	/* the Stream's Source MAC addr */
 unsigned short  IPXlen;			/* Length field in the IPX hdr  */
 unsigned char   IPXhop;			/* Hop field in the IPX hdr     */
 unsigned char   IPXtype;			/* IPX type field in the IPX hdr*/
 unsigned char   IPXdst[4];		/* Dest ID in the IPX hdr       */
 unsigned char   IPXdstHost[6];	/* Dest host in the IPX hdr     */
 unsigned short  IPXdstSocket;	/* Dest Socket in the IPX hdr   */
 unsigned char   IPXsrc[4];		/* Source ID in the IPX hdr     */
 unsigned char   IPXsrcHost[6];	/* Source host in the IPX hdr   */
 unsigned short  IPXsrcSocket;	/* Source socket in the IPX hdr */
 unsigned char   extra[24];		/* reserved */
 } StreamIPX;

/* StreamIPX comment:
IMPORTANT: See the "SmartLib Basics" chapter in the
SmartLib Overview and Procedures manual.
*/



/*
StreamTCP Description:

This structure contains values for TCP compliant Streams.

The IP checksum is automatically calculated using
the supplied header fields and inserted into the IP header.

For ATM Terametrics modules, IP checksum has to be in the first cell
(within the first 48 bytes) because of card limitation.

A Netcom Systems Signature field, used for Histogram results, is
inserted at the end of the payload if ucTagField is enabled
(set to 1).

NOTE:

For the LAN-3710AL, LAN-3710AS and LAN-3710AE modules, the maximum number of
streams that can be created using L3_DEFINE_TCP_STREAM is 7.  An inactive default
stream will be the first stream created.  

For ATM Terametrics modules set ucProtocolType as STREAM_PROTOCOL_TCP
when the bound VC is not of BRIDGED encapsulation while set it as
STREAM_PROTOCOL_BRIDGED when the bound VC is of BRIDGED encapsulation

*/
typedef struct tagStreamTCP
{
 unsigned char  ucActive;		/* 1=Enable Stream, 0=Disable Stream */
 unsigned char  ucProtocolType;	/* use STREAM_PROTOCOL_TCP, or
                                       STREAM_PROTOCOL_BRIDGED (ATM only)
                                    */
 unsigned char  ucRandomLength;  /* 1 = Enable random frame length, 
                                    0 = use uiFrameLength.  
                                    Available on the LAN and POS TeraMetrics modules.
                                    Need to set the minimum and 
                                    maximum random lengths using 
                                    NS_PORT_TRANSMIT when enabled. */

 unsigned char  ucRandomData;	/* 1 = Random Data, 0 = use the */
											/* cards background pattern     */
											/* not available on Frame Relay */
											/* and ATM Terametrics modules  */
 unsigned short uiFrameLength;	/* frame length not counting CRC*/
											/* 0 - 2048 for Ethernet        */
											/* 0 - 8196 for Frame Relay     */

 /*****************************************************************/
 /** VFD1, VFD2, and VFD3 structure members are reserved for later
     use. Set to 0. **/
 unsigned short uiVFD1Offset;	/* in bits                      */
 unsigned char  ucVFD1Range;		/* in bits                      */
 unsigned char  ucVFD1Pattern;	/* HVFD_ENABLED, HVFD_STATIC,   */
											/* HVFD_INCR, HVFD_DECR,        */
											/* HVFD_RANDOM, HVFD_NONE       */
 unsigned long  ulVFD1PatternCount;/* from 0(off) to 16,777,215.*/
											/* number to incr. or decr.     */
											/* through when using inc or    */
											/* dec pattern                  */
 unsigned char  ucVFD1StartVal[6];/*the initial VFD byte pattern */

 unsigned short uiVFD2Offset;	/* in bits                      */
 unsigned char  ucVFD2Range;		/* in bits                      */
 unsigned char  ucVFD2Pattern;	/* HVFD_ENABLED, HVFD_STATIC,   */
											/* HVFD_INCR, HVFD_DECR,        */
											/* HVFD_RANDOM, HVFD_NONE       */
 unsigned long  ulVFD2PatternCount;/* from 0(off) to 16,777,215 */
											/* number to incr. or decr.     */
											/* through when using inc or    */
											/* dec pattern                  */
 unsigned char  ucVFD2StartVal[6];/*the initial VFD byte pattern*/
 unsigned short uiVFD3Offset;	/* in bytes                     */
 unsigned short uiVFD3Range;		/* in bytes                     */
 unsigned char  ucVFD3Enable;	/* HVFD_ENABLED, HVFD_NONE       */
 /*****************************************************************/

 unsigned char  ucTagField;		/* 0 = off, 1 = insert signature */
											/* field into each frame         */

 unsigned char  DestinationMAC[6];/* the Stream's Dest MAC addr  */
 unsigned char  SourceMAC[6];		/* the Stream's Source MAC addr */
 unsigned char  TypeOfService;	/* the various levels of speed and/or
											   reliability, as described in RFC
											   1359 */
 unsigned char  TimeToLive;		/* number of "hops" until frame */
											/* will be dropped */
 unsigned short InitialSequenceNumber;	/* Initial sequence number*/
 unsigned char  DestinationIP[4];/* Dest IP addr(e.g. 192.100.5.3) */
 unsigned char  SourceIP[4];		/* Src IP addr (e.g. 192.100.5.4) */
 unsigned char  Netmask[4];      /* Netmask address (e.g. 255.255.255.0)*/
 unsigned char  Gateway[4];		/* Gateway addr (e.g. 192.100.1.1)*/
 unsigned short SourcePort;      /*	Source Port for TCP connection */
 unsigned short DestPort;        /*	Destination Port for TCP connection */
 unsigned short Window;          /* TCP protocol window size, in bytes*/

 unsigned char  reserved[2]; 

 unsigned long  TCPAck;       	/*	TCP Acknowledgment number */
 unsigned long  TCPSequence;     /* TCP Sequence number */

 unsigned char  Flags;           /*	use TCP_FLAG_XXX defines */
 unsigned char  extra[3];

 unsigned long 	ulARPOut;      /* reserved--not currently in use */
 unsigned long 	ulARPBack;     /* reserved--not currently in use */
 unsigned long 	ulARPGap;      /* the time between ARPs, in 100ns
                                    units; not available on LAN-3300A,
                                    LAN-3301A, LAN-3310A, or
                                    LAN-3311A. */
	} StreamTCP;

#define TCP_FLAG_FIN		0x01
#define TCP_FLAG_SYN		0x02
#define TCP_FLAG_RST		0x04
#define TCP_FLAG_PSH		0x08
#define TCP_FLAG_ACK		0x10
#define TCP_FLAG_URG		0x20


/*
StreamTCPVLAN Description:

This structure contains values for TCP compliant Streams with VLAN
tagging.

A Netcom Systems Signature field, used for Histogram results, is
inserted at the end of the payload if ucTagField is enabled
(set to 1).

NOTE:

  For the LAN-3710AL, LAN-3710AS and LAN-3710AE modules, the maximum number of
streams that can be created using L3_DEFINE_TCP_STREAM_VLAN is 7.  An inactive default
stream will be the first stream created.  
*/
typedef struct tagStreamTCPVLAN
{
 unsigned char  ucActive;		/* 1=Enable Stream, 0=Disable Stream */
 unsigned char  ucProtocolType;	/* use STREAM_PROTOCOL_TCP_VLAN      */
 unsigned char  ucRandomLength;  /* 1 = Enable random frame length, 
                                    0 = use uiFrameLength.  
                                    Available on the LAN and POS TeraMetrics modules.
                                    Need to set the minimum and 
                                    maximum random lengths using 
                                    NS_PORT_TRANSMIT when enabled. */

 unsigned char  ucRandomData;	/* 1 = Random Data, 0 = use the */
											/* cards background pattern     */
											/* not available on Frame Relay */
 unsigned short uiFrameLength;	/* frame length not counting CRC*/
											/* 0 - 2048 for Ethernet        */
											/* 0 - 8196 for Frame Relay     */


 /** VFD1 and VFD2 structure members are reserved for later use. Set to 0. **/
 unsigned short uiVFD1Offset;	/* in bits                      */
 unsigned char  ucVFD1Range;		/* in bits                      */
 unsigned char  ucVFD1Pattern;	/* HVFD_ENABLED, HVFD_STATIC,   */
											/* HVFD_INCR, HVFD_DECR,        */
											/* HVFD_RANDOM, HVFD_NONE       */
 unsigned long  ulVFD1PatternCount;/* from 0(off) to 16,777,215.*/
											/* number to incr. or decr.     */
											/* through when using inc or    */
											/* dec pattern                  */
 unsigned char  ucVFD1StartVal[6];/*the initial VFD byte pattern */

 unsigned short uiVFD2Offset;	/* in bits                      */
 unsigned char  ucVFD2Range;		/* in bits                      */
 unsigned char  ucVFD2Pattern;	/* HVFD_ENABLED, HVFD_STATIC,   */
											/* HVFD_INCR, HVFD_DECR,        */
											/* HVFD_RANDOM, HVFD_NONE       */
 unsigned long  ulVFD2PatternCount;/* from 0(off) to 16,777,215 */
											/* number to incr. or decr.     */
											/* through when using inc or    */
											/* dec pattern                  */
 unsigned char  ucVFD2StartVal[6];/*the initial VFD byte pattern*/
 /****************************************************************/


 unsigned short uiVFD3Offset;	/* in bytes                     */
 unsigned short uiVFD3Range;		/* in bytes                     */
 unsigned char  ucVFD3Enable;	/* HVFD_ENABLED, HVFD_NONE       */

 unsigned char  ucTagField;		/* 0 = off, 1 = insert signature */
											/* field into each frame         */

 unsigned char	DestinationMAC[6];/* the Stream's Dest MAC addr  */
 unsigned char  SourceMAC[6];		/* the Stream's Source MAC addr */
 unsigned char  TypeOfService;	/* */
 unsigned char  TimeToLive;		/* number of "hops" until frame */
											/* will be dropped */
 unsigned short InitialSequenceNumber;	/* Initial sequence number*/
 unsigned char  DestinationIP[4];/* Dest IP addr(e.g. 192.100.5.3) */
 unsigned char  SourceIP[4];		/* Src IP addr (e.g. 192.100.5.4) */
 unsigned char  Netmask[4];      /*Netmask address (e.g. 255.255.255.0)*/
 unsigned char  Gateway[4];		/* Gateway addr (e.g. 192.100.1.1)*/
 unsigned short SourcePort;      /*	Source Port for TCP connection */
 unsigned short DestPort;        /*	Destination Port for TCP connection */
 unsigned short Window;          /* TCP protocol window size */

 unsigned short VLAN_Pri;			/*VLAN Priority: available constants
                                   VLAN_PRI_0 VLAN_PRI_1 VLAN_PRI_2 VLAN_PRI_3
                                   VLAN_PRI_4 VLAN_PRI_5 VLAN_PRI_6 VLAN_PRI_7
                                   VLAN_PRI_LOWEST VLAN_PRI_HIGHEST */

 unsigned short VLAN_Cfi;			/*V LAN CFI bit: available constants	*/
											/* VLAN_CFI_RIF_ABSENT  VLAN_CFI_RIF_PRESENT */

 unsigned short VLAN_Vid;			/*VLAN identifier */

 unsigned long  TCPAck;				/*	TCP Acknowledgment */
 unsigned long  TCPSequence;     /* */

 unsigned char  Flags;           /*	1 is FIN, 2 is SYN, 4 is RST, 8 is PSH */
 											/* 16 is ACK, 32 is URG */
 unsigned char  Spare[3];			/**/

 unsigned long 	ulARPOut;      /* */
 unsigned long 	ulARPBack;     /**/
 unsigned long 	ulARPGap;      /**/
	} StreamTCPVLAN;


/*
StreamSmartTCP Description:

This structure contains values for TCP compliant Streams for the SmartTCP tests.

*/
typedef struct tagStreamSmartTCP
{
 unsigned char  ucActive;			/* 1=Enable Stream, 0=Disable Stream */
 unsigned char  ucProtocolType;	/* use STREAM_PROTOCOL_SMART_TCP */
 unsigned char  ucRandomLength;	/* Reserved */
 unsigned char  ucRandomData;	/* 1 = Random Data, 0 = use the */
											/* cards background pattern     */
											/* not available on Frame Relay */
 unsigned short uiFrameLength;	/* frame length not counting CRC*/
											/* 0 - 2048 for Ethernet        */
											/* 0 - 8196 for Frame Relay     */


 /** VFD1 and VFD2 structure members are reserved for later use. Set to 0. **/
 unsigned short uiVFD1Offset;	/* in bits                      */
 unsigned char  ucVFD1Range;		/* in bits                      */
 unsigned char  ucVFD1Pattern;	/* HVFD_ENABLED, HVFD_STATIC,   */
											/* HVFD_INCR, HVFD_DECR,        */
											/* HVFD_RANDOM, HVFD_NONE       */
 unsigned long  ulVFD1PatternCount;/* from 0(off) to 16,777,215.*/
											/* number to incr. or decr.     */
											/* through when using inc or    */
											/* dec pattern                  */
 unsigned char  ucVFD1StartVal[6];/*the initial VFD byte pattern */

 unsigned short uiVFD2Offset;	/* in bits                      */
 unsigned char  ucVFD2Range;		/* in bits                      */
 unsigned char  ucVFD2Pattern;	/* HVFD_ENABLED, HVFD_STATIC,   */
											/* HVFD_INCR, HVFD_DECR,        */
											/* HVFD_RANDOM, HVFD_NONE       */
 unsigned long  ulVFD2PatternCount;/* from 0(off) to 16,777,215 */
											/* number to incr. or decr.     */
											/* through when using inc or    */
											/* dec pattern                  */
 unsigned char  ucVFD2StartVal[6];/*the initial VFD byte pattern*/
 /****************************************************************/


 unsigned short uiVFD3Offset;	/* in bytes                     */
 unsigned short uiVFD3Range;		/* in bytes                     */
 unsigned char  ucVFD3Enable;	/* HVFD_ENABLED, HVFD_NONE       */

 unsigned char  ucTagField;		/* 0 = off, 1 = insert signature */
											/* field into each frame         */

 unsigned char  DestinationMAC[6];/* the Stream's Dest MAC addr  */
 unsigned char  SourceMAC[6];		/* the Stream's Source MAC addr */
 unsigned char  TypeOfService;	/* */
 unsigned char  TimeToLive;		/* number of "hops" until frame */
											/* will be dropped */
 unsigned short InitialSequenceNumber;	/* Initial sequence number*/
 unsigned char  DestinationIP[4];/* Dest IP addr(e.g. 192.100.5.3) */
 unsigned char  SourceIP[4];		/* Src IP addr (e.g. 192.100.5.4) */
 unsigned char  Netmask[4];      /*Netmask address (e.g. 255.255.255.0)*/
 unsigned char  Gateway[4];		/* Gateway addr (e.g. 192.100.1.1)*/
 unsigned short SourcePort;      /*	Source Port for TCP connection */
 unsigned short DestPort;        /*	Destination Port for TCP connection */
 unsigned short TCPLength;       /* Length field for TCP Header */
 unsigned short Sequence_acc;    /*	*/
 unsigned long  PartialChecksum; /* */
 unsigned long  TCPSequence;     /* TCP Sequence*/
 unsigned short Window;          /* TCP protocol window size */
 unsigned char  Flags;           /*	1 is FIN, 2 is SYN, 4 is RST, 8 is PSH */
 unsigned char  Spare;           /**/
 unsigned long  ulARPOut;      /**/
 unsigned long 	ulARPBack;     /**/
 unsigned long 	ulARPGap;      /**/
} StreamSmartTCP;

//Support added for Vlan in Websuite 2.0

/*
StreamSmartTCPVLAN Description:

This structure contains values for TCP compliant Streams for the SmartTCPVLAN tests.

*/
typedef struct tagStreamSmartTCPVLAN
{
 unsigned char  ucActive;			/* 1=Enable Stream, 0=Disable Stream */
 unsigned char  ucProtocolType;	/* use STREAM_PROTOCOL_SMART_TCP */
 unsigned char  ucRandomLength;	/* Reserved */
 unsigned char  ucRandomData;	/* 1 = Random Data, 0 = use the */
											/* cards background pattern     */
											/* not available on Frame Relay */
 unsigned short uiFrameLength;	/* frame length not counting CRC*/
											/* 0 - 2048 for Ethernet        */
											/* 0 - 8196 for Frame Relay     */


 /** VFD1 and VFD2 structure members are reserved for later use. Set to 0. **/
 unsigned short uiVFD1Offset;	/* in bits                      */
 unsigned char  ucVFD1Range;		/* in bits                      */
 unsigned char  ucVFD1Pattern;	/* HVFD_ENABLED, HVFD_STATIC,   */
											/* HVFD_INCR, HVFD_DECR,        */
											/* HVFD_RANDOM, HVFD_NONE       */
 unsigned long  ulVFD1PatternCount;/* from 0(off) to 16,777,215.*/
											/* number to incr. or decr.     */
											/* through when using inc or    */
											/* dec pattern                  */
 unsigned char  ucVFD1StartVal[6];/*the initial VFD byte pattern */

 unsigned short uiVFD2Offset;	/* in bits                      */
 unsigned char  ucVFD2Range;		/* in bits                      */
 unsigned char  ucVFD2Pattern;	/* HVFD_ENABLED, HVFD_STATIC,   */
											/* HVFD_INCR, HVFD_DECR,        */
											/* HVFD_RANDOM, HVFD_NONE       */
 unsigned long  ulVFD2PatternCount;/* from 0(off) to 16,777,215 */
											/* number to incr. or decr.     */
											/* through when using inc or    */
											/* dec pattern                  */
 unsigned char  ucVFD2StartVal[6];/*the initial VFD byte pattern*/
 /****************************************************************/


 unsigned short uiVFD3Offset;	/* in bytes                     */
 unsigned short uiVFD3Range;		/* in bytes                     */
 unsigned char  ucVFD3Enable;	/* HVFD_ENABLED, HVFD_NONE       */

 unsigned char  ucTagField;		/* 0 = off, 1 = insert signature */
											/* field into each frame         */
 unsigned char  DestinationMAC[6];/* the Stream's Dest MAC addr  */
 unsigned char  SourceMAC[6];		/* the Stream's Source MAC addr */
 unsigned short VLAN_Pri;			/*VLAN Priority: available constants
                                   VLAN_PRI_0 VLAN_PRI_1 VLAN_PRI_2 VLAN_PRI_3
                                   VLAN_PRI_4 VLAN_PRI_5 VLAN_PRI_6 VLAN_PRI_7
                                   VLAN_PRI_LOWEST VLAN_PRI_HIGHEST */
 unsigned short VLAN_Cfi;			/*V LAN CFI bit: available constants	*/
											/* VLAN_CFI_RIF_ABSENT  VLAN_CFI_RIF_PRESENT */
 unsigned short VLAN_Vid;			/*VLAN identifier */

 unsigned char  TypeOfService;	/* */
 unsigned char  TimeToLive;		/* number of "hops" until frame */
											/* will be dropped */
 unsigned short InitialSequenceNumber;	/* Initial sequence number*/
 unsigned char  DestinationIP[4];/* Dest IP addr(e.g. 192.100.5.3) */
 unsigned char  SourceIP[4];		/* Src IP addr (e.g. 192.100.5.4) */
 unsigned char  Netmask[4];      /*Netmask address (e.g. 255.255.255.0)*/
 unsigned char  Gateway[4];		/* Gateway addr (e.g. 192.100.1.1)*/
 unsigned short SourcePort;      /*	Source Port for TCP connection */
 unsigned short DestPort;        /*	Destination Port for TCP connection */
 unsigned short TCPLength;       /* Length field for TCP Header */
 unsigned short Sequence_acc;    /*	*/
 unsigned long  PartialChecksum; /* */
 unsigned long  TCPSequence;     /* TCP Sequence*/
 unsigned short Window;          /* TCP protocol window size */
 unsigned char  Flags;           /*	1 is FIN, 2 is SYN, 4 is RST, 8 is PSH */
 unsigned char  Spare;           /**/
 unsigned long  ulARPOut;      /**/
 unsigned long 	ulARPBack;     /**/
 unsigned long 	ulARPGap;      /**/
} StreamSmartTCPVLAN;

/*
StreamICMP Description:

This structure contains values for ICMP compliant Streams for the SmartTCP tests.

The ICMP checksum is automatically calculated using
the supplied header fields and inserted into the IP header.

For ATM Terametrics modules, IP checksum has to be in the first cell
(within the first 48 bytes) because of card limitation.

A Netcom Systems Signature field, used for Histogram results, is
inserted at the end of the payload if ucTagField is enabled 
(set to 1).

NOTE:  The Signature field is 18 bytes long, and laid into the frame
just before the CRC. Use caution when defining the frame length
so that the Signature does not overwrite important data.

For ATM Terametrics modules set ucProtocolType as STREAM_PROTOCOL_ICMP
when the bound VC is not of BRIDGED encapsulation while set it as
STREAM_PROTOCOL_BRIDGED when the bound VC is of BRIDGED encapsulation

*/
 typedef struct tagStreamICMP
	{
 unsigned char   ucActive;			/* 1=Enable Stream, 0=Disable Stream */
 unsigned char   ucProtocolType;	/* use STREAM_PROTOCOL_ICMP or
                                       STREAM_PROTOCOL_BRIDGED (ATM only)
                                    */
 unsigned char   ucRandomLength;	/*1 = Enable random frame length, 
                                          0 = use uiFrameLength.  
                                          Available on the LAN and POS TeraMetrics modules.
                                          Need to set the minimum and 
                                          maximum random lengths using 
                                          NS_PORT_TRANSMIT when enabled. 
                                  */
 unsigned char   ucRandomData;	/* 1 = Random Data, 0 = use the */
											/* cards background pattern     */
											/* not available on Frame Relay */
 unsigned short  uiFrameLength;	/* frame length not counting CRC*/
											/* 0 - 2048 for Ethernet        */
											/* 0 - 8196 for Frame Relay     */


 /** VFD1 and VFD2 structure members are reserved for later use. Set to 0. **/
 unsigned short  uiVFD1Offset;	/* in bits                      */
 unsigned char   ucVFD1Range;		/* in bits                      */
 unsigned char   ucVFD1Pattern;	/* HVFD_ENABLED, HVFD_STATIC,   */
											/* HVFD_INCR, HVFD_DECR,        */
											/* HVFD_RANDOM, HVFD_NONE       */
 unsigned long   ulVFD1PatternCount;/* from 0(off) to 16,777,215.*/
											/* number to incr. or decr.     */
											/* through when using inc or    */
											/* dec pattern                  */
 unsigned char   ucVFD1StartVal[6];/*the initial VFD byte pattern */

 unsigned short  uiVFD2Offset;	/* in bits                      */
 unsigned char   ucVFD2Range;		/* in bits                      */
 unsigned char   ucVFD2Pattern;	/* HVFD_ENABLED, HVFD_STATIC,   */
											/* HVFD_INCR, HVFD_DECR,        */
											/* HVFD_RANDOM, HVFD_NONE       */
 unsigned long   ulVFD2PatternCount;/* from 0(off) to 16,777,215 */
											/* number to incr. or decr.     */
											/* through when using inc or    */
											/* dec pattern                  */
 unsigned char   ucVFD2StartVal[6];/*the initial VFD byte pattern*/
 /****************************************************************/


 unsigned short  uiVFD3Offset;	/* in bytes                     */
 unsigned short  uiVFD3Range;		/* in bytes                     */
 unsigned char   ucVFD3Enable;	/* HVFD_ENABLED, HVFD_NONE       */

 unsigned char   ucTagField;		/* 0 = off, 1 = insert signature */
											/* field into each frame         */

 unsigned char  DestinationMAC[6];/* the Stream's Dest MAC addr  */
 unsigned char  SourceMAC[6];		/* the Stream's Source MAC addr */
 unsigned char  TypeOfService;	/* The various levels of speed 
                                    and/or reliability           */
 unsigned char  TimeToLive;		/* number of "hops" until frame */
											/* will be dropped */
 unsigned short InitialSequenceNumber;	/* Initial sequence number*/
 unsigned char  DestinationIP[4];/* Dest IP addr(e.g. 192.100.5.3) */
 unsigned char  SourceIP[4];		/* Src IP addr (e.g. 192.100.5.4) */
 unsigned char  Netmask[4];      /*Netmask address (e.g. 255.255.255.0)*/
 unsigned char  Gateway[4];		/* Gateway addr (e.g. 192.100.1.1)*/
 unsigned char  ucType;          /* ICMP Type Number: Echo Request, Reply, etc.*/
 unsigned char  ucCode;          /* ICMP Code field */
 unsigned short uiIdentifier;    /* ICMP Identifier field */
 unsigned char  extra[16];       /* Reserved */
 unsigned long  ulARPOut;        
 unsigned long  ulARPBack;       
 unsigned long  ulARPGap;        
	} StreamICMP;

/* for RTPPayloadType */
#define RTP_PAYLOAD_G711U			0
#define RTP_PAYLOAD_G723_1			4
#define RTP_PAYLOAD_G711A			8
#define RTP_PAYLOAD_G729			18

/*
StreamRTP Description:

This structure contains values for RTP compliant Streams.

A Netcom Systems Signature field, used for Histogram results, is
inserted at the end of the payload if ucTagField is enabled 
(set to 1).

NOTE:  The Signature field is 18 bytes long, and laid into the frame
just before the CRC. Use caution when defining the frame length
so that the Signature does not overwrite important data.

*/
 typedef struct tagStreamRTP
	{
 unsigned char   ucActive;			/* 1=Enable Stream, 0=Disable Stream */
 unsigned char   ucProtocolType;	/* use STREAM_PROTOCOL_RTP      */
 unsigned char   ucRandomLength;	/* Reserved                     */
 unsigned char   ucRandomData;	/* 1 = Random Data, 0 = use the */
											/* cards background pattern     */
											/* not available on Frame Relay */
 unsigned short  uiFrameLength;	/* frame length not counting CRC*/
											/* 0 - 2048 for Ethernet        */
											/* 0 - 8196 for Frame Relay     */


 /** VFD1 and VFD2 structure members are reserved for later use. Set to 0. **/
 unsigned short  uiVFD1Offset;	/* in bits                      */
 unsigned char   ucVFD1Range;		/* in bits                      */
 unsigned char   ucVFD1Pattern;	/* HVFD_ENABLED, HVFD_STATIC,   */
											/* HVFD_INCR, HVFD_DECR,        */
											/* HVFD_RANDOM, HVFD_NONE       */
 unsigned long   ulVFD1PatternCount;/* from 0(off) to 16,777,215.*/
											/* number to incr. or decr.     */
											/* through when using inc or    */
											/* dec pattern                  */
 unsigned char   ucVFD1StartVal[6];/*the initial VFD byte pattern */

 unsigned short  uiVFD2Offset;	/* in bits                      */
 unsigned char   ucVFD2Range;		/* in bits                      */
 unsigned char   ucVFD2Pattern;	/* HVFD_ENABLED, HVFD_STATIC,   */
											/* HVFD_INCR, HVFD_DECR,        */
											/* HVFD_RANDOM, HVFD_NONE       */
 unsigned long   ulVFD2PatternCount;/* from 0(off) to 16,777,215 */
											/* number to incr. or decr.     */
											/* through when using inc or    */
											/* dec pattern                  */
 unsigned char   ucVFD2StartVal[6];/*the initial VFD byte pattern*/
 /****************************************************************/


 unsigned short  uiVFD3Offset;	/* in bytes                     */
 unsigned short  uiVFD3Range;		/* in bytes                     */
 unsigned char   ucVFD3Enable;	/* HVFD_ENABLED, HVFD_NONE       */

 unsigned char   ucTagField;		/* 0 = off, 1 = insert signature */
											/* field into each frame         */

 unsigned char    DestinationMAC[6];      /* the Stream's Dest MAC addr    */
 unsigned char	   SourceMAC[6];           /* the Stream's Source MAC addr  */
 unsigned char	   TypeOfService;          /* The various levels of speed 
                                             and/or reliability            */
 unsigned char	   TimeToLive;             /* number of "hops" until frame 
											            will be dropped               */
 unsigned short	InitialSequenceNumber;  /* Initial sequence number       */
 unsigned char	   DestinationIP[4];       /* Dest IP addr(e.g. 192.100.5.3)*/
 unsigned char	   SourceIP[4];            /* Src IP addr (e.g. 192.100.5.4)*/
 unsigned char	   Netmask[4];             /* Network Mask (e.g. 255.255.0.0)*/
 unsigned char	   Gateway[4];             /* Gateway addr (e.g. 192.100.1.1)*/
 unsigned short	UDPSrc;                 /*	UDP Source Port                */
 unsigned short	UDPDest;                /*	UDP Destination Port           */
 unsigned short	UDPLen;                 /* UDP Length field - not used    */
 unsigned char    extra1[2];              /* reserved                       */
 unsigned long		RTPSyncSource;          /* RTP Syncronization Source ID  */
 unsigned char		RTPPayloadType;         /* RTP Payload type must be one of
                                             RTP_PAYLOAD_G711A
                                             RTP_PAYLOAD_G711U
                                             RTP_PAYLOAD_G729
                                             RTP_PAYLOAD_G723_1            */
 unsigned char  ucUDPChecksumEnable;      /* Only applicable for the LAN-3101A, LAN-3101B cards.
                                             0 = disable, 1 = enable
                                     */                                       
 unsigned char	   extra2[18];             /* reserved                      */
 } StreamRTP;


/*
StreamRTPVLAN Description:

This structure contains values for RTP compliant Streams with VLAN
tagging.

A Netcom Systems Signature field, used for Histogram results, is
inserted at the end of the payload if ucTagField is enabled 
(set to 1).

NOTE:  The Signature field is 18 bytes long, and laid into the frame
just before the CRC. Use caution when defining the frame length
so that the Signature does not overwrite important data.

*/
 typedef struct tagStreamRTPVLAN
	{
 unsigned char   ucActive;			/* 1=Enable Stream, 0=Disable Stream */
 unsigned char   ucProtocolType;	/* use STREAM_PROTOCOL_RTP_VLAN */
 unsigned char   ucRandomLength;	/* Reserved                     */
 unsigned char   ucRandomData;	/* 1 = Random Data, 0 = use the */
											/* cards background pattern     */
											/* not available on Frame Relay */
 unsigned short  uiFrameLength;	/* frame length not counting CRC*/
											/* 0 - 2048 for Ethernet        */
											/* 0 - 8196 for Frame Relay     */


 /** VFD1 and VFD2 structure members are reserved for later use. Set to 0. **/
 unsigned short  uiVFD1Offset;	/* in bits                      */
 unsigned char   ucVFD1Range;		/* in bits                      */
 unsigned char   ucVFD1Pattern;	/* HVFD_ENABLED, HVFD_STATIC,   */
											/* HVFD_INCR, HVFD_DECR,        */
											/* HVFD_RANDOM, HVFD_NONE       */
 unsigned long   ulVFD1PatternCount;/* from 0(off) to 16,777,215.*/
											/* number to incr. or decr.     */
											/* through when using inc or    */
											/* dec pattern                  */
 unsigned char   ucVFD1StartVal[6];/*the initial VFD byte pattern */

 unsigned short  uiVFD2Offset;	/* in bits                      */
 unsigned char   ucVFD2Range;		/* in bits                      */
 unsigned char   ucVFD2Pattern;	/* HVFD_ENABLED, HVFD_STATIC,   */
											/* HVFD_INCR, HVFD_DECR,        */
											/* HVFD_RANDOM, HVFD_NONE       */
 unsigned long   ulVFD2PatternCount;/* from 0(off) to 16,777,215 */
											/* number to incr. or decr.     */
											/* through when using inc or    */
											/* dec pattern                  */
 unsigned char   ucVFD2StartVal[6];/*the initial VFD byte pattern*/
 /****************************************************************/


 unsigned short  uiVFD3Offset;	/* in bytes                     */
 unsigned short  uiVFD3Range;		/* in bytes                     */
 unsigned char   ucVFD3Enable;	/* HVFD_ENABLED, HVFD_NONE       */

 unsigned char   ucTagField;		/* 0 = off, 1 = insert signature */
											/* field into each frame         */

 unsigned char 	DestinationMAC[6];      /* the Stream's Dest MAC addr    */
 unsigned char   	SourceMAC[6];           /* the Stream's Source MAC addr  */
 unsigned char   	TypeOfService;          /* The various levels of speed 
                                             and/or reliability            */
 unsigned char   	TimeToLive;             /* number of "hops" until frame 
											            will be dropped               */
 unsigned short	InitialSequenceNumber;  /* Initial sequence number       */
 unsigned char	  	DestinationIP[4];       /* Dest IP addr(e.g. 192.100.5.3)*/
 unsigned char	  	SourceIP[4];            /* Src IP addr (e.g. 192.100.5.4)*/
 unsigned char	  	Netmask[4];             /* Network Mask (e.g. 255.255.0.0)*/
 unsigned char	  	Gateway[4];             /* Gateway addr (e.g. 192.100.1.1)*/
 unsigned short	UDPSrc;                 /*	UDP Source Port                */
 unsigned short	UDPDest;                /*	UDP Destination Port           */
 unsigned short	UDPLen;                 /* UDP Length field - not used    */
 unsigned long		RTPSyncSource;          /* RTP Syncronization Source ID   */
 unsigned char		RTPPayloadType;         /* RTP Payload type must be one of
                                             RTP_PAYLOAD_G711A
                                             RTP_PAYLOAD_G711U
                                             RTP_PAYLOAD_G729
                                             RTP_PAYLOAD_G723_1            */
 unsigned short VLAN_Pri;                 /*VLAN Priority: available constants
                                             VLAN_PRI_0 VLAN_PRI_1 VLAN_PRI_2 VLAN_PRI_3
                                             VLAN_PRI_4 VLAN_PRI_5 VLAN_PRI_6 VLAN_PRI_7
                                             VLAN_PRI_LOWEST VLAN_PRI_HIGHEST */

 unsigned short VLAN_Cfi;                 /*VLAN CFI bit: available constants
                                             VLAN_CFI_RIF_ABSENT  VLAN_CFI_RIF_PRESENT */

 unsigned short VLAN_Vid;                 /*VLAN identifier */
 unsigned char  ucUDPChecksumEnable;      /* Only applicable for the LAN-3101A, LAN-3101B cards.
                                             0 = disable, 1 = enable
                                          */                                       
 unsigned char	  	extra[18];              /* reserved                      */
 } StreamRTPVLAN;


/* IPv6 streams */

/*
StreamIPv6 Description:

This structure contains values for IPv6 compliant Streams.

A Netcom Systems Signature field, used for Histogram results, is
inserted at the end of the payload if ucTagField is enabled 
(set to 1).

NOTE:  

The Signature field is 18 bytes long, and laid into the frame
just before the CRC. Use caution when defining the frame length
so that the Signature does not overwrite important data.

Use L3_START_ARPS to perform neighbor discovery for each stream.
Only LAN cards currently have neighbor discovery capability.
  
For ATM Terametrics modules set ucProtocolType as STREAM_PROTOCOL_IPV6
when the bound VC is not of BRIDGED encapsulation while set it as
STREAM_PROTOCOL_BRIDGED when the bound VC is of BRIDGED encapsulation

Note for ucRandomLength:
1.	For the 1st generation Terametrics cards (LAN-330x/331x), ucRandomLength
    is supported when the start of IP (either IPv4 or IPv6) occurs
    at byte 63 or less.
2.	For the 2nd generation Terametrics cards (LAN-332x), ucRandomLength
    is supported when the start of IP (either IPv4 or IPv6) occurs at byte 127
    or less.
*/
typedef struct tagStreamIPv6 {
	unsigned char   ucActive;           /* 1=Enable Stream, 0=Disable Stream*/
	unsigned char   ucProtocolType;     /* use STREAM_PROTOCOL_IPV6, or
                                               STREAM_PROTOCOL_BRIDGED (ATM only)
                                          */
	unsigned char   ucRandomLength;     /* 1 = Enable random frame length, 
                                          0 = use uiFrameLength.  
                                          Available on the LAN-33XX and
                                          POS-35XX(except POS-3500/3502) cards.  
                                          Need to set the minimum and 
                                          maximum random lengths using 
                                          NS_PORT_TRANSMIT when enabled. */
	unsigned char   ucRandomData;       /* 1 = Random Data, 0 = use the
                                           cards background pattern */
   	unsigned short  uiFrameLength;      /* frame length not counting CRC */

	/*****************************************************************
	*                                                                *
	*   The VFD1, VFD2, and VFD3 structure members                   *
	* are reserved for later use. Set to 0.                          *
	*****************************************************************/

	unsigned short  uiVFD1Offset;       /* in bits							*/
	unsigned char   ucVFD1Range;        /* in bits							*/
	unsigned char   ucVFD1Pattern;      /* HVFD_ENABLED, HVFD_STATIC,	*/
                                        /* HVFD_INCR, HVFD_DECR,      */
                                        /* HVFD_RANDOM, HVFD_NONE     */
	unsigned long   ulVFD1PatternCount; /* from 0(off) to 16,777,215	*/
										/* number to incr. or decr.   */
										/* through when using inc or  */
										/* dec pattern                */
	unsigned char   ucVFD1StartVal[6];	/*the initial VFD byte pattern*/

	unsigned short  uiVFD2Offset;       /* in bits */
	unsigned char   ucVFD2Range;        /* in bits */
	unsigned char   ucVFD2Pattern;      /* HVFD_ENABLED, HVFD_STATIC, */
										/* HVFD_INCR, HVFD_DECR,      */
										/* HVFD_RANDOM, HVFD_NONE     */
	unsigned long   ulVFD2PatternCount;	/* from 0(off) to 16,777,215  */
										/* number to incr. or decr.   */
										/* through when using inc or  */
										/* dec pattern                */
	unsigned char   ucVFD2StartVal[6];	/*the initial VFD byte pattern*/

	unsigned short  uiVFD3Offset;       /* in bytes	*/
	unsigned short  uiVFD3Range;		/* in bytes	*/
	unsigned char   ucVFD3Enable;		/* HVFD_ENABLED, HVFD_NONE */
	/****************************************************************************/

	unsigned char   ucTagField;           /* 0 = off, 1 = insert Signature	*/
                                          /* field into each frame			*/
	unsigned char	DestinationMAC[6];    /* Destination MAC address  */
	unsigned char	SourceMAC[6];         /* Source MAC address */
	unsigned char 	ucTrafficClass;       /* Packet priority */
	unsigned char	ucNextHeader;         /* identifies the header type immediately
                                             following the IPV6 header */
	unsigned char 	ucHopLimit;           /* number of "hops" until frame */
                                          /* will be dropped */
	unsigned long 	ulFlowLabel;          /* label packets to request special handling */
	unsigned char 	SourceIP[16];         /* Source IPv6 address (e.g. 192.100.5.....4) */
	unsigned char 	DestinationIP[16];    /* Destination IPv6 address (e.g. 192.100.5.....4) */
	unsigned char	RouterIP[16];         /* Similar to gateway address */	
	unsigned char	ucPayloadLengthError; /* 0 - disable, 1 - enable, generate
                                             frame length error */
} StreamIPv6;


/*
StreamUDPIPv6 Description:

This structure contains values for UDP IPv6 compliant Streams.

A Netcom Systems Signature field, used for Histogram results, is
inserted at the end of the payload if ucTagField is enabled 
(set to 1).

NOTE:  

The Signature field is 18 bytes long, and laid into the frame
just before the CRC. Use caution when defining the frame length
so that the Signature does not overwrite important data.

Use L3_START_ARPS to perform neighbor discovery for each stream.
Only LAN cards currently have neighbor discovery capability.

For ATM Terametrics modules set ucProtocolType as STREAM_PROTOCOL_UDP_IPV6
when the bound VC is not of BRIDGED encapsulation while set it as
STREAM_PROTOCOL_BRIDGED when the bound VC is of BRIDGED encapsulation

Note for ucRandomLength:
1.	For the 1st generation Terametrics cards (LAN-330x/331x), ucRandomLength
    is supported when the start of IP (either IPv4 or IPv6) occurs
    at byte 63 or less.
2.	For the 2nd generation Terametrics cards (LAN-332x), ucRandomLength
    is supported when the start of IP (either IPv4 or IPv6) occurs at byte 127
    or less.
*/
typedef struct tagStreamUDPIPv6
{
	unsigned char   ucActive;           /* 1=Enable Stream, 0=Disable Stream*/
	unsigned char   ucProtocolType;     /* use STREAM_PROTOCOL_UDP_IPV6, or
                                               STREAM_PROTOCOL_BRIDGED (ATM only)
                                          */
	unsigned char   ucRandomLength;     /* 1 = Enable random frame length, 
                                          0 = use uiFrameLength.  
                                          Available on the LAN-33XX and
                                          POS-35XX(except POS-3500/3502) cards.  
                                          Need to set the minimum and 
                                          maximum random lengths using 
                                          NS_PORT_TRANSMIT when enabled. */
	unsigned char   ucRandomData;       /* 1 = Random Data, 0 = use the
                                           cards background pattern	*/
	unsigned short  uiFrameLength;      /* frame length not counting CRC */

	/*****************************************************************
	*                                                                *
	*  For ETHERNET, cards VFD1, VFD2, and VFD3 structure members    *
	* are reserved for later use. Set to 0.                          *
	*****************************************************************/

	unsigned short  uiVFD1Offset;			/* in bits							*/
	unsigned char   ucVFD1Range;			/* in bits							*/
	unsigned char   ucVFD1Pattern;		/* HVFD_ENABLED, HVFD_STATIC,	*/
													/* HVFD_INCR, HVFD_DECR,      */
													/* HVFD_RANDOM, HVFD_NONE     */
	unsigned long   ulVFD1PatternCount;	/* from 0(off) to 16,777,215	*/
													/* number to incr. or decr.   */
													/* through when using inc or  */
													/* dec pattern                */
	unsigned char   ucVFD1StartVal[6];	/*the initial VFD byte pattern*/
	unsigned short  uiVFD2Offset;			/* in bits							*/
	unsigned char   ucVFD2Range;			/* in bits							*/
	unsigned char   ucVFD2Pattern;		/* HVFD_ENABLED, HVFD_STATIC,	*/
													/* HVFD_INCR, HVFD_DECR,      */
													/* HVFD_RANDOM, HVFD_NONE     */
	unsigned long   ulVFD2PatternCount;	/* from 0(off) to 16,777,215  */
													/* number to incr. or decr.   */
													/* through when using inc or  */
													/* dec pattern                */
	unsigned char   ucVFD2StartVal[6];	/*the initial VFD byte pattern*/
	unsigned short  uiVFD3Offset;			/* in bytes							*/
	unsigned short  uiVFD3Range;			/* in bytes							*/
	unsigned char   ucVFD3Enable;			/* HVFD_ENABLED, HVFD_NONE		*/
	/****************************************************************************/

	unsigned char   ucTagField;           /* 0 = off, 1 = insert Signature
										     field into each frame */
	unsigned char	DestinationMAC[6];    /* Destination MAC address  */
	unsigned char	SourceMAC[6];         /* Source MAC address */
	unsigned char 	ucTrafficClass;	      /* Packet priority */
	unsigned char	ucNextHeader;         /* Identifies the header type immediately
                                             following the IPV6 header */
	unsigned char 	ucHopLimit;           /* Number of "hops" until frame will be dropped */
	unsigned long 	ulFlowLabel;          /* Label packets to request special handling */
	unsigned char 	SourceIP[16];         /* Source IPv6 address (e.g. 192.100.5.....4) */	
	unsigned char 	DestinationIP[16];    /* Destination IPv6 address (e.g. 192.100.5.....4) */
	unsigned char	RouterIP[16];		  /* Gateway address */	
	unsigned char	ucPayloadLengthError; /* 0 - disable, 1 - enable, generate frame
	                                         length error */
	unsigned short	UDPSrc;               /* UDP Source Port */
	unsigned short	UDPDest;              /* UDP Dest Port */
	unsigned short	UDPLen;               /* UDP Length field (currently not used) */
} StreamUDPIPv6;


/*
StreamTCPIPv6 Description:

This structure contains values for TCP IPv6 compliant Streams.

A Netcom Systems Signature field, used for Histogram results, is
inserted at the end of the payload if ucTagField is enabled
(set to 1).

IMPORTANT: Before defining streams with this command, you must use NS_PORT_TRANSMIT(NSPortTransmit)
to set the ucEnableExtendedPayload field to 1. This enables the 128-byte header length to
accommodate the longer stream header. When you do this, the maximum number of streams that can be
defined is reduced to half: from 512 to 256 (this applies to all TeraMetrics modules except the
POS-3518A/3519A). In addition, any time you switch between enabling and disabling the extended
payload, all currently configured streams will be deleted. 

NOTE:  

The Signature field is 18 bytes long, and laid into the frame
just before the CRC. Use caution when defining the frame length
so that the Signature does not overwrite important data.

Use L3_START_ARPS to perform neighbor discovery for each stream.
Only LAN cards currently have neighbor discovery capability.

For ATM Terametrics modules set ucProtocolType as STREAM_PROTOCOL_TCP_IPV6
when the bound VC is not of BRIDGED encapsulation while set it as
STREAM_PROTOCOL_BRIDGED when the bound VC is of BRIDGED encapsulation

Note for ucRandomLength:
1.	For the 1st generation Terametrics cards (LAN-330x/331x), ucRandomLength
    is supported when the start of IP (either IPv4 or IPv6) occurs
    at byte 63 or less.
2.	For the 2nd generation Terametrics cards (LAN-332x), ucRandomLength
    is supported when the start of IP (either IPv4 or IPv6) occurs at byte 127
    or less.
*/
typedef struct tagStreamTCPIPv6
{
	unsigned char   ucActive;           /* 1=Enable Stream, 0=Disable Stream */
	unsigned char   ucProtocolType;     /* use STREAM_PROTOCOL_TCP_IPV6
                                               STREAM_PROTOCOL_BRIDGED (ATM only)
                                          */
	unsigned char   ucRandomLength;     /* 1 = Enable random frame length, 
                                          0 = use uiFrameLength
                                          Available on the LAN-33XX and
                                          POS-35XX(except POS-3500/3502) cards.  
                                          Need to set the minimum and 
                                          maximum random lengths using 
                                          NS_PORT_TRANSMIT when enabled. */
	unsigned char   ucRandomData;       /* 1 = Random Data, 0 = use the
                                           cards background pattern	*/
	unsigned short  uiFrameLength;      /* frame length not counting CRC */

	/*****************************************************************
	*                                                                *
	*  For ETHERNET, cards VFD1, VFD2, and VFD3 structure members    *
	* are reserved for later use. Set to 0.                          *
	*****************************************************************/

	unsigned short  uiVFD1Offset;			/* in bits							*/
	unsigned char   ucVFD1Range;			/* in bits							*/
	unsigned char   ucVFD1Pattern;		/* HVFD_ENABLED, HVFD_STATIC,	*/
													/* HVFD_INCR, HVFD_DECR,      */
													/* HVFD_RANDOM, HVFD_NONE     */
	unsigned long   ulVFD1PatternCount;	/* from 0(off) to 16,777,215	*/
													/* number to incr. or decr.   */
													/* through when using inc or  */
													/* dec pattern                */
	unsigned char   ucVFD1StartVal[6];	/*the initial VFD byte pattern*/


	unsigned short  uiVFD2Offset;			/* in bits							*/
	unsigned char   ucVFD2Range;			/* in bits							*/
	unsigned char   ucVFD2Pattern;		/* HVFD_ENABLED, HVFD_STATIC,	*/
													/* HVFD_INCR, HVFD_DECR,      */
													/* HVFD_RANDOM, HVFD_NONE     */
	unsigned long   ulVFD2PatternCount;	/* from 0(off) to 16,777,215  */
													/* number to incr. or decr.   */
													/* through when using inc or  */
													/* dec pattern                */
	unsigned char   ucVFD2StartVal[6];	/*the initial VFD byte pattern*/


	unsigned short  uiVFD3Offset;			/* in bytes							*/
	unsigned short  uiVFD3Range;			/* in bytes							*/
	unsigned char   ucVFD3Enable;			/* HVFD_ENABLED, HVFD_NONE		*/
	/****************************************************************************/

	unsigned char   ucTagField;           /* 0 = off, 1 = insert Signature field into each frame */
	unsigned char	DestinationMAC[6];    /* Destination MAC address  */
	unsigned char	SourceMAC[6];		  /* Source MAC address */
	unsigned char 	ucTrafficClass;       /* Packet priority */
	unsigned char	ucNextHeader;         /* identifies the header type immediately
	                                         following the IPV6 header */
	unsigned char 	ucHopLimit;           /* Number of "hops" until frame will be dropped */
	unsigned long 	ulFlowLabel;          /* Label packets to request special handling */
	unsigned char 	SourceIP[16];         /* Source IP address (e.g. 192.100.5.....4) */	
	unsigned char 	DestinationIP[16];    /* Destination IP address (e.g. 192.100.5.....4) */
	unsigned char	RouterIP[16];		  /* Gateway address */	
	unsigned char	ucPayloadLengthError; /* 0 - disable, 1 - enable, generate frame
	                                         length error */
	unsigned short	SourcePort;           /* Source port */
	unsigned short	DestPort;             /* Destination port */
	unsigned short	Window;               /* Protocol window size, in bytes */
	unsigned long	TCPAck;               /* Acknowledgment number */
	unsigned long	TCPSequence;          /* TCP Sequence number */
	unsigned char	Flags;                /* use TCP_FLAG_XXX defines */
	unsigned char	extra[3];             /* Reserved */
} StreamTCPIPv6;


/*
StreamIPv6VLAN Description:

This structure contains values for IPv6 compliant Streams that use VLAN tagging.

A Netcom Systems Signature field, used for Histogram results, is
inserted at the end of the payload if ucTagField is enabled
(set to 1).

NOTE:  

The Signature field is 18 bytes long, and laid into the frame
just before the CRC. Use caution when defining the frame length
so that the Signature does not overwrite important data.

Use L3_START_ARPS to perform neighbor discovery for each stream.
Only LAN cards currently have neighbor discovery capability.

Note for ucRandomLength:
1.	For the 1st generation Terametrics cards (LAN-330x/331x), ucRandomLength
    is supported when the start of IP (either IPv4 or IPv6) occurs
    at byte 63 or less.
2.	For the 2nd generation Terametrics cards (LAN-332x), ucRandomLength
    is supported when the start of IP (either IPv4 or IPv6) occurs at byte 127
    or less.
*/
typedef struct tagStreamIPv6VLAN {
	unsigned char   ucActive;           /* 1=Enable Stream, 0=Disable Stream */
	unsigned char   ucProtocolType;     /* Use STREAM_PROTOCOL_IPV6_VLAN */

	unsigned char   ucRandomLength;     /* 1 = Enable random frame length, 
                                          0 = use uiFrameLength.
                                          Available on the LAN-33XX and
                                          POS-35XX(except POS-3500/3502) cards.  
                                          Need to set the minimum and 
                                          maximum random lengths using 
                                          NS_PORT_TRANSMIT when enabled. */
	unsigned char   ucRandomData;       /* 1 = Random Data, 0 = use the cards background pattern */
	unsigned short  uiFrameLength;      /* Frame length not counting CRC */

	/*****************************************************************
	*                                                                *
	*  For ETHERNET, cards VFD1, VFD2, and VFD3 structure members    *
	* are reserved for later use. Set to 0.                          *
	*****************************************************************/

	unsigned short  uiVFD1Offset;			/* in bits							*/
	unsigned char   ucVFD1Range;			/* in bits							*/
	unsigned char   ucVFD1Pattern;		/* HVFD_ENABLED, HVFD_STATIC,	*/
													/* HVFD_INCR, HVFD_DECR,      */
													/* HVFD_RANDOM, HVFD_NONE     */
	unsigned long   ulVFD1PatternCount;	/* from 0(off) to 16,777,215	*/
													/* number to incr. or decr.   */
													/* through when using inc or  */
													/* dec pattern                */
	unsigned char   ucVFD1StartVal[6];	/*the initial VFD byte pattern*/


	unsigned short  uiVFD2Offset;			/* in bits							*/
	unsigned char   ucVFD2Range;			/* in bits							*/
	unsigned char   ucVFD2Pattern;		/* HVFD_ENABLED, HVFD_STATIC,	*/
													/* HVFD_INCR, HVFD_DECR,      */
													/* HVFD_RANDOM, HVFD_NONE     */
	unsigned long   ulVFD2PatternCount;	/* from 0(off) to 16,777,215  */
													/* number to incr. or decr.   */
													/* through when using inc or  */
													/* dec pattern                */
	unsigned char   ucVFD2StartVal[6];	/*the initial VFD byte pattern*/


	unsigned short  uiVFD3Offset;			/* in bytes							*/
	unsigned short  uiVFD3Range;			/* in bytes							*/
	unsigned char   ucVFD3Enable;			/* HVFD_ENABLED, HVFD_NONE		*/
	/****************************************************************************/

	unsigned char   ucTagField;         /* 0 = off, 1 = insert Signature field into each frame */
	unsigned char	DestinationMAC[6];  /* Destination MAC address */
	unsigned char	SourceMAC[6];       /* Source MAC address */
	unsigned char 	ucTrafficClass;     /* Packet priority */
	unsigned char	ucNextHeader;       /* identifies the type header type immediately
                                           following the IPV6 header */
	unsigned char 	ucHopLimit;         /* Number of "hops" until frame will be dropped */
	unsigned long 	ulFlowLabel;        /* label packets to request special handling */
	unsigned char 	SourceIP[16];       /* Source IP address (e.g. 192.100.5.....4)	*/	
	unsigned char 	DestinationIP[16];  /* Destination IP address (e.g. 192.100.5.....4) */
	unsigned char	RouterIP[16];       /* Gateway address */
	unsigned char	ucPayloadLengthError; /* 0 - disable, 1 - enable, generates
                                             error in frame length */
	unsigned short VLAN_Pri;            /* VLAN Priority: available constants
                                           VLAN_PRI_0 VLAN_PRI_1 VLAN_PRI_2 VLAN_PRI_3
                                           VLAN_PRI_4 VLAN_PRI_5 VLAN_PRI_6 VLAN_PRI_7
                                           VLAN_PRI_LOWEST VLAN_PRI_HIGHEST */
	unsigned short VLAN_Cfi;            /* VLAN CFI bit: available constants
                                           VLAN_CFI_RIF_ABSENT  VLAN_CFI_RIF_PRESENT */
	unsigned short VLAN_Vid;            /* VLAN identifier */
} StreamIPv6VLAN;



/*
StreamUDPIPv6VLAN Description:

This structure is contains values for UDP IPv6 compliant 
Streams with VLAN tagging.

A Netcom Systems Signature field, used for Histogram results, is
inserted at the end of the payload if ucTagField is enabled 
(set to 1).

IMPORTANT: Before defining streams with this command, you must use NS_PORT_TRANSMIT(NSPortTransmit)
to set the ucEnableExtendedPayload field to 1. This enables the 128-byte header length to
accommodate the longer stream header. When you do this, the maximum number of streams that can be
defined is reduced to half: from 512 to 256 (this applies to all TeraMetrics modules except the
POS-3518A/3519A). In addition, any time you switch between enabling and disabling the extended
payload, all currently configured streams will be deleted. 

NOTE:  

The Signature field is 18 bytes long, and laid into the frame
just before the CRC. Use caution when defining the frame length
so that the Signature does not overwrite important data.

Use L3_START_ARPS to perform neighbor discovery for each stream.
Only LAN cards currently have neighbor discovery capability.

Note for ucRandomLength:
1.	For the 1st generation Terametrics cards (LAN-330x/331x), ucRandomLength
    is supported when the start of IP (either IPv4 or IPv6) occurs
    at byte 63 or less.
2.	For the 2nd generation Terametrics cards (LAN-332x), ucRandomLength
    is supported when the start of IP (either IPv4 or IPv6) occurs at byte 127
    or less.
*/
typedef struct tagStreamUDPIPv6VLAN {
	unsigned char   ucActive;           /* 1=Enable Stream, 0=Disable Stream */
	unsigned char   ucProtocolType;     /* use STREAM_PROTOCOL_UDP_IPV6_VLAN */

	unsigned char   ucRandomLength;     /* 1 = Enable random frame length, 
                                          0 = use uiFrameLength.  
                                          Available on the LAN-33XX and 
                                          POS-35XX(except POS-3500/3502) cards.  
                                          Need to set the minimum and 
                                          maximum random lengths using 
                                          NS_PORT_TRANSMIT when enabled. */
	unsigned char   ucRandomData;       /* 1 = Random Data, 0 = use the cards background pattern */
	unsigned short  uiFrameLength;      /* frame length not counting CRC */

	/*****************************************************************
	*                                                                *
	*  For ETHERNET, cards VFD1, VFD2, and VFD3 structure members    *
	* are reserved for later use. Set to 0.                          *
	*****************************************************************/

	unsigned short  uiVFD1Offset;			/* in bits							*/
	unsigned char   ucVFD1Range;			/* in bits							*/
	unsigned char   ucVFD1Pattern;		/* HVFD_ENABLED, HVFD_STATIC,	*/
													/* HVFD_INCR, HVFD_DECR,      */
													/* HVFD_RANDOM, HVFD_NONE     */
	unsigned long   ulVFD1PatternCount;	/* from 0(off) to 16,777,215	*/
													/* number to incr. or decr.   */
													/* through when using inc or  */
													/* dec pattern                */
	unsigned char   ucVFD1StartVal[6];	/*the initial VFD byte pattern*/


	unsigned short  uiVFD2Offset;			/* in bits							*/
	unsigned char   ucVFD2Range;			/* in bits							*/
	unsigned char   ucVFD2Pattern;		/* HVFD_ENABLED, HVFD_STATIC,	*/
													/* HVFD_INCR, HVFD_DECR,      */
													/* HVFD_RANDOM, HVFD_NONE     */
	unsigned long   ulVFD2PatternCount;	/* from 0(off) to 16,777,215  */
													/* number to incr. or decr.   */
													/* through when using inc or  */
													/* dec pattern                */
	unsigned char   ucVFD2StartVal[6];	/*the initial VFD byte pattern*/


	unsigned short  uiVFD3Offset;			/* in bytes							*/
	unsigned short  uiVFD3Range;			/* in bytes							*/
	unsigned char   ucVFD3Enable;			/* HVFD_ENABLED, HVFD_NONE		*/
	/****************************************************************************/

	unsigned char   ucTagField;         /* 0 = off, 1 = insert Signature field into each frame */
	unsigned char	DestinationMAC[6];  /* Destination MAC address */
	unsigned char	SourceMAC[6];		/* Source MAC address */
	unsigned char 	ucTrafficClass;     /* Packet priority */
	unsigned char	ucNextHeader;       /* identifies the header type immediately
                                           following the IPV6 header */
	unsigned char 	ucHopLimit;         /* Number of "hops" until frame will be dropped */
	unsigned long 	ulFlowLabel;        /* Label packets to request special handling */
	unsigned char 	SourceIP[16];       /* Source IP address (e.g. 192.100.5.....4)	*/
	unsigned char 	DestinationIP[16];  /* Destination IP address (e.g. 192.100.5.....4) */
	unsigned char	RouterIP[16];       /* Gateway address */	
	unsigned char	ucPayloadLengthError; /* 0 - disable, 1 - enable, generates
                                             error in frame length */
	unsigned short	UDPSrc;             /* UDP Source Port              */
	unsigned short	UDPDest;            /* UDP Dest Port                */
	unsigned short	UDPLen;             /* UDP Length field - not used  */
	unsigned short VLAN_Pri;            /* VLAN Priority: available constants
                                           VLAN_PRI_0 VLAN_PRI_1 VLAN_PRI_2 VLAN_PRI_3
                                           VLAN_PRI_4 VLAN_PRI_5 VLAN_PRI_6 VLAN_PRI_7
                                           VLAN_PRI_LOWEST VLAN_PRI_HIGHEST */
	unsigned short VLAN_Cfi;            /* VLAN CFI bit: available constants
                                           VLAN_CFI_RIF_ABSENT  VLAN_CFI_RIF_PRESENT */
	unsigned short VLAN_Vid;            /* VLAN identifier */
} StreamUDPIPv6VLAN;



/*
StreamTCPIPv6VLAN Description:

This structure contains values for TCP IPv6 compliant Streams with VLAN
tagging.

A Netcom Systems Signature field, used for Histogram results, is
inserted at the end of the payload if ucTagField is enabled
(set to 1).

IMPORTANT: Before defining streams with this command, you must use NS_PORT_TRANSMIT(NSPortTransmit)
to set the ucEnableExtendedPayload field to 1. This enables the 128-byte header length to
accommodate the longer stream header. When you do this, the maximum number of streams that can be
defined is reduced to half: from 512 to 256 (this applies to all TeraMetrics modules except the
POS-3518A/3519A). In addition, any time you switch between enabling and disabling the extended
payload, all currently configured streams will be deleted. 

NOTE:  

The Signature field is 18 bytes long, and laid into the frame
just before the CRC. Use caution when defining the frame length
so that the Signature does not overwrite important data.

Use L3_START_ARPS to perform neighbor discovery for each stream.
Only LAN cards currently have neighbor discovery capability.

Note for ucRandomLength:
1.	For the 1st generation Terametrics cards (LAN-330x/331x), ucRandomLength
    is supported when the start of IP (either IPv4 or IPv6) occurs
    at byte 63 or less.
2.	For the 2nd generation Terametrics cards (LAN-332x), ucRandomLength
    is supported when the start of IP (either IPv4 or IPv6) occurs at byte 127
    or less.
*/
typedef struct tagStreamTCPIPv6VLAN {
	unsigned char   ucActive;           /* 1=Enable Stream, 0=Disable Stream */
	unsigned char   ucProtocolType;     /* use STREAM_PROTOCOL_TCP_IPV6_VLAN */
	unsigned char   ucRandomLength;     /* 1 = Enable random frame length, 
                                          0 = use uiFrameLength.
                                          Available on the LAN-33XX and 
                                          POS-35XX(except POS-3500/3502) cards.  
                                          Need to set the minimum and 
                                          maximum random lengths using 
                                          NS_PORT_TRANSMIT when enabled. */

	unsigned char   ucRandomData;       /* 1 = Random Data, 0 = use the cards background pattern */
	unsigned short  uiFrameLength;      /* frame length not counting CRC */

	/*****************************************************************
	*                                                                *
	*  For ETHERNET, cards VFD1, VFD2, and VFD3 structure members    *
	* are reserved for later use. Set to 0.                          *
	*****************************************************************/

	unsigned short  uiVFD1Offset;			/* in bits							*/
	unsigned char   ucVFD1Range;			/* in bits							*/
	unsigned char   ucVFD1Pattern;		/* HVFD_ENABLED, HVFD_STATIC,	*/
													/* HVFD_INCR, HVFD_DECR,      */
													/* HVFD_RANDOM, HVFD_NONE     */
	unsigned long   ulVFD1PatternCount;	/* from 0(off) to 16,777,215	*/
													/* number to incr. or decr.   */
													/* through when using inc or  */
													/* dec pattern                */
	unsigned char   ucVFD1StartVal[6];	/*the initial VFD byte pattern*/


	unsigned short  uiVFD2Offset;			/* in bits							*/
	unsigned char   ucVFD2Range;			/* in bits							*/
	unsigned char   ucVFD2Pattern;		/* HVFD_ENABLED, HVFD_STATIC,	*/
													/* HVFD_INCR, HVFD_DECR,      */
													/* HVFD_RANDOM, HVFD_NONE     */
	unsigned long   ulVFD2PatternCount;	/* from 0(off) to 16,777,215  */
													/* number to incr. or decr.   */
													/* through when using inc or  */
													/* dec pattern                */
	unsigned char   ucVFD2StartVal[6];	/*the initial VFD byte pattern*/


	unsigned short  uiVFD3Offset;			/* in bytes							*/
	unsigned short  uiVFD3Range;			/* in bytes							*/
	unsigned char   ucVFD3Enable;			/* HVFD_ENABLED, HVFD_NONE		*/
	/****************************************************************************/

	unsigned char   ucTagField;         /* 0 = off, 1 = insert Signature field into each frame */
	unsigned char	DestinationMAC[6];  /* Destination MAC address */
	unsigned char	SourceMAC[6];       /* Source MAC address */
	unsigned char 	ucTrafficClass;     /* Packet priority */
	unsigned char	ucNextHeader;       /* identifies the header type immediately
                                           following the IPV6 header */
	unsigned char 	ucHopLimit;         /* Number of "hops" until frame will be dropped */
	unsigned long 	ulFlowLabel;        /* label packets to request special handling */
	unsigned char 	SourceIP[16];       /* Source IP address (e.g. 192.100.5.....4) */
	unsigned char 	DestinationIP[16];  /* Destination IP address (e.g. 192.100.5.....4) */
	unsigned char	RouterIP[16];       /* Gateway address */
	unsigned char	ucPayloadLengthError; /* 0 - disable, 1 - enable, generates error in frame length */
	unsigned short	SourcePort;      /* Source Port */
	unsigned short	DestPort;        /* Destination Port */
	unsigned short	Window;          /* Window size, in bytes*/
	unsigned long	TCPAck;          /* Acknowledgment number */
	unsigned long	TCPSequence;     /* Sequence number */
	unsigned char	Flags;           /* use TCP_FLAG_XXX defines */
	unsigned char	extra[3];        /* Reserved */
	unsigned short VLAN_Pri;        /*VLAN Priority: available constants
                                      VLAN_PRI_0 VLAN_PRI_1 VLAN_PRI_2 VLAN_PRI_3
                                      VLAN_PRI_4 VLAN_PRI_5 VLAN_PRI_6 VLAN_PRI_7
                                      VLAN_PRI_LOWEST VLAN_PRI_HIGHEST */
	unsigned short VLAN_Cfi;        /*VLAN CFI bit: available constants
                                      VLAN_CFI_RIF_ABSENT  VLAN_CFI_RIF_PRESENT */
	unsigned short VLAN_Vid;        /*VLAN identifier */
} StreamTCPIPv6VLAN;

/* end of IPv6 stream definitions */

/*
RTPCounterInfo description:
   get information of the current RTP counter on the Transmit Engine.

iType1:		L3_RTP_COUNTER_INFO
iType2:     index
iType3:     count
Function:	HTGetStructure

*/
typedef struct tagRTPCounterInfo
{
   unsigned long  ulStreamNumber;       /* stream number */
   unsigned long  ulFrameCount;         /* number of transmitted frame containing the stream */
   unsigned long  ulReserved[4];
}RTPCounterInfo;

/*---- OBSOLETE ---- OBSOLETE --------------------- OBSOLETE ----- OBSOLETE ---*/
/*---- OBSOLETE -------------------- OBSOLETE -------------------- OBSOLETE ---*/
/*---- OBSOLETE ---- OBSOLETE --------------------- OBSOLETE ----- OBSOLETE ---*/

/* The items listed in this section below are obsolete and should NOT be
 * used. They exist for backward compatibility for old programs but are
 * NOT recommended for use in new programs.
 */

#define NS_HIST_LATENCY_PER_STREAM_INFO_32   NS_HIST_V1_LATENCY_PER_STREAM_INFO	/* Get 32-bit Latency per Stream histogram results */
#define NS_HIST_LATENCY_PER_STREAM_32			NS_HIST_V1_LATENCY_PER_STREAM			/* Set to collect 32-bit Latency per Stream histogram */

#define NS_DEFINE_UDPDHCP_STREAM					0x1005	/* Create a single UDPDHCP Stream (based on a structure)*/
																		/* or multiple UDPDHCP Streams (using an array of structures)*/
#define NS_DEFINE_MULTI_UDPDHCP_STREAM		0x1015		/* Define multiple copies of a UDPDHCP Stream */
#define NS_MOD_UDPDHCP_STREAM					0x1035		/* put one UDPDHCP Stream in the list at a given index */
#define NS_UDPDHCP_STREAM_INFO				0x1515		/* Retrieve one UDPDHCP Stream */

#define STREAM_PROTOCOL_UDPDHCP   99		/* a UDPDHCP Stream type, unsupported */

/*
StreamUDPDHCP Description:

This structure contains values for UDPDHCP protocol Stream type.

The UDPDHCP header is filled in with the protocol fields
the structure. The IP checksum is
calculated using the supplied header fields and
automatically inserted into the UDPDHCP header.

If the ucTagField is enabled ( set to 1), then the
Netcom Systems signature tag field will be inserted
into each frame at the latter end of the payload.

*/
typedef struct tagStreamUDPDHCP
 {
 unsigned char   ucActive;			/* 1 = Enabled, 0 = Disabled    */
 unsigned char   ucProtocolType;	/* use STREAM_PROTOCOL_xxx      */
											/* defines above                */
 unsigned char   ucRandomLength;	/* Reserved */
 unsigned char   ucRandomData;	/* 1 = Random Data, 0 = use the */
											/* cards background pattern     */
											/* not available on Frame Relay */
 unsigned short  uiFrameLength;	/* frame length not counting CRC*/
											/* 0 - 2048 for Ethernet        */
											/* 0 - 8196 for Frame Relay     */
 unsigned short  uiVFD1Offset;	/* in bits                      */
 unsigned char   ucVFD1Range;		/* in bits                      */
 unsigned char   ucVFD1Pattern;	/* HVFD_ENABLED, HVFD_STATIC,   */
											/* HVFD_INCR, HVFD_DECR,        */
											/* HVFD_RANDOM, HVFD_NONE       */
 unsigned long   ulVFD1PatternCount;/* from 0(off) to 16,777,215 */
											/* number to incr. or decr.     */
											/* through when using inc or    */
											/* dec pattern                  */
 unsigned char   ucVFD1StartVal[6];/*the initial VFD byte pattern*/

 unsigned short  uiVFD2Offset;	/* in bits                      */
 unsigned char   ucVFD2Range;		/* in bits                      */
 unsigned char   ucVFD2Pattern;	/* HVFD_ENABLED, HVFD_STATIC,   */
											/* HVFD_INCR, HVFD_DECR,        */
											/* HVFD_RANDOM, HVFD_NONE       */
 unsigned long   ulVFD2PatternCount;/* from 0(off) to 16,777,215 */
											/* number to incr. or decr.     */
											/* through when using inc or    */
											/* dec pattern                  */
 unsigned char   ucVFD2StartVal[6];/*the initial VFD byte pattern*/

 unsigned short  uiVFD3Offset;	/* in bits                      */
 unsigned short  uiVFD3Range;		/* in bytes                     */
 unsigned char   ucVFD3Enable;	/* HVFD_ENABLED, VFD_NONE       */

 unsigned char   ucTagField;		/* 0 = off, 1 = insert signature */
											/* tag field into each frame    */

 unsigned char  DestinationMAC[6];/* the Stream's Dest MAC addr  */
 unsigned char  SourceMAC[6];		/* the Stream's Source MAC addr */
 unsigned char  TypeOfService;	/* */
 unsigned char  TimeToLive;		/* number of "hops" until frame */
											/* will be dropped */
 unsigned short InitialSequenceNumber;/* Initial sequence number */
 unsigned char  DestinationIP[4];/* Dest IP addr(e.g. 192.100.5.3) */
 unsigned char  SourceIP[4];		/* Src IP addr (e.g. 192.100.5.4) */
 unsigned char  Netmask[4];		/* Network Mask (e.g. 255.255.0.0)*/
 unsigned char  Gateway[4];		/* Gateway addr (e.g. 192.100.1.1)*/
 unsigned short UDPSrc;				/* UDP Source Port              */
 unsigned short UDPDest;			/* UDP Dest Port                */
 unsigned short UDPLen;				/* UDP Length field - not used  */

 unsigned char  DHCPRelayIP[4];	/* The Relay IP addr            */
 unsigned char  DHCPAction;		/* see DHCP_ACTION_ defines     */
 unsigned char  DHCPState;			/* see DHCP_STATE_ defines      */
 unsigned char  extra[6];			/* reserved                     */
 unsigned short uiActualSequenceNumber;/* Actual Sequence number */

 unsigned long  ulARPStart;		/* Return value for the Time of */
											/* the last ARP initiated       */
 unsigned long  ulARPEnd;			/* Return value for the Time of */
											/* the last ARP completed       */
 unsigned long  ulARPGap;			/* The Time between ARPs, in 100ns units */
 } StreamUDPDHCP;


/*
StreamICMPVLAN Description:

This structure contains values for ICMP compliant Streams for IPv4 that use VLAN tagging.

The ICMP checksum is automatically calculated using
the supplied header fields and inserted into the IP header.

A Netcom Systems Signature field, used for Histogram results, is
inserted at the end of the payload if ucTagField is enabled 
(set to 1).

NOTE:  The Signature field is 18 bytes long, and laid into the frame
just before the CRC. Use caution when defining the frame length
so that the Signature does not overwrite important data.

*/
typedef struct tagStreamICMPVLAN
{
 unsigned char   ucActive;			/* 1=Enable Stream, 0=Disable Stream */
 unsigned char   ucProtocolType;	/* use STREAM_PROTOCOL_ICMP_VLAN      */
 unsigned char   ucRandomLength;	/* 1 = Enable random frame length, 
                                 0 = use uiFrameLength.  
                                 Available on the LAN and POS TeraMetrics modules.
                                 Need to set the minimum and 
                                 maximum random lengths using 
                                 NS_PORT_TRANSMIT when enabled. 
                                 */
 unsigned char   ucRandomData;	/* 1 = Random Data, 0 = use the */
                                                         /* cards background pattern     */
				/* not available on Frame Relay */
 unsigned short  uiFrameLength;	/* frame length not counting CRC*/
				/* 0 - 2048 for Ethernet        */
				/* 0 - 8196 for Frame Relay     */

 /** VFD1 and VFD2 structure members are reserved for later use. Set to 0. **/
 unsigned short  uiVFD1Offset;	/* in bits                      */
 unsigned char   ucVFD1Range;	/* in bits                      */
 unsigned char   ucVFD1Pattern;	/* HVFD_ENABLED, HVFD_STATIC,   */
				/* HVFD_INCR, HVFD_DECR,        */
				/* HVFD_RANDOM, HVFD_NONE       */
 unsigned long   ulVFD1PatternCount;/* from 0(off) to 16,777,215.*/
				/* number to incr. or decr.     */
				/* through when using inc or    */
				/* dec pattern                  */
 unsigned char   ucVFD1StartVal[6];/*the initial VFD byte pattern */

 unsigned short  uiVFD2Offset;	/* in bits                      */
 unsigned char   ucVFD2Range;	/* in bits                      */
 unsigned char   ucVFD2Pattern;	/* HVFD_ENABLED, HVFD_STATIC,   */
				/* HVFD_INCR, HVFD_DECR,        */
				/* HVFD_RANDOM, HVFD_NONE       */
 unsigned long   ulVFD2PatternCount;/* from 0(off) to 16,777,215 */
				/* number to incr. or decr.     */
				/* through when using inc or    */
				/* dec pattern                  */
 unsigned char   ucVFD2StartVal[6];/*the initial VFD byte pattern*/
 /****************************************************************/


 unsigned short  uiVFD3Offset;	/* in bytes                     */
 unsigned short  uiVFD3Range;	/* in bytes                     */
 unsigned char   ucVFD3Enable;	/* HVFD_ENABLED, HVFD_NONE       */

 unsigned char   ucTagField;	/* 0 = off, 1 = insert signature */
				/* field into each frame         */

 unsigned char  DestinationMAC[6];/* the Stream's Dest MAC addr  */
 unsigned char  SourceMAC[6];	/* the Stream's Source MAC addr */
 unsigned char  TypeOfService;	/* The various levels of speed 
                                                         and/or reliability           */
 unsigned char  TimeToLive;	/* number of "hops" until frame */
				/* will be dropped */
 unsigned short InitialSequenceNumber;	/* Initial sequence number*/
 unsigned char  DestinationIP[4];/* Dest IP addr(e.g. 192.100.5.3) */
 unsigned char  SourceIP[4];		/* Src IP addr (e.g. 192.100.5.4) */
 unsigned char  Netmask[4];      /*Netmask address (e.g. 255.255.255.0)*/
 unsigned char  Gateway[4];		/* Gateway addr (e.g. 192.100.1.1)*/

 unsigned short VLAN_Pri;         /* VLAN Priority: available constants
                                       VLAN_PRI_0 VLAN_PRI_1 VLAN_PRI_2 VLAN_PRI_3
                                       VLAN_PRI_4 VLAN_PRI_5 VLAN_PRI_6 VLAN_PRI_7
                                       VLAN_PRI_LOWEST VLAN_PRI_HIGHEST */

 unsigned short VLAN_Cfi;         /* VLAN CFI bit: available constants
                                       VLAN_CFI_RIF_ABSENT  VLAN_CFI_RIF_PRESENT */

 unsigned short VLAN_Vid;         /*VLAN identifier                */

 unsigned char  ucType;          /* ICMP Type Number: Echo Request, Reply, etc.*/
 unsigned char  ucCode;          /* ICMP Code field */
 unsigned short uiIdentifier;    /* ICMP Identifier field */
 unsigned long  ulARPOut; /* Reserved */
 unsigned long  ulARPBack;  /* Reserved */
 unsigned long  ulARPGap;  /* Reserved */

 unsigned char  ucReserved[24];       /* Reserved */

}StreamICMPVLAN;


/*
StreamICMPIPv6 Description:

This structure contains values for ICMP compliant Streams for IPv6.

The ICMP checksum is automatically calculated using
the supplied header fields and inserted into the IP header.

A Netcom Systems Signature field, used for Histogram results, is
inserted at the end of the payload if ucTagField is enabled 
(set to 1).

NOTE:  The Signature field is 18 bytes long, and laid into the frame
just before the CRC. Use caution when defining the frame length
so that the Signature does not overwrite important data.

For ATM Terametrics modules set ucProtocolType as STREAM_PROTOCOL_ICMP_IPV6
when the bound VC is not of BRIDGED encapsulation while set it as
STREAM_PROTOCOL_BRIDGED when the bound VC is of BRIDGED encapsulation

Note for ucRandomLength:
1.	For the 1st generation Terametrics cards (LAN-330x/331x), ucRandomLength
    is supported when the start of IP (either IPv4 or IPv6) occurs
    at byte 63 or less.
2.	For the 2nd generation Terametrics cards (LAN-332x), ucRandomLength
    is supported when the start of IP (either IPv4 or IPv6) occurs at byte 127
    or less.

*/
typedef struct tagStreamICMPIPv6
{
 unsigned char   ucActive;			/* 1=Enable Stream, 0=Disable Stream */
 unsigned char   ucProtocolType;	/* use STREAM_PROTOCOL_ICMP_IPV6 or
                                       STREAM_PROTOCOL_BRIDGED (ATM only)
                                    */
 unsigned char   ucRandomLength;	     /* 1 = Enable random frame length, 
                                          0 = use uiFrameLength.
                                          Available on the LAN-33XX and 
                                          POS-35XX(except POS-3500/3502) cards.  
                                          Need to set the minimum and 
                                          maximum random lengths using 
                                          NS_PORT_TRANSMIT when enabled. */

 unsigned char   ucRandomData;	/* 1 = Random Data, 0 = use the */
                                                         /* cards background pattern     */
				/* not available on Frame Relay */
 unsigned short  uiFrameLength;	/* frame length not counting CRC*/
				/* 0 - 2048 for Ethernet        */
				/* 0 - 8196 for Frame Relay     */

 /** VFD1 and VFD2 structure members are reserved for later use. Set to 0. **/
 unsigned short  uiVFD1Offset;	/* in bits                      */
 unsigned char   ucVFD1Range;	/* in bits                      */
 unsigned char   ucVFD1Pattern;	/* HVFD_ENABLED, HVFD_STATIC,   */
				/* HVFD_INCR, HVFD_DECR,        */
				/* HVFD_RANDOM, HVFD_NONE       */
 unsigned long   ulVFD1PatternCount;/* from 0(off) to 16,777,215.*/
				/* number to incr. or decr.     */
				/* through when using inc or    */
				/* dec pattern                  */
 unsigned char   ucVFD1StartVal[6];/*the initial VFD byte pattern */

 unsigned short  uiVFD2Offset;	/* in bits                      */
 unsigned char   ucVFD2Range;	/* in bits                      */
 unsigned char   ucVFD2Pattern;	/* HVFD_ENABLED, HVFD_STATIC,   */
				/* HVFD_INCR, HVFD_DECR,        */
				/* HVFD_RANDOM, HVFD_NONE       */
 unsigned long   ulVFD2PatternCount;/* from 0(off) to 16,777,215 */
				/* number to incr. or decr.     */
				/* through when using inc or    */
				/* dec pattern                  */
 unsigned char   ucVFD2StartVal[6];/*the initial VFD byte pattern*/
 /****************************************************************/


 unsigned short  uiVFD3Offset;	/* in bytes                     */
 unsigned short  uiVFD3Range;	/* in bytes                     */
 unsigned char   ucVFD3Enable;	/* HVFD_ENABLED, HVFD_NONE       */

 unsigned char   ucTagField;	/* 0 = off, 1 = insert signature */
				/* field into each frame         */

 unsigned char DestinationMAC[6];/* the Stream's Dest MAC addr  */
 unsigned char SourceMAC[6];	/* the Stream's Source MAC addr */
 unsigned char ucTrafficClass;       /* Packet priority */
 unsigned char	ucNextHeader;         /* identifies the header type immediately
                                             following the IPV6 header */
 unsigned char ucHopLimit;           /* number of "hops" until frame */
                                          /* will be dropped */
 unsigned long ulFlowLabel;          /* label packets to request special handling */
 unsigned char SourceIP[16];         /* Source IPv6 address (e.g. 192.100.5.....4) */
 unsigned char DestinationIP[16];    /* Destination IPv6 address (e.g. 192.100.5.....4) */
 unsigned char	RouterIP[16];         /* Similar to gateway address */	
 unsigned char	ucPayloadLengthError; /* 0 - disable, 1 - enable, generate
                                             frame length error */ 
 unsigned char ucType;          /* ICMP Type Number: Echo Request, Reply, etc.*/
 unsigned char ucCode;          /* ICMP Code field */
 unsigned short uiIdentifier;    /* ICMP Identifier field */
 unsigned char ucReserved[24];
}StreamICMPIPv6;



/*
StreamICMPIPv6VLAN Description:

This structure contains values for ICMP compliant Streams for IPv6 that use VLAN tagging.

The ICMP checksum is automatically calculated using
the supplied header fields and inserted into the IP header.

A Netcom Systems Signature field, used for Histogram results, is
inserted at the end of the payload if ucTagField is enabled 
(set to 1).

NOTE:  The Signature field is 18 bytes long, and laid into the frame
just before the CRC. Use caution when defining the frame length
so that the Signature does not overwrite important data.

Note for ucRandomLength:
1.	For the 1st generation Terametrics cards (LAN-330x/331x), ucRandomLength
    is supported when the start of IP (either IPv4 or IPv6) occurs
    at byte 63 or less.
2.	For the 2nd generation Terametrics cards (LAN-332x), ucRandomLength
    is supported when the start of IP (either IPv4 or IPv6) occurs at byte 127
    or less.

*/
typedef struct tagStreamICMPIPv6VLAN
{
 unsigned char   ucActive;			/* 1=Enable Stream, 0=Disable Stream */
 unsigned char   ucProtocolType;	/* use STREAM_PROTOCOL_ICMP_IPV6_VLAN      */
 unsigned char   ucRandomLength;	     /* 1 = Enable random frame length, 
                                          0 = use uiFrameLength.
                                          Available on the LAN-33XX and 
                                          POS-35XX(except POS-3500/3502) cards.  
                                          Need to set the minimum and 
                                          maximum random lengths using 
                                          NS_PORT_TRANSMIT when enabled. */

 unsigned char   ucRandomData;	/* 1 = Random Data, 0 = use the */
                                                         /* cards background pattern     */
				/* not available on Frame Relay */
 unsigned short  uiFrameLength;	/* frame length not counting CRC*/
				/* 0 - 2048 for Ethernet        */
				/* 0 - 8196 for Frame Relay     */

 /** VFD1 and VFD2 structure members are reserved for later use. Set to 0. **/
 unsigned short  uiVFD1Offset;	/* in bits                      */
 unsigned char   ucVFD1Range;	/* in bits                      */
 unsigned char   ucVFD1Pattern;	/* HVFD_ENABLED, HVFD_STATIC,   */
				/* HVFD_INCR, HVFD_DECR,        */
				/* HVFD_RANDOM, HVFD_NONE       */
 unsigned long   ulVFD1PatternCount;/* from 0(off) to 16,777,215.*/
				/* number to incr. or decr.     */
				/* through when using inc or    */
				/* dec pattern                  */
 unsigned char   ucVFD1StartVal[6];/*the initial VFD byte pattern */

 unsigned short  uiVFD2Offset;	/* in bits                      */
 unsigned char   ucVFD2Range;	/* in bits                      */
 unsigned char   ucVFD2Pattern;	/* HVFD_ENABLED, HVFD_STATIC,   */
				/* HVFD_INCR, HVFD_DECR,        */
				/* HVFD_RANDOM, HVFD_NONE       */
 unsigned long   ulVFD2PatternCount;/* from 0(off) to 16,777,215 */
				/* number to incr. or decr.     */
				/* through when using inc or    */
				/* dec pattern                  */
 unsigned char   ucVFD2StartVal[6];/*the initial VFD byte pattern*/
 /****************************************************************/


 unsigned short  uiVFD3Offset;	/* in bytes                     */
 unsigned short  uiVFD3Range;	/* in bytes                     */
 unsigned char   ucVFD3Enable;	/* HVFD_ENABLED, HVFD_NONE       */

 unsigned char   ucTagField;	/* 0 = off, 1 = insert signature */
				/* field into each frame         */

 unsigned char  DestinationMAC[6];/* the Stream's Dest MAC addr  */
 unsigned char  SourceMAC[6];	/* the Stream's Source MAC addr */

 unsigned char ucTrafficClass;       /* Packet priority */
 unsigned char	ucNextHeader;         /* identifies the header type immediately
                                             following the IPV6 header */
 unsigned char ucHopLimit;           /* number of "hops" until frame */
                                          /* will be dropped */
 unsigned long ulFlowLabel;          /* label packets to request special handling */
 unsigned char SourceIP[16];         /* Source IPv6 address (e.g. 192.100.5.....4) */
 unsigned char DestinationIP[16];    /* Destination IPv6 address (e.g. 192.100.5.....4) */
 unsigned char	RouterIP[16];         /* Similar to gateway address */	
 unsigned char	ucPayloadLengthError; /* 0 - disable, 1 - enable, generate
                                             frame length error */
 unsigned short VLAN_Pri;         /* VLAN Priority: available constants
                                       VLAN_PRI_0 VLAN_PRI_1 VLAN_PRI_2 VLAN_PRI_3
                                       VLAN_PRI_4 VLAN_PRI_5 VLAN_PRI_6 VLAN_PRI_7
                                       VLAN_PRI_LOWEST VLAN_PRI_HIGHEST */

 unsigned short VLAN_Cfi;         /* VLAN CFI bit: available constants
                                       VLAN_CFI_RIF_ABSENT  VLAN_CFI_RIF_PRESENT */

 unsigned short VLAN_Vid;         /*VLAN identifier                */

 unsigned char ucType;          /* ICMP Type Number: Echo Request, Reply, etc.*/
 unsigned char ucCode;          /* ICMP Code field */
 unsigned short uiIdentifier;    /* ICMP Identifier field */
 unsigned char ucReserved[24];
}StreamICMPIPv6VLAN;


#endif  /* _STREAM_ITEMS_H_ */


