
/*
 *                                                        
 *  power_save (power_save.c): 
 *	Normal Mode: Normal operation
 *	IEEE Mode: Powering down all digital and analog blocks initiates a write to 
 *  PHY Control Register address 0x0010 bits '9:8' = '01'
 *	Active Sleep: This mode is the same as Passive Sleep mode,
 *  but also sends an NLP every 1.4 seconds (approximately) to wake up a link-partner. 
 *  Initiates a write to PHY Control Register address 0x0010 bits '9:8' = '10'
 *	Passive Sleep: This option powers down all digital and analog blocks.
 *  Automatic power-up is done when the link partner is detected. 
 *  Initiates a write to PHY Control Register address 0x0010 bits '9:8' ='11'
 *
 */                                                        


#include "registers.h"
#include "read_write.h"
#include "status.h"
#include "loopback.h"
#include "power_save.h"


int power_save(int phy_id, int set_power_save)
{

	    int  error=0;
		int  physcr_data=0,bmcr_data=0;

      //set power save
		switch (set_power_save)
        {
         case POWER_NORMAL: //
         physcr_data = phy_read(phy_id, PHYSCR); // read PHYCR_DATA holds the value of PHYCR 	   
    		 if (physcr_data < 0)// error
			 {			   
	              return error = physcr_data;
			 }		 
         physcr_data &= 0x8FFF ;   // clear bits [14:12] 		
         error = phy_write(phy_id, PHYSCR, physcr_data); //write
	         if (error < 0)
			 {			   
			     return error;
			 }

		 bmcr_data = phy_read(phy_id, BMCR); // read BMCR_DATA holds the value of BMCR 	   
 		     if (bmcr_data < 0)// error
			 {			   
	             return error = bmcr_data;
			 }		 
         bmcr_data &= 0xF7FF ;   // clear bit [11]		
         error = phy_write(phy_id, BMCR, bmcr_data); //write
	         if (error < 0)
			 {			   
			     return error;
			 }
		 break;

		 case POWER_IEEE: // ieee mode
         physcr_data = phy_read(phy_id, PHYSCR); // read PHYSCR_DATA holds the value of PHSYCR 	   
  		     if (physcr_data < 0)// error
			 {			   
	             return error = physcr_data;
			 }		 
         physcr_data &= 0x8FEF ;   // clear bits [14:12] 		         
         error = phy_write(phy_id, PHYSCR, physcr_data); //write
	         if (error < 0)
			 {			   
			     return error;
			 }

		 bmcr_data = phy_read(phy_id, BMCR); // read BMCR_DATA holds the value of BMCR 	   
  		     if (bmcr_data < 0)// error
			 {			   
	             return error = bmcr_data;
			 }		 	
         bmcr_data |= 0x0800 ;   // set bit 11
         error = phy_write(phy_id, BMCR, bmcr_data); //write
	         if (error < 0)
			 {			   
			     return error;
			 }
		 break;

		 case POWER_ACTIVE_SLEEP: //
         physcr_data = phy_read(phy_id, PHYSCR); // read PHYCR_DATA holds the value of PHYCR 	   
  		     if (physcr_data < 0)// error
			 {			   
	             return error = physcr_data;
			 }		 
         physcr_data &= 0x8FEF ;   // clear bits [14:12]		
         physcr_data |= 0x6000 ;   // set bit 14 & 13 
         error = phy_write(phy_id, PHYSCR, physcr_data); //write
	         if (error < 0)
			 {			   
			     return error;
			 }

		 bmcr_data = phy_read(phy_id, BMCR); // read BMCR_DATA holds the value of BMCR 	   
  		     if (bmcr_data < 0)// error
			 {			   
	             return error = bmcr_data;
			 }		 
         bmcr_data &= 0xF7FF ;   // clear bit [11]		
         error = phy_write(phy_id, BMCR, bmcr_data); //write
	         if (error < 0)
			 {			   
			     return error;
			 }
		 break;

		 case POWER_PASSIVE_SLEEP: //
         physcr_data = phy_read(phy_id, PHYSCR); // read PHYCR_DATA holds the value of PHYCR 	   
  		     if (physcr_data < 0)// error
			 {			   
	             return error = physcr_data;
			 }		          	
         physcr_data |= 0x7000 ;   // set bit 9 and bit 8
         error = phy_write(phy_id, PHYSCR, physcr_data); //write
	         if (error < 0)
			 {			   
			     return error;
			 }

		 bmcr_data = phy_read(phy_id, BMCR); // read BMCR_DATA holds the value of BMCR 	   
  		     if (bmcr_data < 0)// error
			 {			   
	             return error = bmcr_data;
			 }		 
         bmcr_data &= 0xF7FF ;   // clear bit [11]		         
         error = phy_write(phy_id, BMCR, bmcr_data); //write
	         if (error < 0)
			 {			   
			     return error;
			 }
		 break;


		 default: // normal power
         physcr_data = phy_read(phy_id, PHYSCR); // read PHYCR_DATA holds the value of PHYCR 	   
  		     if (physcr_data < 0)// error
			 {			   
	             return error = physcr_data;
			 }		 
         physcr_data &= 0x8FEF ;   // clear bits [14:12]		
         error = phy_write(phy_id, PHYSCR, physcr_data); //write
	         if (error < 0)
			 {			   
			     return error;
			 }

		 bmcr_data = phy_read(phy_id, BMCR); // read BMCR_DATA holds the value of BMCR 	   
  		     if (bmcr_data < 0)// error
			 {			   
	             return error = bmcr_data;
			 }		 
         bmcr_data &= 0xF7FF ;   // clear bit [11]		
         error = phy_write(phy_id, BMCR, bmcr_data); //write
	         if (error < 0)
			 {			   
			     return error;
			 }
		 break;

		}

		return 0;
}



