
/*
 * prbs_generator (prbs.c): PRBS BIST (built In self test),
 * the following options can be found in the prbs.h file
 * disable / enable
 * mode: continuous / single
 * Full control of the packets lengths and of the Inter Packet Gap (IPG) via the 
 * set_packet_length, set_packet_IPG inputs.
 *
 *  To send data from the Pseudo-Random Bit Sequence (PRBS) generator, the
 *  User must first establish a link and a loopback. The user can choose one of  
 *  The inner loopbacks, force the device to establish a link with itself, and then 
 *  Operate the PRBS generator. Another option is to configure a link with a 
 *  Partner and then set the partner to work in reverse loopback mode. 
 *
 *	prbs_checker (prbs.c): 
 *	number of error bytes
 *	lock_and_clear counter
 *
 *
 *	prbs_status (prbs.c): status on the following BIST data
 *	PRBS checker is locked on received byte stream
 *	PRBS checker has lost sync
 *	Packet generator is in process
 *
 */




#include <math.h>
#include "registers.h"
#include "read_write.h"
#include "status.h"
#include "loopback.h"
#include "power_save.h"
#include "prbs.h"

int prbs_generator(int phy_id,int prbs_generator_enable, int set_packet_length, int set_packet_IPG, int prbs_count_mode)
{

	    int  error=0;
		int  biscr_data=0;


if (prbs_generator_enable == ENABLE) // enable prbs generator
{

		 // set packet length reg BISPLR
         error = phy_write(phy_id, BISPLR, set_packet_length); 
	         if (error < 0)
			 {			   
			     return error;
			 }
		
		 // set packet IPG reg BISIPGR
         error = phy_write(phy_id, BICSR1, set_packet_IPG); 
	         if (error < 0)
			 {			   
			     return error;
			 }

         // read BIST Control Register
         biscr_data = phy_read(phy_id, BISCR);  	   
  		     if (biscr_data < 0)
			 {			   
	             return error = biscr_data;
			 }		 
         biscr_data &= 0xAFFF ;   //bits 14, and 12 to 0

		     if (prbs_count_mode == CONTINUOUS) // prbs counters wrap around
			 {
                  biscr_data |= 0x7000 ;   
			 }
			 else
			 {
                  biscr_data |= 0x3000 ; // prbs counters stop on max value
			 }
         error = phy_write(phy_id, BISCR, biscr_data); //write
	         if (error < 0)
			 {			   
			     return error;
			 }

}

else // disable prbs generator
{
	     // read BIST Control Register
         biscr_data = phy_read(phy_id, BISCR); 	   
   		     if (biscr_data < 0)// error
			 {			   
	             return error = biscr_data;
			 }		 
         biscr_data &= 0x0FFF ;   //bits 12 to 0 		   
         error = phy_write(phy_id, BISCR, biscr_data); //write
	         if (error < 0)
			 {			   
			     return error;
			 }

}
return 0;

}

// read error counter
int prbs_checker(int phy_id, int lock_and_clear_prbs_counters, prbs_counters *counters)
{

	    int  error=0;
		int	 bicsr1_data=0;
        
		 		 
         // Writing bit 15 generates a lock and clear signal for the PRBS Error counter
         bicsr1_data = phy_read(phy_id, BICSR1); //  	   
   		     if (bicsr1_data < 0)// error
			 {			   
	             return error = bicsr1_data;
			 }		       
 
		 if (lock_and_clear_prbs_counters == LOCK_AND_CLEAR)
		 {
		 bicsr1_data |= 0x8000 ;   // set bit 15
         error = phy_write(phy_id, BICSR1, bicsr1_data); //write
	         if (error < 0)
			 {			   
			     return error;
			 }
		 }      
		 bicsr1_data = phy_read(phy_id, BICSR1); //Holds number of erroneous bytes received by the PRBS checker.  	   
   		     if (bicsr1_data < 0)
			 {			   
	             return error = bicsr1_data;
			 }		 
         
         //counters->byte_counter = bisbcr_data;
		 counters->error_counter = bicsr1_data >> 8; //shift right by 8

		 return error;
}


// prbs status
int prbs_status(int phy_id, int *prbs_lock, int *prbs_sync_loss, int *prbs_busy)
{

	    int  error=0;
		int  biscr_data = 0;
        int  power_int;
		double power; 
        int lock=0, sync_loss=0, busy=0;

         biscr_data = phy_read(phy_id, BISCR); //  	   
   		     if (biscr_data < 0)// error
			 {			   
	             return error = biscr_data;
			 }		 
         //prbs_lock
		 power =	pow(2,11); 
         power_int = (int) (power);
	     lock = (biscr_data / power_int) & 0x1; //bit 11 = 1 --> PRBS checker is locked on received byte stream

         //prbs_sync_loss
		 power =	pow(2,10); 
         power_int = (int) (power);
	     sync_loss = (biscr_data / power_int) & 0x1; //bit 10 = 1 --> PRBS checker has lost sync

         //prbs_ busy
		 power =	pow(2,9); 
         power_int = (int) (power);
	     busy = (biscr_data / power_int) & 0x1; //bit 9 = 1 --> Packet generator is in process 

		     *prbs_lock = lock;
			 *prbs_sync_loss = sync_loss;
			 *prbs_busy = busy;

		 return error;
}